unit OdbcInst;

interface

uses Windows, SqlTypes, Sql;

{ ---------------------------------------------------------- }
{ ODBCInst.pas -- Prototypes for ODBCCP32.DLL                }
{              -- Win32 Support                              }
{                                                            }
{ (c) Microsoft Corp., 1990-1996                             }
{                                                            }
{ Translated From: ODBCInst.h                                }
{ Last Modified: 12/05/1997                                  }
{ Version: 1.0                                               }
{ ---------------------------------------------------------- }

{ ----------- Conditional Compilation Directives ----------- }
{                                                            }
{ During compilation, the version of ODBC support can be     }
{ specified as one, or a combination of the following        }
{ condition compilation directives:                          }
{                                                            }
{    ODBC_BaseVer  (Base ODBC Version Support)               }
{    ODBC_Ver10    (ODBC Version 1.0  Support)               }
{    ODBC_Ver20    (ODBC Version 2.0  Support)               }
{    ODBC_Ver25    (ODBC Version 2.5  Support)               }
{    ODBC_Ver30    (ODBC Version 3.0  Support)               }
{                                                            }
{    If the ODBC version is not explicitly defined with a    }
{    conditional compilation directive, the compile will     }
{    default to ODBC_Ver30.                                  }
{ ---------------------------------------------------------- }

//  Default to ODBC Version 3.0 if no version is specified
{$IFNDEF ODBC_BaseVer} {and} {$IFNDEF ODBC_Ver10} {and} {$IFNDEF ODBC_Ver20}
      {and} {$IFNDEF ODBC_Ver25} {and} {$IFNDEF ODBC_Ver30} {then}
  {$DEFINE ODBC_Ver30}
{$ENDIF} {$ENDIF} {$ENDIF} {$ENDIF} {$ENDIF}

//  Make sure ODBC Version 2.5 is included if this is ODBC Version 3.0
{$IFDEF ODBC_Ver30} {and} {$IFNDEF ODBC_Ver25}
    {$DEFINE ODBC_Ver25}
{$ENDIF} {$ENDIF}


const
//  ODBC Version Constant
{$IFDEF ODBC_Ver30}    ODBCVER = $0300;  { ODBC Version 3.0  } {$ELSE}
{$IFDEF ODBC_Ver25}    ODBCVER = $0250;  { ODBC Version 2.5  } {$ELSE}
{$IFDEF ODBC_Ver20}    ODBCVER = $0200;  { ODBC Version 2.0  } {$ELSE}
{$IFDEF ODBC_Ver10}    ODBCVER = $0100;  { ODBC Version 1.0  } {$ELSE}
{$IFDEF ODBC_BaseVer}  ODBCVER = $0100;  { Base ODBC Version }
{$ELSE}                ODBCVER = $0000;  { Unknown Version   }
{$ENDIF} {$ENDIF} {$ENDIF} {$ENDIF} {$ENDIF}

//  SQLConfigDataSource request flags
  ODBC_ADD_DSN            = 1;        //  Add data source
  ODBC_CONFIG_DSN         = 2;        //  Configure (edit) data source
  ODBC_REMOVE_DSN         = 3;        //  Remove data source

{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
  ODBC_ADD_SYS_DSN        = 4;        //  add a system DSN
  ODBC_CONFIG_SYS_DSN     = 5;        //  Configure a system DSN
  ODBC_REMOVE_SYS_DSN     = 6;        //  remove a system DSN

  //  install request flags
  ODBC_INSTALL_INQUIRY    = 1;
  ODBC_INSTALL_COMPLETE   = 2;

  //  config driver flags
  ODBC_INSTALL_DRIVER     = 1;
  ODBC_REMOVE_DRIVER      = 2;
  ODBC_CONFIG_DRIVER      = 3;
  ODBC_CONFIG_DRIVER_MAX  = 100;
{$ENDIF} {ODBC_Ver25}

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  ODBC_REMOVE_DEFAULT_DSN             = 7;  //  remove the default DSN

  //  SQLGetConfigMode and SQLSetConfigMode flags
  ODBC_BOTH_DSN                       = 0;
  ODBC_USER_DSN                       = 1;
  ODBC_SYSTEM_DSN                     = 2;

  //  SQLInstallerError code
  ODBC_ERROR_GENERAL_ERR              = 1;
  ODBC_ERROR_INVALID_BUFF_LEN         = 2;
  ODBC_ERROR_INVALID_HWND             = 3;
  ODBC_ERROR_INVALID_STR              = 4;
  ODBC_ERROR_INVALID_REQUEST_TYPE     = 5;
  ODBC_ERROR_COMPONENT_NOT_FOUND      = 6;
  ODBC_ERROR_INVALID_NAME             = 7;
  ODBC_ERROR_INVALID_KEYWORD_VALUE    = 8;
  ODBC_ERROR_INVALID_DSN              = 9;
  ODBC_ERROR_INVALID_INF              = 10;
  ODBC_ERROR_REQUEST_FAILED           = 11;
  ODBC_ERROR_INVALID_PATH             = 12;
  ODBC_ERROR_LOAD_LIB_FAILED          = 13;
  ODBC_ERROR_INVALID_PARAM_SEQUENCE   = 14;
  ODBC_ERROR_INVALID_LOG_FILE         = 15;
  ODBC_ERROR_USER_CANCELED            = 16;
  ODBC_ERROR_USAGE_UPDATE_FAILED      = 17;
  ODBC_ERROR_CREATE_DSN_FAILED        = 18;
  ODBC_ERROR_WRITING_SYSINFO_FAILED   = 19;
  ODBC_ERROR_REMOVE_DSN_FAILED        = 20;
  ODBC_ERROR_OUT_OF_MEM               = 21;
  ODBC_ERROR_OUTPUT_STRING_TRUNCATED  = 22;
{$ENDIF} {ODBC_Ver30}


type
  PUWORD = PWORD;
  UWORD = WORD;

  
//  Prototypes ---------------------------------------------------------

//  High level APIs
function SQLManageDataSources(hwndParent: HWND): BOOL; cdecl;


//  High level APIs  --  ANSI and UNICODE APIs
function SQLInstallODBC(hwndParent: HWND; lpszInfFile, lpszSrcPath,
               lpszDrivers: LPCSTR): BOOL; cdecl;
function SQLInstallODBCW(hwndParent: HWND; lpszInfFile, lpszSrcPath,
               lpszDrivers: LPCWSTR): BOOL; cdecl;

function SQLCreateDataSource(hwndParent: HWND; lpszDSN: LPCSTR): BOOL; cdecl;
function SQLCreateDataSourceW(hwndParent: HWND; lpszDSN: LPCWSTR): BOOL; cdecl;

function SQLGetTranslator(hwndTrans: HWND; lpszName: LPSTR; cbNameMax: WORD;
               pcbNameOut: PWORD; lpszPath: LPSTR; cbPathMax: WORD;
               pcbPathOut: PWORD; pvOption: PDWORD): BOOL; cdecl;
function SQLGetTranslatorW(hwndTrans: HWND; lpszName: LPWSTR; cbNameMax: WORD;
               pcbNameOut: PWORD; lpszPath: LPWSTR; cbPathMax: WORD;
               pcbPathOut: PWORD; pvOption: PDWORD): BOOL; cdecl;


//  Low level APIs
//  NOTE: The high-level APIs should always be used. These APIs
//        have been left for compatibility.

function SQLRemoveDefaultDataSource: BOOL; cdecl;

{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
function SQLRemoveDriverManager(lpdwUsageCount: LPDWORD): BOOL; cdecl;
{$ENDIF} {ODBC_Ver25}

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLGetConfigMode(pwConfigMode: PUWORD): BOOL; cdecl;
function SQLSetConfigMode(wConfigMode: UWORD): BOOL; cdecl;
{$ENDIF} {ODBC_Ver30}


//  Low level APIs  --  ANSI and UNICODE APIs
//  NOTE: The high-level APIs should always be used. These APIs
//        have been left for compatibility.
function SQLInstallDriver(lpszInfFile, lpszDriver: LPCSTR; lpszPath: LPSTR;
               cbPathMax: WORD; pcbPathOut: PWORD): BOOL; cdecl;
function SQLInstallDriverW(lpszInfFile, lpszDriver: LPCWSTR; lpszPath: LPWSTR;
               cbPathMax: WORD; pcbPathOut: PWORD): BOOL; cdecl;

function SQLInstallDriverManager(lpszPath: LPSTR; cbPathMax: WORD;
               pcbPathOut: PWORD): BOOL; cdecl;
function SQLInstallDriverManagerW(lpszPath: LPWSTR; cbPathMax: WORD;
               pcbPathOut: PWORD): BOOL; cdecl;

function SQLGetInstalledDrivers(lpszBuf: LPSTR; cbBufMax: WORD;
               pcbBufOut: PWORD): BOOL; cdecl;
function SQLGetInstalledDriversW(lpszBuf: LPWSTR; cbBufMax: WORD;
               pcbBufOut: PWORD): BOOL; cdecl;

function SQLGetAvailableDrivers(lpszInfFile: LPCSTR; lpszBuf: LPSTR;
               cbBufMax: WORD; pcbBufOut: PWORD): BOOL; cdecl;
function SQLGetAvailableDriversW(lpszInfFile: LPCWSTR; lpszBuf: LPWSTR;
               cbBufMax: WORD; pcbBufOut: PWORD): BOOL; cdecl;

function SQLConfigDataSource(hwndParent: HWND; fRequest: WORD;
               lpszDriver, lpszAttributes: LPCSTR): BOOL; cdecl;
function SQLConfigDataSourceW(hwndParent: HWND; fRequest: WORD;
               lpszDriver, lpszAttributes: LPCWSTR): BOOL; cdecl;

function SQLWriteDSNToIni(lpszDSN, lpszDriver: LPCSTR): BOOL; cdecl;
function SQLWriteDSNToIniW(lpszDSN, lpszDriver: LPCWSTR): BOOL; cdecl;

function SQLRemoveDSNFromIni(lpszDSN: LPCSTR): BOOL; cdecl;
function SQLRemoveDSNFromIniW(lpszDSN: LPCWSTR): BOOL; cdecl;

function SQLValidDSN(lpszDSN: LPCSTR): BOOL; cdecl;
function SQLValidDSNW(lpszDSN: LPCWSTR): BOOL; cdecl;

function SQLWritePrivateProfileString(lpszSection, lpszEntry, lpszString,
               lpszFilename: LPCSTR): BOOL; cdecl;
function SQLWritePrivateProfileStringW(lpszSection, lpszEntry, lpszString,
               lpszFilename: LPCWSTR): BOOL; cdecl;

function SQLGetPrivateProfileString(lpszSection, lpszEntry, lpszDefault: LPCSTR;
               lpszRetBuffer: LPSTR; cbRetBuffer: Integer;
               lpszFilename: LPCSTR): Integer; cdecl;
function SQLGetPrivateProfileStringW(lpszSection, lpszEntry, lpszDefault: LPCWSTR;
               lpszRetBuffer: LPWSTR; cbRetBuffer: Integer;
               lpszFilename: LPCWSTR): Integer; cdecl;


{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
function SQLInstallTranslator(lpszInfFile, lpszTranslator, lpszPathIn: LPCSTR;
               lpszPathOut: LPSTR; cbPathOutMax: WORD; pcbPathOut: PWORD;
               fRequest: WORD; lpdwUsageCount: LPDWORD): BOOL; cdecl;
function SQLInstallTranslatorW(lpszInfFile, lpszTranslator, lpszPathIn: LPCWSTR;
               lpszPathOut: LPWSTR; cbPathOutMax: WORD; pcbPathOut: PWORD;
               fRequest: WORD; lpdwUsageCount: LPDWORD): BOOL; cdecl;

function SQLRemoveTranslator(lpszTranslator: LPCSTR; lpdwUsageCount: LPDWORD): BOOL; cdecl;
function SQLRemoveTranslatorW(lpszTranslator: LPCWSTR; lpdwUsageCount: LPDWORD): BOOL; cdecl;

function SQLRemoveDriver(lpszDriver: LPCSTR; fRemoveDSN: BOOL;
               lpdwUsageCount: LPDWORD): BOOL; cdecl;
function SQLRemoveDriverW(lpszDriver: LPCWSTR; fRemoveDSN: BOOL;
               lpdwUsageCount: LPDWORD): BOOL; cdecl;

function SQLConfigDriver(hwndParent: HWND; fRequest: WORD; lpszDriver,
               lpszArgs: LPCSTR; lpszMsg: LPSTR; cbMsgMax: WORD;
               pcbMsgOut: PWORD): BOOL; cdecl;
function SQLConfigDriverW(hwndParent: HWND; fRequest: WORD; lpszDriver, lpszArgs: LPCWSTR;
               lpszMsg: LPWSTR; cbMsgMax: WORD; pcbMsgOut: PWORD): BOOL; cdecl;
{$ENDIF} {ODBC_Ver25}


{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLInstallerError(iError: WORD; pfErrorCode: PDWORD; lpszErrorMsg: LPSTR;
               cbErrorMsgMax: WORD; pcbErrorMsg: PWORD): SQLRETURN; cdecl;
function SQLInstallerErrorW(iError: WORD; pfErrorCode: PDWORD; lpszErrorMsg: LPWSTR;
               cbErrorMsgMax: WORD; pcbErrorMsg: PWORD): SQLRETURN; cdecl;

function SQLPostInstallerError(dwErrorCode: DWORD; lpszErrMsg: LPCSTR): SQLRETURN; cdecl;
function SQLPostInstallerErrorW(dwErrorCode: DWORD; lpszErrorMsg: LPCWSTR): SQLRETURN; cdecl;

function SQLWriteFileDSN(lpszFileName, lpszAppName, lpszKeyName,
               lpszString: LPCSTR): BOOL; cdecl;
function SQLWriteFileDSNW(lpszFileName, lpszAppName, lpszKeyName,
               lpszString: LPCWSTR): BOOL; cdecl;

function SQLReadFileDSN(lpszFileName, lpszAppName, lpszKeyName: LPCSTR;
               lpszString: LPSTR; cbString: WORD; pcbString: PWORD): BOOL; cdecl;
function SQLReadFileDSNW(lpszFileName, lpszAppName, lpszKeyName: LPCWSTR;
               lpszString: LPWSTR; cbString: WORD; pcbString: PWORD): BOOL; cdecl;

function SQLInstallDriverEx(lpszDriver, lpszPathIn: LPCSTR;
               lpszPathOut: LPSTR; cbPathOutMax: WORD; pcbPathOut: PWORD;
               fRequest: WORD; lpdwUsageCount: LPDWORD): BOOL; cdecl;
function SQLInstallDriverExW(lpszDriver, lpszPathIn: LPCWSTR;
               lpszPathOut: LPWSTR; cbPathOutMax: WORD; pcbPathOut: WORD;
               fRequest: WORD; lpdwUsageCount: LPDWORD): BOOL; cdecl;

function SQLInstallTranslatorEx(lpszTranslator, lpszPathIn: LPCSTR;
               lpszPathOut: LPSTR; cbPathOutMax: WORD; pcbPathOut: PWORD;
               fRequest: WORD; lpdwUsageCount: LPDWORD): BOOL; cdecl;
function SQLInstallTranslatorExW(lpszTranslator, lpszPathIn: LPCWSTR;
               lpszPathOut: LPWSTR; cbPathOutMax: WORD; pcbPathOut: PWORD;
               fRequest: WORD; lpdwUsageCount: LPDWORD): BOOL; cdecl;

{$ENDIF} {ODBC_Ver30}


//  Driver specific Setup APIs called by installer

function ConfigDSN(hwndParent: HWND; fRequest: WORD;
               lpszDriver, lpszAttributes: LPCSTR): BOOL; cdecl;
function ConfigDSNW(hwndParent: HWND; fRequest: WORD;
               lpszDriver, lpszAttributes: LPCWSTR): BOOL; cdecl;

function ConfigTranslator(hwndParent: HWND; pvOption: PDWORD): BOOL; cdecl;


{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
function ConfigDriver(hwndParent: HWND; fRequest: WORD; lpszDriver, lpszArgs: LPCSTR;
               lpszMsg: LPSTR; cbMsgMax: WORD; pcbMsgOut: PWORD): BOOL; cdecl;
function ConfigDriverW(hwndParent: HWND; fRequest: WORD; lpszDriver, lpszArgs: LPCWSTR;
               lpszMsg: LPWSTR; cbMsgMax: WORD; pcbMsgOut: PWORD): BOOL; cdecl;
{$ENDIF} {ODBC_Ver25}


const
  ODBCCP32 = 'odbccp32.dll';

implementation

//  ANSI

function SQLManageDataSources; external ODBCCP32 name 'SQLManageDataSources';
function SQLRemoveDefaultDataSource; external ODBCCP32 name 'SQLRemoveDefaultDataSource';

{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
function SQLRemoveDriverManager; external ODBCCP32 name 'SQLRemoveDriverManager';
{$ENDIF} {ODBC_Ver25}

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLGetConfigMode; external ODBCCP32 name 'SQLGetConfigMode';
function SQLSetConfigMode; external ODBCCP32 name 'SQLSetConfigMode';
{$ENDIF} {ODBC_Ver30}

function ConfigTranslator; external ODBCCP32 name 'ConfigTranslator';


//  UNICODE

function SQLInstallODBCW; external ODBCCP32 name 'SQLInstallODBCW';
function SQLCreateDataSourceW; external ODBCCP32 name 'SQLCreateDataSourceW';
function SQLGetTranslatorW; external ODBCCP32 name 'SQLGetTranslatorW';
function SQLInstallDriverW; external ODBCCP32 name 'SQLInstallDriverW';
function SQLInstallDriverManagerW; external ODBCCP32 name 'SQLInstallDriverManagerW';
function SQLGetInstalledDriversW; external ODBCCP32 name 'SQLGetInstalledDriversW';
function SQLGetAvailableDriversW; external ODBCCP32 name 'SQLGetAvailableDriversW';
function SQLConfigDataSourceW; external ODBCCP32 name 'SQLConfigDataSourceW';
function SQLWriteDSNToIniW; external ODBCCP32 name 'SQLWriteDSNToIniW';
function SQLRemoveDSNFromIniW; external ODBCCP32 name 'SQLRemoveDSNFromIniW';
function SQLValidDSNW; external ODBCCP32 name 'SQLValidDSNW';
function SQLWritePrivateProfileStringW; external ODBCCP32 name 'SQLWritePrivateProfileStringW';
function SQLGetPrivateProfileStringW; external ODBCCP32 name 'SQLGetPrivateProfileStringW';

{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
function SQLInstallTranslatorW; external ODBCCP32 name 'SQLInstallTranslatorW';
function SQLRemoveTranslatorW; external ODBCCP32 name 'SQLRemoveTranslatorW';
function SQLRemoveDriverW; external ODBCCP32 name 'SQLRemoveDriverW';
function SQLConfigDriverW; external ODBCCP32 name 'SQLConfigDriverW';
{$ENDIF} {ODBC_Ver25}

{$IFDEF ODBC_Ver30}  { ODBC Version 2.5 and above }
function SQLInstallerErrorW; external ODBCCP32 name 'SQLInstallerErrorW';
function SQLPostInstallerErrorW; external ODBCCP32 name 'SQLPostInstallerErrorW';
function SQLWriteFileDSNW; external ODBCCP32 name 'SQLWriteFileDSNW';
function SQLReadFileDSNW; external ODBCCP32 name 'SQLReadFileDSNW';
function SQLInstallDriverExW; external ODBCCP32 name 'SQLInstallDriverExW';
function SQLInstallTranslatorExW; external ODBCCP32 name 'SQLInstallTranslatorExW';
{$ENDIF} {ODBC_Ver30}

function ConfigDSNW; external ODBCCP32 name 'ConfigDSNW';

{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
function ConfigDriverW; external ODBCCP32 name 'ConfigDriverW';
{$ENDIF} {ODBC_Ver25}


{$IFNDEF SQL_NOUNICODEMAP}   //  define this to disable the mapping
{$IFDEF UNICODE}

//    UNICODE Mappings
function SQLInstallODBC; external ODBCCP32 name 'SQLInstallODBCW';
function SQLCreateDataSource; external ODBCCP32 name 'SQLCreateDataSourceW';
function SQLGetTranslator; external ODBCCP32 name 'SQLGetTranslatorW';
function SQLInstallDriver; external ODBCCP32 name 'SQLInstallDriverW';
function SQLInstallDriverManager; external ODBCCP32 name 'SQLInstallDriverManagerW';
function SQLGetInstalledDrivers; external ODBCCP32 name 'SQLGetInstalledDriversW';
function SQLGetAvailableDrivers; external ODBCCP32 name 'SQLGetAvailableDriversW';
function SQLConfigDataSource; external ODBCCP32 name 'SQLConfigDataSourceW';
function SQLWriteDSNToIni; external ODBCCP32 name 'SQLWriteDSNToIniW';
function SQLRemoveDSNFromIni; external ODBCCP32 name 'SQLRemoveDSNFromIniW';
function SQLValidDSN; external ODBCCP32 name 'SQLValidDSNW';
function SQLWritePrivateProfileString; external ODBCCP32 name 'SQLWritePrivateProfileStringW';
function SQLGetPrivateProfileString; external ODBCCP32 name 'SQLGetPrivateProfileStringW';

{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
function SQLInstallTranslator; external ODBCCP32 name 'SQLInstallTranslatorW';
function SQLRemoveTranslator; external ODBCCP32 name 'SQLRemoveTranslatorW';
function SQLRemoveDriver; external ODBCCP32 name 'SQLRemoveDriverW';
function SQLConfigDriver; external ODBCCP32 name 'SQLConfigDriverW';
{$ENDIF} {ODBC_Ver25}

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLInstallerError; external ODBCCP32 name 'SQLInstallerErrorW';
function SQLPostInstallerError; external ODBCCP32 name 'SQLPostInstallerErrorW';
function SQLWriteFileDSN; external ODBCCP32 name 'SQLWriteFileDSNW';
function SQLReadFileDSN; external ODBCCP32 name 'SQLReadFileDSNW';
function SQLInstallDriverEx; external ODBCCP32 name 'SQLInstallDriverExW';
function SQLInstallTranslatorEx; external ODBCCP32 name 'SQLInstallTranslatorExW';
{$ENDIF} {ODBC_Ver30}

function ConfigDSN; external ODBCCP32 name 'ConfigDSNW';

{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
function ConfigDriver; external ODBCCP32 name 'ConfigDriverW';
{$ENDIF} {ODBC_Ver25}


{$ELSE}   //  ANSI

//    Without UNICODE Mappings
function SQLInstallODBC; external ODBCCP32 name 'SQLInstallODBC';
function SQLCreateDataSource; external ODBCCP32 name 'SQLCreateDataSource';
function SQLGetTranslator; external ODBCCP32 name 'SQLGetTranslator';
function SQLInstallDriver; external ODBCCP32 name 'SQLInstallDriver';
function SQLInstallDriverManager; external ODBCCP32 name 'SQLInstallDriverManager';
function SQLGetInstalledDrivers; external ODBCCP32 name 'SQLGetInstalledDrivers';
function SQLGetAvailableDrivers; external ODBCCP32 name 'SQLGetAvailableDrivers';
function SQLConfigDataSource; external ODBCCP32 name 'SQLConfigDataSource';
function SQLWriteDSNToIni; external ODBCCP32 name 'SQLWriteDSNToIni';
function SQLRemoveDSNFromIni; external ODBCCP32 name 'SQLRemoveDSNFromIni';
function SQLValidDSN; external ODBCCP32 name 'SQLValidDSN';
function SQLWritePrivateProfileString; external ODBCCP32 name 'SQLWritePrivateProfileString';
function SQLGetPrivateProfileString; external ODBCCP32 name 'SQLGetPrivateProfileString';

{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
function SQLInstallTranslator; external ODBCCP32 name 'SQLInstallTranslator';
function SQLRemoveTranslator; external ODBCCP32 name 'SQLRemoveTranslator';
function SQLRemoveDriver; external ODBCCP32 name 'SQLRemoveDriver';
function SQLConfigDriver; external ODBCCP32 name 'SQLConfigDriver';
{$ENDIF} {ODBC_Ver25}

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLInstallerError; external ODBCCP32 name 'SQLInstallerError';
function SQLPostInstallerError; external ODBCCP32 name 'SQLPostInstallerError';
function SQLWriteFileDSN; external ODBCCP32 name 'SQLWriteFileDSN';
function SQLReadFileDSN; external ODBCCP32 name 'SQLReadFileDSN';
function SQLInstallDriverEx; external ODBCCP32 name 'SQLInstallDriverEx';
function SQLInstallTranslatorEx; external ODBCCP32 name 'SQLInstallTranslatorEx';
{$ENDIF} {ODBC_Ver30}

function ConfigDSN; external ODBCCP32 name 'ConfigDSN';

{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
function ConfigDriver; external ODBCCP32 name 'ConfigDriver';
{$ENDIF} {ODBC_Ver25}

{$ENDIF} {UNICODE}

{$ELSE}  //    Without UNICODE Mappings
function SQLInstallODBC; external ODBCCP32 name 'SQLInstallODBC';
function SQLCreateDataSource; external ODBCCP32 name 'SQLCreateDataSource';
function SQLGetTranslator; external ODBCCP32 name 'SQLGetTranslator';
function SQLInstallDriver; external ODBCCP32 name 'SQLInstallDriver';
function SQLInstallDriverManager; external ODBCCP32 name 'SQLInstallDriverManager';
function SQLGetInstalledDrivers; external ODBCCP32 name 'SQLGetInstalledDrivers';
function SQLGetAvailableDrivers; external ODBCCP32 name 'SQLGetAvailableDrivers';
function SQLConfigDataSource; external ODBCCP32 name 'SQLConfigDataSource';
function SQLWriteDSNToIni; external ODBCCP32 name 'SQLWriteDSNToIni';
function SQLRemoveDSNFromIni; external ODBCCP32 name 'SQLRemoveDSNFromIni';
function SQLValidDSN; external ODBCCP32 name 'SQLValidDSN';
function SQLWritePrivateProfileString; external ODBCCP32 name 'SQLWritePrivateProfileString';
function SQLGetPrivateProfileString; external ODBCCP32 name 'SQLGetPrivateProfileString';

{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
function SQLInstallTranslator; external ODBCCP32 name 'SQLInstallTranslator';
function SQLRemoveTranslator; external ODBCCP32 name 'SQLRemoveTranslator';
function SQLRemoveDriver; external ODBCCP32 name 'SQLRemoveDriver';
function SQLConfigDriver; external ODBCCP32 name 'SQLConfigDriver';
{$ENDIF} {ODBC_Ver25}

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLInstallerError; external ODBCCP32 name 'SQLInstallerError';
function SQLPostInstallerError; external ODBCCP32 name 'SQLPostInstallerError';
function SQLWriteFileDSN; external ODBCCP32 name 'SQLWriteFileDSN';
function SQLReadFileDSN; external ODBCCP32 name 'SQLReadFileDSN';
function SQLInstallDriverEx; external ODBCCP32 name 'SQLInstallDriverEx';
function SQLInstallTranslatorEx; external ODBCCP32 name 'SQLInstallTranslatorEx';
{$ENDIF} {ODBC_Ver30}

function ConfigDSN; external ODBCCP32 name 'ConfigDSN';

{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
function ConfigDriver; external ODBCCP32 name 'ConfigDriver';
{$ENDIF} {ODBC_Ver25}

{$ENDIF} {SQL_NOUNICODEMAP}

// The following is the original code without the mappings...
// Can delete later if the above satisfies UNICODE mappings.

{
function SQLInstallODBC; external ODBCCP32 name 'SQLInstallODBC';
function SQLInstallODBCW; external ODBCCP32 name 'SQLInstallODBCW';
function SQLManageDataSources; external ODBCCP32 name 'SQLManageDataSources';
function SQLCreateDataSource; external ODBCCP32 name 'SQLCreateDataSource';
function SQLCreateDataSourceW; external ODBCCP32 name 'SQLCreateDataSourceW';
function SQLGetTranslator; external ODBCCP32 name 'SQLGetTranslator';
function SQLGetTranslatorW; external ODBCCP32 name 'SQLGetTranslatorW';
function SQLInstallDriver; external ODBCCP32 name 'SQLInstallDriver';
function SQLInstallDriverW; external ODBCCP32 name 'SQLInstallDriverW';
function SQLInstallDriverManager; external ODBCCP32 name 'SQLInstallDriverManager';
function SQLInstallDriverManagerW; external ODBCCP32 name 'SQLInstallDriverManagerW';
function SQLGetInstalledDrivers; external ODBCCP32 name 'SQLGetInstalledDrivers';
function SQLGetInstalledDriversW; external ODBCCP32 name 'SQLGetInstalledDriversW';
function SQLGetAvailableDrivers; external ODBCCP32 name 'SQLGetAvailableDrivers';
function SQLGetAvailableDriversW; external ODBCCP32 name 'SQLGetAvailableDriversW';
function SQLConfigDataSource; external ODBCCP32 name 'SQLConfigDataSource';
function SQLConfigDataSourceW; external ODBCCP32 name 'SQLConfigDataSourceW';
function SQLRemoveDefaultDataSource; external ODBCCP32 name 'SQLRemoveDefaultDataSource';
function SQLWriteDSNToIni; external ODBCCP32 name 'SQLWriteDSNToIni';
function SQLWriteDSNToIniW; external ODBCCP32 name 'SQLWriteDSNToIniW';
function SQLRemoveDSNFromIni; external ODBCCP32 name 'SQLRemoveDSNFromIni';
function SQLRemoveDSNFromIniW; external ODBCCP32 name 'SQLRemoveDSNFromIniW';
function SQLValidDSN; external ODBCCP32 name 'SQLValidDSN';
function SQLValidDSNW; external ODBCCP32 name 'SQLValidDSNW';
function SQLWritePrivateProfileString;  external ODBCCP32 name 'SQLWritePrivateProfileString';
function SQLWritePrivateProfileStringW; external ODBCCP32 name 'SQLWritePrivateProfileStringW';
function SQLGetPrivateProfileString; external ODBCCP32 name 'SQLGetPrivateProfileString';
function SQLGetPrivateProfileStringW; external ODBCCP32 name 'SQLGetPrivateProfileStringW';
}

//{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
{
function SQLRemoveDriverManager; external ODBCCP32 name 'SQLRemoveDriverManager';
function SQLInstallTranslator; external ODBCCP32 name 'SQLInstallTranslator';
function SQLInstallTranslatorW; external ODBCCP32 name 'SQLInstallTranslatorW';
function SQLRemoveTranslator; external ODBCCP32 name 'SQLRemoveTranslator';
function SQLRemoveTranslatorW; external ODBCCP32 name 'SQLRemoveTranslatorW';
function SQLRemoveDriver; external ODBCCP32 name 'SQLRemoveDriver';
function SQLRemoveDriverW; external ODBCCP32 name 'SQLRemoveDriverW';
function SQLConfigDriver; external ODBCCP32 name 'SQLConfigDriver';
function SQLConfigDriverW; external ODBCCP32 name 'SQLConfigDriverW';
//{$ENDIF} {ODBC_Ver25}

//{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
{
function SQLInstallerError; external ODBCCP32 name 'SQLInstallerError';
function SQLInstallerErrorW; external ODBCCP32 name 'SQLInstallerErrorW';
function SQLPostInstallerError; external ODBCCP32 name 'SQLPostInstallerError';
function SQLPostInstallerErrorW; external ODBCCP32 name 'SQLPostInstallerErrorW';
function SQLWriteFileDSN; external ODBCCP32 name 'SQLWriteFileDSN';
function SQLWriteFileDSNW; external ODBCCP32 name 'SQLWriteFileDSNW';
function SQLReadFileDSN; external ODBCCP32 name 'SQLReadFileDSN';
function SQLReadFileDSNW; external ODBCCP32 name 'SQLReadFileDSNW';
function SQLInstallDriverEx; external ODBCCP32 name 'SQLInstallDriverEx';
function SQLInstallDriverExW; external ODBCCP32 name 'SQLInstallDriverExW';
function SQLInstallTranslatorEx; external ODBCCP32 name 'SQLInstallTranslatorEx';
function SQLInstallTranslatorExW; external ODBCCP32 name 'SQLInstallTranslatorExW';
function SQLGetConfigMode; external ODBCCP32 name 'SQLGetConfigMode';
function SQLSetConfigMode; external ODBCCP32 name 'SQLSetConfigMode';
//{$ENDIF} {ODBC_Ver30}

{
function ConfigDSN; external ODBCCP32 name 'ConfigDSN';
function ConfigDSNW; external ODBCCP32 name 'ConfigDSNW';
function ConfigTranslator; external ODBCCP32 name 'ConfigTranslator';
}

//{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
{
function ConfigDriver; external ODBCCP32 name 'ConfigDriver';
function ConfigDriverW; external ODBCCP32 name 'ConfigDriverW';
//{$ENDIF} {ODBC_Ver25}

end.

