unit Odbcss;

interface

uses
  Windows, SqlTypes;

{ --------------------------------------------------------------- }
{ ODBCSS.PAS - This is the application unit file for the          }
{ SQL Server driver specific defines.                             }
{                                                                 }
{ (C) Copyright 1993-1996 By Microsoft Corp.                      }
{                                                                 }
{ Translated From: ODBCSS.H                                       }
{ Last Modified: 12/05/1997                                       }
{ Revision: 1.0                                                   }
{ --------------------------------------------------------------- }

//      SQLSetConnectOption/SQLSetStmtOption driver specific defines.
//      Microsoft has 1200 thru 1249 reserved for Microsoft SQL Server
//      driver usage.

const
//      Connection Options
  SQL_COPT_SS_BASE                = 1200;
  SQL_REMOTE_PWD                  = (SQL_COPT_SS_BASE+1);   //  dbrpwset SQLSetConnectOption only
  SQL_USE_PROCEDURE_FOR_PREPARE   = (SQL_COPT_SS_BASE+2);   //  Use create proc for SQLPrepare
  SQL_INTEGRATED_SECURITY         = (SQL_COPT_SS_BASE+3);   //  Force integrated security on login
  SQL_PRESERVE_CURSORS            = (SQL_COPT_SS_BASE+4);   //  Preserve server cursors after SQLTransact
  SQL_COPT_SS_USER_DATA           = (SQL_COPT_SS_BASE+5);   //  dbgetuserdata/dbsetuserdata
  SQL_COPT_SS_ANSI_OEM            = (SQL_COPT_SS_BASE+6);   //  dbsetopt/DBANSItoOEM/DBOEMtoANSI
  SQL_COPT_SS_CONNECTION_DEAD     = (SQL_COPT_SS_BASE+9);   //  dbdead SQLGetConnectOption only
  SQL_COPT_SS_FALLBACK_CONNECT    = (SQL_COPT_SS_BASE+10);  //  Enables FallBack connections
  SQL_COPT_SS_PERF_DATA           = (SQL_COPT_SS_BASE+11);  //  Used to access SQL Server ODBC driver performance data
  SQL_COPT_SS_PERF_DATA_LOG       = (SQL_COPT_SS_BASE+12);  //  Used to set the logfile name for the Performance data
  SQL_COPT_SS_PERF_QUERY_INTERVAL = (SQL_COPT_SS_BASE+13);  //  Used to set the query logging threshold in milliseconds.
  SQL_COPT_SS_PERF_QUERY_LOG      = (SQL_COPT_SS_BASE+14);  //  Used to set the logfile name for saving queryies.
  SQL_COPT_SS_PERF_QUERY          = (SQL_COPT_SS_BASE+15);  //  Used to start and stop query logging.
  SQL_COPT_SS_PERF_DATA_LOG_NOW   = (SQL_COPT_SS_BASE+16);  //  Used to make a statistics log entry to disk.
//      The following two options have been added to enable perf data option to be set during browse connect.
  SQL_COPT_SS_PERF_QUERY_AUTO_LOG = (SQL_COPT_SS_BASE+17);  //  Open query log file and start logging all queries.
  SQL_COPT_SS_PERF_DATA_AUTO_LOG  = (SQL_COPT_SS_BASE+18);  //  Open perf stats log file and start logging driver stats.
  SQL_COPT_SS_BCP                 = (SQL_COPT_SS_BASE+19);  //  Allow BCP usage on connection

  SQL_COPT_SS_MAX_USED            = SQL_COPT_SS_BCP;

//      Statement Options
  SQL_SOPT_SS_BASE                = 1225;
  SQL_TEXTPTR_LOGGING             = (SQL_SOPT_SS_BASE+0);  //  Text pointer logging
  SQL_SOPT_SS_CURRENT_COMMAND     = (SQL_SOPT_SS_BASE+1);  //  dbcurcmd SQLGetStmtOption only
  SQL_SOPT_SS_HIDDEN_COLUMNS      = (SQL_SOPT_SS_BASE+2);  //  Expose FOR BROWSE hidden columns
  SQL_SOPT_SS_MAX_USED            = SQL_SOPT_SS_HIDDEN_COLUMNS;


//      Defines for use with SQL_USE_PROCEDURE_FOR_PREPARE
  SQL_UP_OFF      = LongInt(0);  //  Procedures won't be used for prepare
  SQL_UP_ON       = LongInt(1);  //  Procedures will be used for prepare
  SQL_UP_ON_DROP  = LongInt(2);  //  Temp procedures will be explicitly dropped
  SQL_UP_DEFAULT  = SQL_UP_ON;

//      Defines for use with SQL_INTEGRATED_SECURITY - only useable before connecting
  SQL_IS_OFF      = LongInt(0);  //  Integrated security isn't used
  SQL_IS_ON       = LongInt(1);  //  Integrated security is used
  SQL_IS_DEFAULT  = SQL_IS_OFF;

//      Defines for use with SQL_PRESERVE_CURSORS
  SQL_PC_OFF      = LongInt(0);  //  Cursors are closed on SQLTransact
  SQL_PC_ON       = LongInt(1);  //  Cursors remain open on SQLTransact
  SQL_PC_DEFAULT  = SQL_PC_OFF;

//      Defines for use with SQL_COPT_SS_USER_DATA
  SQL_UD_NOTSET   = nil;         //  No user data pointer set

//      Defines for use with SSQL_COPT_SS_ANSI_OEMQL_ANSI_OEM
  SQL_AO_OFF      = LongInt(0);  //  ANSI/OEM translation is not performed
  SQL_AO_ON       = LongInt(1);  //  ANSI/OEM translation is performed
  SQL_AO_DEFAULT  = SQL_AO_OFF;  //  Default unless DSN OEM/ANSI checkbox is checked

//      Defines for use with SQL_COPT_SS_CONNECTION_DEAD
  SQL_CD_TRUE     = LongInt(1);  //  Connection is closed/dead
  SQL_CD_FALSE    = LongInt(0);  //  Connection is open/available

//      Defines for use with SQL_COPT_SS_FALLBACK_CONNECT
  SQL_FB_OFF      = LongInt(0);  //  FallBack connections are disabled
  SQL_FB_ON       = LongInt(1);  //  FallBack connections are enabled
  SQL_FB_DEFAULT  = SQL_FB_OFF;

//      Defines for use with SQL_ENLIST_IN_DTC
  SQL_DTC_DONE    = LongInt(0);  //  Delimits end of DTC transaction

//      Defines for use with SQL_COPT_SS_BCP
  SQL_BCP_OFF     = LongInt(0);  //  BCP is not allowed on connection
  SQL_BCP_ON      = LongInt(1);  //  BCP is allowed on connection
  SQL_BCP_DEFAULT = SQL_BCP_OFF;


//      Defines for use with SQL_TEXTPTR_LOGGING
  SQL_TL_OFF      = LongInt(0);  //  No logging on text pointer ops
  SQL_TL_ON       = LongInt(1);  //  Logging occurs on text pointer ops
  SQL_TL_DEFAULT  = SQL_TL_ON;

//      Defines for use with SQL_SOPT_SS_HIDDEN_COLUMNS
  SQL_HC_OFF      = LongInt(0);  //  FOR BROWSE columns are hidden
  SQL_HC_ON       = LongInt(1);  //  FOR BROWSE columns are exposed
  SQL_HC_DEFAULT  = SQL_HC_OFF;


//      SQLColAttributes driver specific defines.
//      SQLSet/GetDescField driver specific defines.
//      Microsoft has 1200 thru 1249 reserved for Microsoft SQL Server driver usage.

  SQL_CA_SS_BASE           = 1200;
  SQL_CA_SS_COLUMN_SSTYPE  = (SQL_CA_SS_BASE+0);    // dbcoltype/dbaltcoltype
  SQL_CA_SS_COLUMN_UTYPE   = (SQL_CA_SS_BASE+1);    // dbcolutype/dbaltcolutype
  SQL_CA_SS_NUM_ORDERS     = (SQL_CA_SS_BASE+2);    // dbnumorders
  SQL_CA_SS_COLUMN_ORDER   = (SQL_CA_SS_BASE+3);    // dbcolorder
  SQL_CA_SS_COLUMN_VARYLEN = (SQL_CA_SS_BASE+4);    // dbvarylen
  SQL_CA_SS_NUM_COMPUTES   = (SQL_CA_SS_BASE+5);    // dbnumcompute
  SQL_CA_SS_COMPUTE_ID     = (SQL_CA_SS_BASE+6);    // dbnextrow status return
  SQL_CA_SS_COMPUTE_BYLIST = (SQL_CA_SS_BASE+7);    // dbbylist
  SQL_CA_SS_COLUMN_ID      = (SQL_CA_SS_BASE+8);    // dbaltcolid
  SQL_CA_SS_COLUMN_OP      = (SQL_CA_SS_BASE+9);    // dbaltcolop
  SQL_CA_SS_COLUMN_SIZE    = (SQL_CA_SS_BASE+10);   // dbcollen
  SQL_CA_SS_COLUMN_HIDDEN  = (SQL_CA_SS_BASE+11);   // Column is hidden (FOR BROWSE)
  SQL_CA_SS_COLUMN_KEY     = (SQL_CA_SS_BASE+12);   // Column is key column (FOR BROWSE)
  SQL_CA_SS_MAX_USED       = SQL_CA_SS_COLUMN_KEY;

//      SQL Server Data Type Tokens. Returned by SQLColAttributes/SQL_CA_SS_COLUMN_SSTYPE.
  SQLTEXT      = $23;
  SQLVARBINARY = $25;
  SQLINTN      = $26;
  SQLVARCHAR   = $27;
  SQLBINARY    = $2d;
  SQLIMAGE     = $22;
  SQLCHARACTER = $2f;
  SQLINT1      = $30;
  SQLBIT       = $32;
  SQLINT2      = $34;
  SQLINT4      = $38;
  SQLMONEY     = $3c;
  SQLDATETIME  = $3d;
  SQLFLT8      = $3e;
  SQLFLTN      = $6d;
  SQLMONEYN    = $6e;
  SQLDATETIMN  = $6f;
  SQLFLT4      = $3b;
  SQLMONEY4    = $7a;
  SQLDATETIM4  = $3a;
  SQLDECIMAL   = $37;
  SQLDECIMALN  = $6a;
  SQLNUMERIC   = $3f;
  SQLNUMERICN  = $6c;

//      User Data Type definitions. Returned by SQLColAttributes/SQL_CA_SS_COLUMN_UTYPE.
  SQLudtTEXT        = 19;
  SQLudtVARBINARY   = 4;
  SQLudtINTN        = 13;
  SQLudtVARCHAR     = 2;
  SQLudtBINARY      = 3;
  SQLudtIMAGE       = 20;
  SQLudtCHAR        = 1;
  SQLudtINT1        = 5;
  SQLudtBIT         = 16;
  SQLudtINT2        = 6;
  SQLudtINT4        = 7;
  SQLudtMONEY       = 11;
  SQLudtDATETIME    = 12;
  SQLudtFLT8        = 8;
  SQLudtFLTN        = 14;
  SQLudtMONEYN      = 17;
  SQLudtDATETIMN    = 15;
  SQLudtSYSNAME     = 18;
  SQLudtTIMESTAMP   = 80;
  SQLudtFLT4        = 23;
  SQLudtMONEY4      = 21;
  SQLudtDATETIM4    = 22;
  SQLudtDECML       = 24;
  SQLudtDECMLN      = 26;
  SQLudtNUM         = 10;
  SQLudtNUMN        = 25;
  MIN_USER_DATATYPE = 100;

//      aggregate operator types (returned by SQLColAttributes/SQL_CA_SS_COLUMN_OP)
  SQLAOPCNT  = $4b;
  SQLAOPSUM  = $4d;
  SQLAOPAVG  = $4f;
  SQLAOPMIN  = $51;
  SQLAOPMAX  = $52;
  SQLAOPANY  = $53;
  SQLAOPNOOP = $56;


//      SQLGetInfo driver specific defines.
//      Microsoft has 1200 thru 1249 reserved for Microsoft SQL Server driver usage.

  SQL_INFO_SS_FIRST       = 1200;
  SQL_INFO_SS_NETLIB_NAME = (SQL_INFO_SS_FIRST+0);    //  dbprocinfo
  SQL_INFO_SS_MAX_USED    = SQL_INFO_SS_NETLIB_NAME;


//      SQLGetDiagField driver specific defines.
//      Microsoft has -1150 thru -1199 reserved for Microsoft SQL Server driver usage.

  SQL_DIAG_SS_BASE     = (-1150);
  SQL_DIAG_SS_MSGSTATE = (SQL_DIAG_SS_BASE);
  SQL_DIAG_SS_SEVERITY = (SQL_DIAG_SS_BASE-1);
  SQL_DIAG_SS_SRVNAME  = (SQL_DIAG_SS_BASE-2);
  SQL_DIAG_SS_PROCNAME = (SQL_DIAG_SS_BASE-3);
  SQL_DIAG_SS_LINE     = (SQL_DIAG_SS_BASE-4);


//      SQLGetDiagField/SQL_DIAG_DYNAMIC_FUNCTION_CODE driver specific defines.
//      Microsoft has -200 thru -299 reserved for Microsoft SQL Server driver usage.

  SQL_DIAG_DFC_SS_BASE                = (-200);
  SQL_DIAG_DFC_SS_ALTER_DATABASE      = (SQL_DIAG_DFC_SS_BASE-0);
  SQL_DIAG_DFC_SS_CHECKPOINT          = (SQL_DIAG_DFC_SS_BASE-1);
  SQL_DIAG_DFC_SS_CONDITION           = (SQL_DIAG_DFC_SS_BASE-2);
  SQL_DIAG_DFC_SS_CREATE_DATABASE     = (SQL_DIAG_DFC_SS_BASE-3);
  SQL_DIAG_DFC_SS_CREATE_DEFAULT      = (SQL_DIAG_DFC_SS_BASE-4);
  SQL_DIAG_DFC_SS_CREATE_PROCEDURE    = (SQL_DIAG_DFC_SS_BASE-5);
  SQL_DIAG_DFC_SS_CREATE_RULE         = (SQL_DIAG_DFC_SS_BASE-6);
  SQL_DIAG_DFC_SS_CREATE_TRIGGER      = (SQL_DIAG_DFC_SS_BASE-7);
  SQL_DIAG_DFC_SS_CURSOR_DECLARE      = (SQL_DIAG_DFC_SS_BASE-8);
  SQL_DIAG_DFC_SS_CURSOR_OPEN         = (SQL_DIAG_DFC_SS_BASE-9);
  SQL_DIAG_DFC_SS_CURSOR_FETCH        = (SQL_DIAG_DFC_SS_BASE-10);
  SQL_DIAG_DFC_SS_CURSOR_CLOSE        = (SQL_DIAG_DFC_SS_BASE-11);
  SQL_DIAG_DFC_SS_DEALLOCATE_CURSOR   = (SQL_DIAG_DFC_SS_BASE-12);
  SQL_DIAG_DFC_SS_DBCC                = (SQL_DIAG_DFC_SS_BASE-13);
  SQL_DIAG_DFC_SS_DISK                = (SQL_DIAG_DFC_SS_BASE-14);
  SQL_DIAG_DFC_SS_DROP_DATABASE       = (SQL_DIAG_DFC_SS_BASE-15);
  SQL_DIAG_DFC_SS_DROP_DEFAULT        = (SQL_DIAG_DFC_SS_BASE-16);
  SQL_DIAG_DFC_SS_DROP_PROCEDURE      = (SQL_DIAG_DFC_SS_BASE-17);
  SQL_DIAG_DFC_SS_DROP_RULE           = (SQL_DIAG_DFC_SS_BASE-18);
  SQL_DIAG_DFC_SS_DROP_SCHEMA         = (SQL_DIAG_DFC_SS_BASE-19);
  SQL_DIAG_DFC_SS_DROP_TRIGGER        = (SQL_DIAG_DFC_SS_BASE-20);
  SQL_DIAG_DFC_SS_DUMP_DATABASE       = (SQL_DIAG_DFC_SS_BASE-21);
  SQL_DIAG_DFC_SS_DUMP_TABLE          = (SQL_DIAG_DFC_SS_BASE-22);
  SQL_DIAG_DFC_SS_DUMP_TRANSACTION    = (SQL_DIAG_DFC_SS_BASE-23);
  SQL_DIAG_DFC_SS_GOTO                = (SQL_DIAG_DFC_SS_BASE-24);
  SQL_DIAG_DFC_SS_INSERT_BULK         = (SQL_DIAG_DFC_SS_BASE-25);
  SQL_DIAG_DFC_SS_KILL                = (SQL_DIAG_DFC_SS_BASE-26);
  SQL_DIAG_DFC_SS_LOAD_DATABASE       = (SQL_DIAG_DFC_SS_BASE-27);
  SQL_DIAG_DFC_SS_LOAD_HEADERONLY     = (SQL_DIAG_DFC_SS_BASE-28);
  SQL_DIAG_DFC_SS_LOAD_TABLE          = (SQL_DIAG_DFC_SS_BASE-29);
  SQL_DIAG_DFC_SS_LOAD_TRANSACTION    = (SQL_DIAG_DFC_SS_BASE-30);
  SQL_DIAG_DFC_SS_PRINT               = (SQL_DIAG_DFC_SS_BASE-31);
  SQL_DIAG_DFC_SS_RAISERROR           = (SQL_DIAG_DFC_SS_BASE-32);
  SQL_DIAG_DFC_SS_READTEXT            = (SQL_DIAG_DFC_SS_BASE-33);
  SQL_DIAG_DFC_SS_RECONFIGURE         = (SQL_DIAG_DFC_SS_BASE-34);
  SQL_DIAG_DFC_SS_RETURN              = (SQL_DIAG_DFC_SS_BASE-35);
  SQL_DIAG_DFC_SS_SELECT_INTO         = (SQL_DIAG_DFC_SS_BASE-36);
  SQL_DIAG_DFC_SS_SET                 = (SQL_DIAG_DFC_SS_BASE-37);
  SQL_DIAG_DFC_SS_SET_IDENTITY_INSERT = (SQL_DIAG_DFC_SS_BASE-38);
  SQL_DIAG_DFC_SS_SET_ROW_COUNT       = (SQL_DIAG_DFC_SS_BASE-39);
  SQL_DIAG_DFC_SS_SET_STATISTICS      = (SQL_DIAG_DFC_SS_BASE-40);
  SQL_DIAG_DFC_SS_SET_TEXTSIZE        = (SQL_DIAG_DFC_SS_BASE-41);
  SQL_DIAG_DFC_SS_SETUSER             = (SQL_DIAG_DFC_SS_BASE-42);
  SQL_DIAG_DFC_SS_SHUTDOWN            = (SQL_DIAG_DFC_SS_BASE-43);
  SQL_DIAG_DFC_SS_TRANS_BEGIN         = (SQL_DIAG_DFC_SS_BASE-44);
  SQL_DIAG_DFC_SS_TRANS_COMMIT        = (SQL_DIAG_DFC_SS_BASE-45);
  SQL_DIAG_DFC_SS_TRANS_PREPARE       = (SQL_DIAG_DFC_SS_BASE-46);
  SQL_DIAG_DFC_SS_TRANS_ROLLBACK      = (SQL_DIAG_DFC_SS_BASE-47);
  SQL_DIAG_DFC_SS_TRANS_SAVE          = (SQL_DIAG_DFC_SS_BASE-48);
  SQL_DIAG_DFC_SS_TRUNCATE_TABLE      = (SQL_DIAG_DFC_SS_BASE-49);
  SQL_DIAG_DFC_SS_UPDATE_STATISTICS   = (SQL_DIAG_DFC_SS_BASE-50);
  SQL_DIAG_DFC_SS_UPDATETEXT          = (SQL_DIAG_DFC_SS_BASE-51);
  SQL_DIAG_DFC_SS_USE                 = (SQL_DIAG_DFC_SS_BASE-52);
  SQL_DIAG_DFC_SS_WAITFOR             = (SQL_DIAG_DFC_SS_BASE-53);
  SQL_DIAG_DFC_SS_WRITETEXT           = (SQL_DIAG_DFC_SS_BASE-54);

//      Internal server datatypes - used when binding to SQL_C_BINARY
{$IFNDEF MAXNUMERICLEN}	 //  Resolve ODS/DBLib conflicts
//      DB-Library datatypes
const
  DBMAXCHAR = 256;  //  Max length of DBVARBINARY and DBVARCHAR, etc.
  MAXNAME   = 31;

type
  DBCHAR = Char;
  DBBINARY = UCHAR;
  DBTINYINT = UCHAR;
  DBSMALLINT = SHORT;
  DBUSMALLINT = Word;
  DBINT = LongInt;
  DBFLT8 = Double;
  DBBIT = UCHAR;
  DBBOOL = UCHAR;
  DBFLT4 = Single;

  DBREAL = DBFLT4;
  DBUBOOL = UINT;

  TDbVaryChar = record
    len: DBSMALLINT;
    str: array[0..DBMAXCHAR-1] of DBCHAR;
  end;

  TDbVaryBin = record
    len: DBSMALLINT;
    array_: array[0..DBMAXCHAR-1] of BYTE;
  end;

  TDbMoney = record
  //  Internal representation of MONEY data type
    mnyhigh: LONG;  //  Money value *10,000 (High 32 bits/signed)
    mnylow: ULONG;  //  Money value *10,000 (Low 32 bits/unsigned)
  end;

  TDbDateTime = record
  //  Internal representation of DATETIME data type
   dtdays: LONG;   //  No. of days since Jan-1-1900 (maybe negative)
   dttime: ULONG;  //  No. of 300 hundredths of a second since midnight
  end;

  TDbDateTime4 = record
  //  Internal representation of SMALLDATETIME data type
   numdays: USHORT;  //  No. of days since Jan-1-1900
   nummins: USHORT;  //  No. of minutes since midnight
  end;

  DBMONEY4 = LONG;   // Internal representation of SMALLMONEY data type
                     // Money value *10,000

  DBNUM_PREC_TYPE  = BYTE;
  DBNUM_SCALE_TYPE = BYTE;
  DBNUM_VAL_TYPE   = BYTE;

  LPBYTE  = PBYTE;
  LPCBYTE = LPBYTE;
  LPDBINT = ^DBINT;

{$IFNDEF ODBC_Ver30}  { Below ODBC Version 3.0 }
const
  MAXNUMERICLEN = 16;

type
  TDbNumeric = record
  //  Internal representation of NUMERIC data type
    precision: DBNUM_PREC_TYPE;   //  Precision
    scale:     DBNUM_SCALE_TYPE;  //  Scale
    sign:      BYTE;              //  Sign (1 if positive, 0 if negative)
    val: array[0..MAXNUMERICLEN-1] of DBNUM_VAL_TYPE;  //  Value
  end;

  TDbDecimal = TDbNumeric;  //  Internal representation of DECIMAL data type
{$ELSE}   //   Use ODBC 3.0 definitions since same as DBLib
const
  SQL_MAX_NUMERIC_LEN = MAXNUMERICLEN;

type
  TDbNumeric = SQL_NUMERIC_STRUCT;
  TDbDecimal = SQL_NUMERIC_STRUCT;
{$ENDIF} {Below ODBC_Ver30}

{$ENDIF} {MAXNUMERICLEN}

{ ********************************************************* }
{ This struct is a global used for                          }
{ gathering statistal data on the driver.                   }
{ Access to this struct is controled via the                }
{ pStatCrit;                                                }
{ ********************************************************* }

type
  PSqlPerf = ^TSqlPerf;
  TSqlPerf = record
    // Application Profile Statistics
    TimerResolution:   DWORD;
    SQLidu:            DWORD;
    SQLiduRows:        DWORD;
    SQLSelects:        DWORD;
    SQLSelectRows:     DWORD;
    Transactions:      DWORD;
    SQLPrepares:       DWORD;
    ExecDirects:       DWORD;
    SQLExecutes:       DWORD;
    CursorOpens:       DWORD;
    CursorSize:        DWORD;
    CursorUsed:        DWORD;
    PercentCursorUsed: LDOUBLE;
    AvgFetchTime:      LDOUBLE;
    AvgCursorSize:     LDOUBLE;
    AvgCursorUsed:     LDOUBLE;
    SQLFetchTime:      DWORD;
    SQLFetchCount:     DWORD;
    CurrentStmtCount:  DWORD;
    MaxOpenStmt:       DWORD;
    SumOpenStmt:       DWORD;
	
    // Connection Statistics
    CurrentConnectionCount: DWORD;
    MaxConnectionsOpened:   DWORD;
    SumConnectionsOpened:   DWORD;
    SumConnectiontime:      DWORD;
    AvgTimeOpened:          LDOUBLE;

    // Network Statistics
    ServerRndTrips: DWORD;
    BuffersSent:    DWORD;
    BuffersRec:     DWORD;
    BytesSent:      DWORD;
    BytesRec:       DWORD;

    // Time Statistics;
    msExecutionTime:     DWORD;
    msNetWorkServerTime: DWORD;
  end;


const
//      The following are option for SQL_COPT_SS_PERF_DATA and SQL_COPT_SS_PERF_QUERY
  SQL_PERF_START = 1;  //  Starts the driver sampling performance data.
  SQL_PERF_STOP  = 2;  //  Stops the counters from sampling performance data.


//      ODBC BCP prototypes and defines

  SUCCEED = 1;
  FAIL    = 0;

  DB_IN   = 1;  //  Transfer from client to server
  DB_OUT  = 2;  //  Transfer from server to client

  BCPMAXERRS   = 1;  //  bcp_control parameter
  BCPFIRST     = 2;  //  bcp_control parameter
  BCPLAST      = 3;  //  bcp_control parameter
  BCPBATCH     = 4;  //  bcp_control parameter
  BCPKEEPNULLS = 5;  //  bcp_control parameter
  BCPABORT     = 6;  //  bcp_control parameter

//      BCP functions
function bcp_batch(
              dbproc: HDBC
         ):DBINT; stdcall;

function bcp_bind(
              dbproc: HDBC;
              varaddr: LPCBYTE;
              prefixlen: INT;
              varlen: DBINT;
              terminator: LPCBYTE;
              termlen,
              typ,
              table_column:INT
         ):RETCODE; stdcall;

function bcp_colfmt(
              dbproc: HDBC;
              file_column: INT;
              file_type: BYTE;
              file_prefixlen: INT;
              file_collen: DBINT;
              file_term: LPCBYTE;
              file_termlen,
              table_column: INT
         ):RETCODE; stdcall;

function bcp_collen(
              dbproc: HDBC;
              varlen: DBINT;
              table_column: INT
         ):RETCODE; stdcall;

function bcp_colptr(
              dbproc: HDBC;
              colptr: LPCBYTE;
              table_column: INT
         ):RETCODE; stdcall;

function bcp_columns(
              dbproc: HDBC;
              file_colcount: INT
         ):RETCODE; stdcall;

function bcp_control(
              dbproc: HDBC;
              field: INT;
              value: DBINT
         ):RETCODE; stdcall;

function bcp_done(
              dbproc: HDBC
         ):DBINT; stdcall;

function bcp_exec(
              dbproc: HDBC;
              rows_copied: LPDBINT
         ):RETCODE; stdcall;

function bcp_init(
              dbproc: HDBC;
              tblname,
              hfile,
              errfile: LPCSTR;
              direction: INT
         ):RETCODE; stdcall;

function bcp_moretext(
              dbproc: HDBC;
              size: DBINT;
              text: LPCBYTE
         ):RETCODE; stdcall;

function bcp_readfmt(
              dbproc: HDBC;
              filename: LPCSTR
         ):RETCODE; stdcall;

function bcp_sendrow(
              dbproc: HDBC
         ):RETCODE; stdcall;

function bcp_writefmt(
              dbproc: HDBC;
              filename: LPCSTR
         ):RETCODE; stdcall;

// CHAR FAR *   SQL_API dbprtype (INT);
function dbprtype(
              token: INT
         ):PChar; stdcall;


const

//      The following options have been deprecated

  SQL_FAST_CONNECT = (SQL_COPT_SS_BASE+0);
//	Defines for use with SQL_FAST_CONNECT - only useable before connecting
  SQL_FC_OFF       = LongInt(0);  //  Fast connect is off
  SQL_FC_ON        = LongInt(1);  //  Fast connect is on
  SQL_FC_DEFAULT   = SQL_FC_OFF;

//      Use SQL_ATTR_ENLIST_IN_DTC and SQL_ATTR_ENLIST_IN_XA (ODBC 3.0 definitions)
  SQL_COPT_SS_ENLIST_IN_DTC = (SQL_COPT_SS_BASE+7);  //  Enlist in a DTC transaction
  SQL_COPT_SS_ENLIST_IN_XA  = (SQL_COPT_SS_BASE+8);  //  Enlist in a XA transaction

const
  NTWDBLIB = 'ntwdblib.dll';

implementation

function bcp_batch;    external NTWDBLIB name 'bcp_batch';
function bcp_bind;     external NTWDBLIB name 'bcp_bind';
function bcp_colfmt;   external NTWDBLIB name 'bcp_colfmt';
function bcp_collen;   external NTWDBLIB name 'bcp_collen';
function bcp_colptr;   external NTWDBLIB name 'bcp_colptr';
function bcp_columns;  external NTWDBLIB name 'bcp_columns';
function bcp_control;  external NTWDBLIB name 'bcp_control';
function bcp_done;     external NTWDBLIB name 'bcp_done';
function bcp_exec;     external NTWDBLIB name 'bcp_exec';
function bcp_init;     external NTWDBLIB name 'bcp_init';
function bcp_moretext; external NTWDBLIB name 'bcp_moretext';
function bcp_readfmt;  external NTWDBLIB name 'bcp_readfmt';
function bcp_sendrow;  external NTWDBLIB name 'bcp_sendrow';
function bcp_writefmt; external NTWDBLIB name 'bcp_writefmt';
function dbprtype;     external NTWDBLIB name 'dbprtype';

end.

