unit Sql;

interface

uses Windows, SqlTypes;

{ --------------------------------------------------------------- }
{ SQL.PAS - This is the the main include for ODBC Core functions. }
{                                                                 }
{ preconditions:                                                  }
{      uses windows                                               }
{                                                                 }
{ (C) Copyright 1990 - 1996 By Microsoft Corp.                    }
{                                                                 }
{      Updated 5/12/93 for 2.00 specification                     }
{      Updated 5/23/94 for 2.01 specification                     }
{      Updated 11/10/94 for 2.10 specification                    }
{      Updated 04/10/95 for 2.50 specification                    }
{      Updated 6/6/95  for 3.00 specification                     }
{                                                                 }
{ Translated From: Sql.h                                          }
{ Last Modified: 12/19/1997                                       }
{ Version: 1.0                                                    }
{ --------------------------------------------------------------- }

{  Default to ODBC Version 3.0 if no version is specified       }
{  To exclude definitions introduced in version 3.0 (or above)  }
{  use the compiler directive ODBC_Ver25 before this line.      }
{$IFNDEF ODBC_BaseVer} {and} {$IFNDEF ODBC_Ver10} {and} {$IFNDEF ODBC_Ver20}
      {and} {$IFNDEF ODBC_Ver25} {and} {$IFNDEF ODBC_Ver30} {then}
  {$DEFINE ODBC_Ver30}
{$ENDIF} {$ENDIF} {$ENDIF} {$ENDIF} {$ENDIF}


const

{ special length/indicator values }
  SQL_NULL_DATA         = -1;
  SQL_DATA_AT_EXEC      = -2;


{ return values from functions }
  SQL_SUCCESS           = 0;
  SQL_SUCCESS_WITH_INFO = 1;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_NO_DATA           = 100;
{$ENDIF} {ODBC_Ver30}
  SQL_ERROR             = -1;
  SQL_INVALID_HANDLE    = -2;

  SQL_STILL_EXECUTING   = 2;
  SQL_NEED_DATA         = 99;

{ test for SQL_SUCCESS or SQL_SUCCESS_WITH_INFO }
  function SQL_SUCCEEDED(rc: RETCODE): Boolean;

const

{ flags for null-terminated string }
  SQL_NTS               = -3;
  SQL_NTSL              = LongInt(-3);

{ maximum message length }
  SQL_MAX_MESSAGE_LENGTH = 512;

{ date/time length constants }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_DATE_LEN          = 10;
  SQL_TIME_LEN          =  8;  { add P+1 if precision is nonzero }
  SQL_TIMESTAMP_LEN     = 19;  { add P+1 if precision is nonzero }
{$ENDIF} {ODBC_Ver30}

{ handle type identifiers }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_HANDLE_ENV        = 1;
  SQL_HANDLE_DBC        = 2;
  SQL_HANDLE_STMT       = 3;
  SQL_HANDLE_DESC       = 4;
{$ENDIF} {ODBC_Ver30}

{ environment attribute }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_ATTR_OUTPUT_NTS   = 10001;
{$ENDIF} {ODBC_Ver30}

{ connection attributes }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_ATTR_AUTO_IPD     = 10001;
  SQL_ATTR_METADATA_ID  = 10014;
{$ENDIF} {ODBC_Ver30}

{ statement attributes }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_ATTR_APP_ROW_DESC       = 10010;
  SQL_ATTR_APP_PARAM_DESC     = 10011;
  SQL_ATTR_IMP_ROW_DESC       = 10012;
  SQL_ATTR_IMP_PARAM_DESC     = 10013;
  SQL_ATTR_CURSOR_SCROLLABLE  = -1;
  SQL_ATTR_CURSOR_SENSITIVITY = -2;
{$ENDIF} {ODBC_Ver30}

{ SQL_ATTR_CURSOR_SCROLLABLE values }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_NONSCROLLABLE           = 0;
  SQL_SCROLLABLE              = 1;
{$ENDIF} {ODBC_Ver30}

{ identifiers of fields in the SQL descriptor }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_DESC_COUNT                 = 1001;
  SQL_DESC_TYPE                  = 1002;
  SQL_DESC_LENGTH                = 1003;
  SQL_DESC_OCTET_LENGTH_PTR      = 1004;
  SQL_DESC_PRECISION             = 1005;
  SQL_DESC_SCALE                 = 1006;
  SQL_DESC_DATETIME_INTERVAL_CODE= 1007;
  SQL_DESC_NULLABLE              = 1008;
  SQL_DESC_INDICATOR_PTR         = 1009;
  SQL_DESC_DATA_PTR              = 1010;
  SQL_DESC_NAME                  = 1011;
  SQL_DESC_UNNAMED               = 1012;
  SQL_DESC_OCTET_LENGTH          = 1013;
  SQL_DESC_ALLOC_TYPE            = 1099;
{$ENDIF} {ODBC_Ver30}

{ identifiers of fields in the diagnostics area }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_DIAG_RETURNCODE            =  1;
  SQL_DIAG_NUMBER                =  2;
  SQL_DIAG_ROW_COUNT             =  3;
  SQL_DIAG_SQLSTATE              =  4;
  SQL_DIAG_NATIVE                =  5;
  SQL_DIAG_MESSAGE_TEXT          =  6;
  SQL_DIAG_DYNAMIC_FUNCTION      =  7;
  SQL_DIAG_CLASS_ORIGIN          =  8;
  SQL_DIAG_SUBCLASS_ORIGIN       =  9;
  SQL_DIAG_CONNECTION_NAME       = 10;
  SQL_DIAG_SERVER_NAME           = 11;
  SQL_DIAG_DYNAMIC_FUNCTION_CODE = 12;
{$ENDIF} {ODBC_Ver30}

{ dynamic function codes }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_DIAG_ALTER_TABLE           =  4;
  SQL_DIAG_CREATE_INDEX          = -1;
  SQL_DIAG_CREATE_TABLE          = 77;
  SQL_DIAG_CREATE_VIEW           = 84;
  SQL_DIAG_DELETE_WHERE          = 19;
  SQL_DIAG_DROP_INDEX            = -2;
  SQL_DIAG_DROP_TABLE            = 32;
  SQL_DIAG_DROP_VIEW             = 36;
  SQL_DIAG_DYNAMIC_DELETE_CURSOR = 38;
  SQL_DIAG_DYNAMIC_UPDATE_CURSOR = 81;
  SQL_DIAG_GRANT                 = 48;
  SQL_DIAG_INSERT                = 50;
  SQL_DIAG_REVOKE                = 59;
  SQL_DIAG_SELECT_CURSOR         = 85;
  SQL_DIAG_UNKNOWN_STATEMENT     =  0;
  SQL_DIAG_UPDATE_WHERE          = 82;
{$ENDIF} {ODBC_Ver30}

{ SQL data type codes }
  SQL_UNKNOWN_TYPE      = 0;
  SQL_CHAR              = 1;
  SQL_NUMERIC           = 2;
  SQL_DECIMAL           = 3;
  SQL_INTEGER           = 4;
  SQL_SMALLINT          = 5;
  SQL_FLOAT             = 6;
  SQL_REAL              = 7;
  SQL_DOUBLE            = 8;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_DATETIME          = 9;
{$ENDIF} {ODBC_Ver30}
  SQL_VARCHAR           = 12;

{ One-parameter shortcuts for date/time data types }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_TYPE_DATE         = 91;
  SQL_TYPE_TIME         = 92;
  SQL_TYPE_TIMESTAMP    = 93;
{$ENDIF} {ODBC_Ver30}

{ Statement attribute values for cursor sensitivity }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_UNSPECIFIED       = 0;
  SQL_INSENSITIVE       = 1;
  SQL_SENSITIVE         = 2;
{$ENDIF} {ODBC_Ver30}

{ GetTypeInfo() request for all data types }
  SQL_ALL_TYPES         = 0;

{ Default conversion code for SQLBindCol(), SQLBindParam() and SQLGetData() }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_DEFAULT           = 99;
{$ENDIF} {ODBC_Ver30}

{ SQLGetData() code indicating that the application row descriptor
 * specifies the data type
 }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_ARD_TYPE          = -99;
{$ENDIF} {ODBC_Ver30}

{ SQL date/time type subcodes }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_CODE_DATE         = 1;
  SQL_CODE_TIME         = 2;
  SQL_CODE_TIMESTAMP    = 3;
{$ENDIF} {ODBC_Ver30}

{ CLI option values }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_FALSE             = 0;
  SQL_TRUE              = 1;
{$ENDIF} {ODBC_Ver30}

{ values of NULLABLE field in descriptor }
  SQL_NO_NULLS          = 0;
  SQL_NULLABLE          = 1;

{ Value returned by SQLGetTypeInfo() to denote that it is    }
{ not known whether or not a data type supports null values. }
  SQL_NULLABLE_UNKNOWN  = 2;

{ Values returned by SQLGetTypeInfo() to show WHERE clause supported }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_PRED_NONE         = 0;
  SQL_PRED_CHAR         = 1;
  SQL_PRED_BASIC        = 2;
{$ENDIF} {ODBC_Ver30}

{ values of UNNAMED field in descriptor }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_NAMED             = 0;
  SQL_UNNAMED           = 1;
{$ENDIF} {ODBC_Ver30}

{ values of ALLOC_TYPE field in descriptor }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_DESC_ALLOC_AUTO   = 1;
  SQL_DESC_ALLOC_USER   = 2;
{$ENDIF} {ODBC_Ver30}

{ FreeStmt() options }
  SQL_CLOSE             = 0;
  SQL_DROP              = 1;
  SQL_UNBIND            = 2;
  SQL_RESET_PARAMS      = 3;

{ Codes used for FetchOrientation in SQLFetchScroll(), }
{   and in SQLDataSources()                            }
  SQL_FETCH_NEXT        = 1;
  SQL_FETCH_FIRST       = 2;

{ Other codes used for FetchOrientation in SQLFetchScroll() }
  SQL_FETCH_LAST        = 3;
  SQL_FETCH_PRIOR       = 4;
  SQL_FETCH_ABSOLUTE    = 5;
  SQL_FETCH_RELATIVE    = 6;

{ SQLEndTran() options }
  SQL_COMMIT            = 0;
  SQL_ROLLBACK          = 1;

{ null handles returned by SQLAllocHandle() }
  SQL_NULL_HENV         = 0;
  SQL_NULL_HDBC         = 0;
  SQL_NULL_HSTMT        = 0;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_NULL_HDESC        = 0;
{$ENDIF} {ODBC_Ver30}

{ null handle used in place of parent handle when allocating HENV }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_NULL_HANDLE       = LongInt(0);
{$ENDIF} {ODBC_Ver30}

{ Values that may appear in the result set of SQLSpecialColumns() }
  SQL_SCOPE_CURROW      = 0;
  SQL_SCOPE_TRANSACTION = 1;
  SQL_SCOPE_SESSION     = 2;

  SQL_PC_UNKNOWN        = 0;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_PC_NON_PSEUDO     = 1;
{$ENDIF} {ODBC_Ver30}
  SQL_PC_PSEUDO         = 2;

{ Reserved value for the IdentifierType argument of SQLSpecialColumns() }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_ROW_IDENTIFIER    = 1;
{$ENDIF} {ODBC_Ver30}

{ Reserved values for UNIQUE argument of SQLStatistics() }
  SQL_INDEX_UNIQUE      = 0;
  SQL_INDEX_ALL         = 1;

{ Values that may appear in the result set of SQLStatistics() }
  SQL_INDEX_CLUSTERED   = 1;
  SQL_INDEX_HASHED      = 2;
  SQL_INDEX_OTHER       = 3;

{ SQLGetFunctions() values to identify ODBC APIs }
  SQL_API_SQLALLOCCONNECT     = 1;
  SQL_API_SQLALLOCENV         = 2;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_API_SQLALLOCHANDLE      = 1001;
{$ENDIF} {ODBC_Ver30}
  SQL_API_SQLALLOCSTMT        = 3;
  SQL_API_SQLBINDCOL          = 4;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_API_SQLBINDPARAM        = 1002;
{$ENDIF} {ODBC_Ver30}
  SQL_API_SQLCANCEL           = 5;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_API_SQLCLOSECURSOR      = 1003;
  SQL_API_SQLCOLATTRIBUTE     = 6;
{$ENDIF} {ODBC_Ver30}
  SQL_API_SQLCOLUMNS          = 40;
  SQL_API_SQLCONNECT          = 7;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_API_SQLCOPYDESC         = 1004;
{$ENDIF} {ODBC_Ver30}
  SQL_API_SQLDATASOURCES      = 57;
  SQL_API_SQLDESCRIBECOL      = 8;
  SQL_API_SQLDISCONNECT       = 9;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_API_SQLENDTRAN          = 1005;
{$ENDIF} {ODBC_Ver30}
  SQL_API_SQLERROR            = 10;
  SQL_API_SQLEXECDIRECT       = 11;
  SQL_API_SQLEXECUTE          = 12;
  SQL_API_SQLFETCH            = 13;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_API_SQLFETCHSCROLL      = 1021;
{$ENDIF} {ODBC_Ver30}
  SQL_API_SQLFREECONNECT      = 14;
  SQL_API_SQLFREEENV          = 15;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_API_SQLFREEHANDLE       = 1006;
{$ENDIF} {ODBC_Ver30}
  SQL_API_SQLFREESTMT         = 16;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_API_SQLGETCONNECTATTR   = 1007;
{$ENDIF} {ODBC_Ver30}
  SQL_API_SQLGETCONNECTOPTION = 42;
  SQL_API_SQLGETCURSORNAME    = 17;
  SQL_API_SQLGETDATA          = 43;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_API_SQLGETDESCFIELD     = 1008;
  SQL_API_SQLGETDESCREC       = 1009;
  SQL_API_SQLGETDIAGFIELD     = 1010;
  SQL_API_SQLGETDIAGREC       = 1011;
  SQL_API_SQLGETENVATTR       = 1012;
{$ENDIF} {ODBC_Ver30}
  SQL_API_SQLGETFUNCTIONS     = 44;
  SQL_API_SQLGETINFO          = 45;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_API_SQLGETSTMTATTR      = 1014;
{$ENDIF} {ODBC_Ver30}
  SQL_API_SQLGETSTMTOPTION    = 46;
  SQL_API_SQLGETTYPEINFO      = 47;
  SQL_API_SQLNUMRESULTCOLS    = 18;
  SQL_API_SQLPARAMDATA        = 48;
  SQL_API_SQLPREPARE          = 19;
  SQL_API_SQLPUTDATA          = 49;
  SQL_API_SQLROWCOUNT         = 20;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_API_SQLSETCONNECTATTR   = 1016;
{$ENDIF} {ODBC_Ver30}
  SQL_API_SQLSETCONNECTOPTION = 50;
  SQL_API_SQLSETCURSORNAME    = 21;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_API_SQLSETDESCFIELD     = 1017;
  SQL_API_SQLSETDESCREC       = 1018;
  SQL_API_SQLSETENVATTR       = 1019;
{$ENDIF} {ODBC_Ver30}
  SQL_API_SQLSETPARAM         = 22;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_API_SQLSETSTMTATTR      = 1020;
{$ENDIF} {ODBC_Ver30}
  SQL_API_SQLSETSTMTOPTION    = 51;
  SQL_API_SQLSPECIALCOLUMNS   = 52;
  SQL_API_SQLSTATISTICS       = 53;
  SQL_API_SQLTABLES           = 54;
  SQL_API_SQLTRANSACT         = 23;

{ Information requested by SQLGetInfo() }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_MAX_DRIVER_CONNECTIONS         = 0;
  SQL_MAXIMUM_DRIVER_CONNECTIONS     = SQL_MAX_DRIVER_CONNECTIONS;
  SQL_MAX_CONCURRENT_ACTIVITIES      = 1;
  SQL_MAXIMUM_CONCURRENT_ACTIVITIES  = SQL_MAX_CONCURRENT_ACTIVITIES;
{$ENDIF} {ODBC_Ver30}
  SQL_DATA_SOURCE_NAME               =  2;
  SQL_FETCH_DIRECTION                =  8;
  SQL_SERVER_NAME                    = 13;
  SQL_SEARCH_PATTERN_ESCAPE          = 14;
  SQL_DBMS_NAME                      = 17;
  SQL_DBMS_VER                       = 18;
  SQL_ACCESSIBLE_TABLES              = 19;
  SQL_ACCESSIBLE_PROCEDURES          = 20;
  SQL_CURSOR_COMMIT_BEHAVIOR         = 23;
  SQL_DATA_SOURCE_READ_ONLY          = 25;
  SQL_DEFAULT_TXN_ISOLATION          = 26;
  SQL_IDENTIFIER_CASE                = 28;
  SQL_IDENTIFIER_QUOTE_CHAR          = 29;
  SQL_MAX_COLUMN_NAME_LEN            = 30;
  SQL_MAXIMUM_COLUMN_NAME_LENGTH     = SQL_MAX_COLUMN_NAME_LEN;
  SQL_MAX_CURSOR_NAME_LEN            = 31;
  SQL_MAXIMUM_CURSOR_NAME_LENGTH     = SQL_MAX_CURSOR_NAME_LEN;
  SQL_MAX_SCHEMA_NAME_LEN            = 32;
  SQL_MAXIMUM_SCHEMA_NAME_LENGTH     = SQL_MAX_SCHEMA_NAME_LEN;
  SQL_MAX_CATALOG_NAME_LEN           = 34;
  SQL_MAXIMUM_CATALOG_NAME_LENGTH    = SQL_MAX_CATALOG_NAME_LEN;
  SQL_MAX_TABLE_NAME_LEN             = 35;
  SQL_SCROLL_CONCURRENCY             = 43;
  SQL_TXN_CAPABLE                    = 46;
  SQL_TRANSACTION_CAPABLE            = SQL_TXN_CAPABLE;
  SQL_USER_NAME                      = 47;
  SQL_TXN_ISOLATION_OPTION           = 72;
  SQL_TRANSACTION_ISOLATION_OPTION   = SQL_TXN_ISOLATION_OPTION;
  SQL_INTEGRITY                      = 73;
  SQL_GETDATA_EXTENSIONS             = 81;
  SQL_NULL_COLLATION                 = 85;
  SQL_ALTER_TABLE                    = 86;
  SQL_ORDER_BY_COLUMNS_IN_SELECT     = 90;
  SQL_SPECIAL_CHARACTERS             = 94;
  SQL_MAX_COLUMNS_IN_GROUP_BY        = 97;
  SQL_MAXIMUM_COLUMNS_IN_GROUP_BY    = SQL_MAX_COLUMNS_IN_GROUP_BY;
  SQL_MAX_COLUMNS_IN_INDEX           = 98;
  SQL_MAXIMUM_COLUMNS_IN_INDEX       = SQL_MAX_COLUMNS_IN_INDEX;
  SQL_MAX_COLUMNS_IN_ORDER_BY        = 99;
  SQL_MAXIMUM_COLUMNS_IN_ORDER_BY    = SQL_MAX_COLUMNS_IN_ORDER_BY;
  SQL_MAX_COLUMNS_IN_SELECT          = 100;
  SQL_MAXIMUM_COLUMNS_IN_SELECT      = SQL_MAX_COLUMNS_IN_SELECT;
  SQL_MAX_COLUMNS_IN_TABLE           = 101;
  SQL_MAX_INDEX_SIZE                 = 102;
  SQL_MAXIMUM_INDEX_SIZE             = SQL_MAX_INDEX_SIZE;
  SQL_MAX_ROW_SIZE                   = 104;
  SQL_MAXIMUM_ROW_SIZE               = SQL_MAX_ROW_SIZE;
  SQL_MAX_STATEMENT_LEN              = 105;
  SQL_MAXIMUM_STATEMENT_LENGTH       = SQL_MAX_STATEMENT_LEN;
  SQL_MAX_TABLES_IN_SELECT           = 106;
  SQL_MAXIMUM_TABLES_IN_SELECT       = SQL_MAX_TABLES_IN_SELECT;
  SQL_MAX_USER_NAME_LEN              = 107;
  SQL_MAXIMUM_USER_NAME_LENGTH       = SQL_MAX_USER_NAME_LEN;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_OJ_CAPABILITIES                = 115;
  SQL_OUTER_JOIN_CAPABILITIES        = SQL_OJ_CAPABILITIES;
{$ENDIF} {ODBC_Ver30}

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_XOPEN_CLI_YEAR                 = 10000;
  SQL_CURSOR_SENSITIVITY             = 10001;
  SQL_DESCRIBE_PARAMETER             = 10002;
  SQL_CATALOG_NAME                   = 10003;
  SQL_COLLATION_SEQ                  = 10004;
  SQL_MAX_IDENTIFIER_LEN             = 10005;
  SQL_MAXIMUM_IDENTIFIER_LENGTH      = SQL_MAX_IDENTIFIER_LEN;
{$ENDIF} {ODBC_Ver30}

{ SQL_ALTER_TABLE bitmasks }
{$IFDEF ODBC_Ver20}  { ODBC Version 2.0 and above }
  SQL_AT_ADD_COLUMN                  = $00000001;
  SQL_AT_DROP_COLUMN                 = $00000002;
{$ENDIF} {ODBC_Ver20}

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_AT_ADD_CONSTRAINT              = $00000008;

{ The following bitmasks are ODBC extensions and defined in SqlExt.pas
* SQL_AT_COLUMN_SINGLE                  = $00000020;
* SQL_AT_ADD_COLUMN_DEFAULT             = $00000040;
* SQL_AT_ADD_COLUMN_COLLATION           = $00000080;
* SQL_AT_SET_COLUMN_DEFAULT             = $00000100;
* SQL_AT_DROP_COLUMN_DEFAULT            = $00000200;
* SQL_AT_DROP_COLUMN_CASCADE            = $00000400;
* SQL_AT_DROP_COLUMN_RESTRICT           = $00000800;
* SQL_AT_ADD_TABLE_CONSTRAINT           = $00001000;
* SQL_AT_DROP_TABLE_CONSTRAINT_CASCADE  = $00002000;
* SQL_AT_DROP_TABLE_CONSTRAINT_RESTRICT = $00004000;
* SQL_AT_CONSTRAINT_NAME_DEFINITION     = $00008000;
* SQL_AT_CONSTRAINT_INITIALLY_DEFERRED  = $00010000;
* SQL_AT_CONSTRAINT_INITIALLY_IMMEDIATE = $00020000;
* SQL_AT_CONSTRAINT_DEFERRABLE          = $00040000;
* SQL_AT_CONSTRAINT_NON_DEFERRABLE      = $00080000;
}
{$ENDIF} {ODBC_Ver30}


{ SQL_ASYNC_MODE values }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_AM_NONE                        = 0;
  SQL_AM_CONNECTION                  = 1;
  SQL_AM_STATEMENT                   = 2;
{$ENDIF} {ODBC_Ver30}

{ SQL_CURSOR_COMMIT_BEHAVIOR values }
  SQL_CB_DELETE                      = 0;
  SQL_CB_CLOSE                       = 1;
  SQL_CB_PRESERVE                    = 2;

{ SQL_FETCH_DIRECTION bitmasks }
  SQL_FD_FETCH_NEXT                  = $00000001;
  SQL_FD_FETCH_FIRST                 = $00000002;
  SQL_FD_FETCH_LAST                  = $00000004;
  SQL_FD_FETCH_PRIOR                 = $00000008;
  SQL_FD_FETCH_ABSOLUTE              = $00000010;
  SQL_FD_FETCH_RELATIVE              = $00000020;

{ SQL_GETDATA_EXTENSIONS bitmasks }
  SQL_GD_ANY_COLUMN                  = $00000001;
  SQL_GD_ANY_ORDER                   = $00000002;

{ SQL_IDENTIFIER_CASE values }
  SQL_IC_UPPER                       = 1;
  SQL_IC_LOWER                       = 2;
  SQL_IC_SENSITIVE                   = 3;
  SQL_IC_MIXED                       = 4;

{ SQL_OJ_CAPABILITIES bitmasks }
{$IFDEF ODBC_Ver25}  { Above ODBC Version 2.0 }
  SQL_OJ_RIGHT                       = $00000002;
  SQL_OJ_FULL                        = $00000004;
  SQL_OJ_NESTED                      = $00000008;
  SQL_OJ_NOT_ORDERED                 = $00000010;
  SQL_OJ_INNER                       = $00000020;
  SQL_OJ_ALL_COMPARISON_OPS          = $00000040;
{$ENDIF} {Above ODBC_Ver20}

{ SQL_SCROLL_CONCURRENCY bitmasks }
  SQL_SCCO_READ_ONLY                 = $00000001;
  SQL_SCCO_LOCK                      = $00000002;
  SQL_SCCO_OPT_ROWVER                = $00000004;
  SQL_SCCO_OPT_VALUES                = $00000008;

{ SQL_TXN_CAPABLE values }
  SQL_TC_NONE                        = 0;
  SQL_TC_DML                         = 1;
  SQL_TC_ALL                         = 2;
  SQL_TC_DDL_COMMIT                  = 3;
  SQL_TC_DDL_IGNORE                  = 4;

{ SQL_TXN_ISOLATION_OPTION bitmasks }
  SQL_TXN_READ_UNCOMMITTED           = $00000001;
  SQL_TRANSACTION_READ_UNCOMMITTED   = SQL_TXN_READ_UNCOMMITTED;
  SQL_TXN_READ_COMMITTED             = $00000002;
  SQL_TRANSACTION_READ_COMMITTED     = SQL_TXN_READ_COMMITTED;
  SQL_TXN_REPEATABLE_READ            = $00000004;
  SQL_TRANSACTION_REPEATABLE_READ    = SQL_TXN_REPEATABLE_READ;
  SQL_TXN_SERIALIZABLE               = $00000008;
  SQL_TRANSACTION_SERIALIZABLE       = SQL_TXN_SERIALIZABLE;

{ SQL_NULL_COLLATION values }
  SQL_NC_HIGH                        = 0;
  SQL_NC_LOW                         = 1;


function SQLAllocConnect(EnvironmentHandle: SQLHENV;
            ConnectionHandle: PSQLHDBC
         ): SQLRETURN; stdcall;

function SQLAllocEnv(EnvironmentHandle: SQLHENV
         ): SQLRETURN; stdcall;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLAllocHandle(HandleType: SQLSMALLINT;
            InputHandle: SQLHANDLE; OutputHandle: PSQLHANDLE
         ): SQLRETURN; stdcall;
{$ENDIF} {ODBC_Ver30}

function SQLAllocStmt(ConnectionHandle: SQLHDBC;
            StatementHandle: PSQLHSTMT
         ): SQLRETURN; stdcall;

function SQLBindCol(StatementHandle: SQLHSTMT;
            ColumnNumber: SQLUSMALLINT; TargetType: SQLSMALLINT;
            TargetValue: SQLPOINTER; BufferLength: SQLINTEGER;
            StrLen_or_Ind: PSQLINTEGER
         ): SQLRETURN; stdcall;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLBindParam(StatementHandle: SQLHSTMT;
            ParameterNumber: SQLUSMALLINT; ValueType,
            ParameterType: SQLSMALLINT; LengthPrecision: SQLUINTEGER;
            ParameterScale: SQLSMALLINT; ParameterValue: SQLPOINTER;
            StrLen_or_Ind: PSQLINTEGER
         ): SQLRETURN; stdcall;
{$ENDIF} {ODBC_Ver30}

function SQLCancel(StatementHandle: SQLHSTMT
         ): SQLRETURN; stdcall;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLCloseCursor(StatementHandle: SQLHSTMT
         ): SQLRETURN; stdcall;

function SQLColAttribute(StatementHandle: SQLHSTMT;
            ColumnNumber, FieldIdentifier: SQLUSMALLINT;
            CharacterAttribute: SQLPOINTER; BufferLength: SQLSMALLINT;
            StringLength: PSQLSMALLINT; NumericAttribute: SQLPOINTER
         ): SQLRETURN; stdcall;
{$ENDIF} {ODBC_Ver30}


function SQLColumns(StatementHandle: SQLHSTMT;
            CatalogName: PSQLCHAR; NameLength1: SQLSMALLINT;
            SchemaName: PSQLCHAR; NameLength2: SQLSMALLINT;
            TableName: PSQLCHAR; NameLength3: SQLSMALLINT;
            ColumnName: PSQLCHAR; NameLength4: SQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLConnect(ConnectionHandle: SQLHDBC;
            ServerName: PSQLCHAR; NameLength1: SQLSMALLINT;
            UserName: PSQLCHAR; NameLength2: SQLSMALLINT;
            Authentication: PSQLCHAR; NameLength3: SQLSMALLINT
         ): SQLRETURN; stdcall;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLCopyDesc(SourceDescHandle: SQLHDESC;
            TargetDescHandle: SQLHDESC
         ): SQLRETURN; stdcall;
{$ENDIF} {ODBC_Ver30}

function SQLDataSources(EnvironmentHandle: SQLHENV;
            //Direction: SQLUSMALLINT; ServerName: PSQLCHAR;
            Direction: SQLUSMALLINT; var ServerName: SQLCHAR;
            BufferLength1: SQLSMALLINT; NameLength1: PSQLSMALLINT;
            var Description: SQLCHAR; BufferLength2: SQLSMALLINT;
            NameLength2: PSQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLDescribeCol(StatementHandle: SQLHSTMT;
            ColumnNumber: SQLUSMALLINT; ColumnName: PSQLCHAR;
            BufferLength: SQLSMALLINT; NameLength,
            DataType: PSQLSMALLINT; ColumnSize: PSQLUINTEGER;
            DecimalDigits, Nullable: PSQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLDisconnect(ConnectionHandle: SQLHDBC
         ): SQLRETURN; stdcall;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLEndTran(HandleType: SQLSMALLINT; Handle: SQLHANDLE;
            CompletionType: SQLSMALLINT
         ): SQLRETURN; stdcall;
{$ENDIF} {ODBC_Ver30}

function SQLError(EnvironmentHandle: SQLHENV;
            ConnectionHandle: SQLHDBC; StatementHandle: SQLHSTMT;
            Sqlstate: PSQLCHAR; NativeError: PSQLINTEGER;
            MessageText: PSQLCHAR; BufferLength: SQLSMALLINT;
            TextLength: PSQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLExecDirect(StatementHandle: SQLHSTMT;
            StatementText: PSQLCHAR; TextLength: SQLINTEGER
         ): SQLRETURN; stdcall;

function SQLExecute(StatementHandle: SQLHSTMT
         ): SQLRETURN; stdcall;

function SQLFetch(StatementHandle: SQLHSTMT
         ): SQLRETURN; stdcall;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLFetchScroll(StatementHandle: SQLHSTMT;
            FetchOrientation: SQLSMALLINT; FetchOffset: SQLINTEGER
         ): SQLRETURN; stdcall;
{$ENDIF} {ODBC_Ver30}

function SQLFreeConnect(ConnectionHandle: SQLHDBC
         ): SQLRETURN; stdcall;

function SQLFreeEnv(EnvironmentHandle: SQLHENV
         ): SQLRETURN; stdcall;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLFreeHandle(HandleType: SQLSMALLINT; Handle: SQLHANDLE
         ): SQLRETURN; stdcall;
{$ENDIF} {ODBC_Ver30}

function SQLFreeStmt(StatementHandle: SQLHSTMT;
            Option: SQLUSMALLINT
         ): SQLRETURN; stdcall;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLGetConnectAttr(ConnectionHandle: SQLHDBC;
           Attribute: SQLINTEGER; Value: SQLPOINTER;
           BufferLength: SQLINTEGER; StringLength: PSQLINTEGER
         ): SQLRETURN; stdcall;
{$ENDIF} {ODBC_Ver30}

function SQLGetConnectOption(ConnectionHandle: SQLHDBC;
            Option: SQLUSMALLINT; Value: SQLPOINTER
         ): SQLRETURN; stdcall;

function SQLGetCursorName(StatementHandle: SQLHSTMT;
            CursorName: PSQLCHAR; BufferLength: SQLSMALLINT;
            NameLength: PSQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLGetData(StatementHandle: SQLHSTMT;
           ColumnNumber: SQLUSMALLINT; TargetType: SQLSMALLINT;
           TargetValue: SQLPOINTER; BufferLength: SQLINTEGER;
           StrLen_or_Ind: PSQLINTEGER
         ): SQLRETURN; stdcall;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLGetDescField(DescriptorHandle: SQLHDESC;
            RecNumber, FieldIdentifier: SQLSMALLINT;
            Value: SQLPOINTER; BufferLength: SQLINTEGER;
            StringLength: PSQLINTEGER
         ): SQLRETURN; stdcall;

function SQLGetDescRec(DescriptorHandle: SQLHDESC;
            RecNumber: SQLSMALLINT; Name: PSQLCHAR;
            BufferLength: SQLSMALLINT; StringLength,
            Type_, SubType: PSQLSMALLINT;
            Length: PSQLINTEGER; Precision,
            Scale, Nullable: PSQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLGetDiagField(HandleType: SQLSMALLINT; Handle: SQLHANDLE;
            RecNumber, DiagIdentifier: SQLSMALLINT;
            DiagInfo: SQLPOINTER; BufferLength: SQLSMALLINT;
            StringLength: SQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLGetDiagRec(HandleType: SQLSMALLINT; Handle: SQLHANDLE;
            RecNumber: SQLSMALLINT; Sqlstate: PSQLCHAR;
            NativeError: PSQLINTEGER; MessageText: PSQLCHAR;
            BufferLength: SQLSMALLINT; TextLength: PSQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLGetEnvAttr(EnvironmentHandle: SQLHENV;
            Attribute: SQLINTEGER; Value: SQLPOINTER;
            BufferLength: SQLINTEGER; StringLength: PSQLINTEGER
         ): SQLRETURN; stdcall;
{$ENDIF} {ODBC_Ver30}

function SQLGetFunctions(ConnectionHandle: SQLHDBC;
            FunctionId: SQLUSMALLINT; Supported: PSQLUSMALLINT
         ): SQLRETURN; stdcall;

function SQLGetInfo(ConnectionHandle: SQLHDBC;
            InfoType: SQLUSMALLINT; InfoValue: SQLPOINTER;
            BufferLength: SQLSMALLINT; StringLength: PSQLSMALLINT
         ): SQLRETURN; stdcall;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLGetStmtAttr(StatementHandle: SQLHSTMT;
            Attribute: SQLINTEGER; Value: SQLPOINTER;
            BufferLength: SQLINTEGER; StringLength: PSQLINTEGER
         ): SQLRETURN; stdcall;
{$ENDIF} {ODBC_Ver30}

function SQLGetStmtOption(StatementHandle: SQLHSTMT;
            Option: SQLUSMALLINT; Value: SQLPOINTER
         ): SQLRETURN; stdcall;

function SQLGetTypeInfo(StatementHandle: SQLHSTMT;
            DataType: SQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLNumResultCols(StatementHandle: SQLHSTMT;
            ColumnCount: PSQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLParamData(StatementHandle: SQLHSTMT;
            Value: PSQLPOINTER
         ): SQLRETURN; stdcall;

function SQLPrepare(StatementHandle: SQLHSTMT;
            StatementText: PSQLCHAR; TextLength: SQLINTEGER
         ): SQLRETURN; stdcall;

function SQLPutData(StatementHandle: SQLHSTMT;
            Data: SQLPOINTER; StrLen_or_Ind: SQLINTEGER
         ): SQLRETURN; stdcall;

function SQLRowCount(StatementHandle: SQLHSTMT;
	    RowCount: PSQLINTEGER
         ): SQLRETURN; stdcall;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLSetConnectAttr(ConnectionHandle: SQLHDBC;
            Attribute: SQLINTEGER; Value: SQLPOINTER;
            StringLength: SQLINTEGER
         ): SQLRETURN; stdcall;
{$ENDIF} {ODBC_Ver30}

function SQLSetConnectOption(ConnectionHandle: SQLHDBC;
            Option: SQLUSMALLINT; Value: SQLUINTEGER
         ): SQLRETURN; stdcall;

function SQLSetCursorName(StatementHandle: SQLHSTMT;
            CursorName: PSQLCHAR; NameLength: SQLSMALLINT
         ): SQLRETURN; stdcall;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLSetDescField(DescriptorHandle: SQLHDESC;
            RecNumber: SQLSMALLINT; FieldIdentifier: SQLSMALLINT;
            Value: SQLPOINTER; BufferLength: SQLINTEGER
         ): SQLRETURN; stdcall;

function SQLSetDescRec(DescriptorHandle: SQLHDESC;
            RecNumber, Type_,
            SubType: SQLSMALLINT; Length: SQLINTEGER;
            Precision, Scale: SQLSMALLINT;
            Data: SQLPOINTER; StringLength,
            Indicator: PSQLINTEGER
         ): SQLRETURN; stdcall;

function SQLSetEnvAttr(EnvironmentHandle: SQLHENV;
            Attribute: SQLINTEGER; Value: SQLPOINTER;
            StringLength: SQLINTEGER
         ): SQLRETURN; stdcall;
{$ENDIF} {ODBC_Ver30}

function SQLSetParam(StatementHandle: SQLHSTMT;
            ParameterNumber: SQLUSMALLINT; ValueType,
            ParameterType: SQLSMALLINT; LengthPrecision: SQLUINTEGER;
            ParameterScale: SQLSMALLINT; ParameterValue: SQLPOINTER;
            StrLen_or_Ind: PSQLINTEGER
         ): SQLRETURN; stdcall;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLSetStmtAttr(StatementHandle: SQLHSTMT;
            Attribute: SQLINTEGER; Value: SQLPOINTER;
            StringLength: SQLINTEGER
         ): SQLRETURN; stdcall;
{$ENDIF} {ODBC_Ver30}

function SQLSetStmtOption(StatementHandle: SQLHSTMT;
            Option: SQLUSMALLINT; Value: SQLUINTEGER
         ): SQLRETURN; stdcall;

function SQLSpecialColumns(StatementHandle: SQLHSTMT;
            IdentifierType: SQLUSMALLINT; CatalogName: PSQLCHAR;
            NameLength1: SQLSMALLINT; SchemaName: PSQLCHAR;
            NameLength2: SQLSMALLINT; TableName: PSQLCHAR;
            NameLength3: SQLSMALLINT; Scope,
            Nullable: SQLUSMALLINT
         ): SQLRETURN; stdcall;

function SQLStatistics(StatementHandle: SQLHSTMT;
            CatalogName: PSQLCHAR; NameLength1: SQLSMALLINT;
            SchemaName: PSQLCHAR; NameLength2: SQLSMALLINT;
            TableName: PSQLCHAR; NameLength3: SQLSMALLINT;
            Unique, Reserved: SQLUSMALLINT
         ): SQLRETURN; stdcall;

function SQLTables(StatementHandle: SQLHSTMT;
            CatalogName: PSQLCHAR; NameLength1: SQLSMALLINT;
            SchemaName: PSQLCHAR; NameLength2: SQLSMALLINT;
            TableName: PSQLCHAR; NameLength3: SQLSMALLINT;
            TableType: PSQLCHAR; NameLength4: SQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLTransact(EnvironmentHandle: SQLHENV;
            ConnectionHandle: SQLHDBC; CompletionType: SQLUSMALLINT
         ): SQLRETURN; stdcall;


const
  ODSGT32 = 'odsgt32.dll';
  ODBC32  = 'odbc32.dll';

implementation

function SQLAllocConnect;     external ODSGT32 name 'SQLAllocConnect';
function SQLAllocEnv;         external ODSGT32 name 'SQLAllocEnv';
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLAllocHandle;      external ODBC32  name 'SQLAllocHandle';
{$ENDIF} {ODBC_Ver30}
function SQLAllocStmt;        external ODSGT32 name 'SQLAllocStmt';
function SQLBindCol;          external ODSGT32 name 'SQLBindCol';
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLBindParam;        external ODSGT32 name 'SQLBindParam';
{$ENDIF} {ODBC_Ver30}
function SQLCancel;           external ODSGT32 name 'SQLCancel';
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLCloseCursor;      external ODBC32  name 'SQLCloseCursor';
function SQLColAttribute;     external ODBC32  name 'SQLColAttribute';
{$ENDIF} {ODBC_Ver30}
function SQLColumns;          external ODSGT32 name 'SQLColumns';
function SQLConnect;          external ODSGT32 name 'SQLConnect';
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLCopyDesc;         external ODBC32  name 'SQLCopyDesc';
{$ENDIF} {ODBC_Ver30}
function SQLDataSources;      external ODBC32  name 'SQLDataSources';
function SQLDescribeCol;      external ODSGT32 name 'SQLDescribeCol';
function SQLDisconnect;       external ODSGT32 name 'SQLDisconnect';
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLEndTran;          external ODBC32  name 'SQLEndTran';
{$ENDIF} {ODBC_Ver30}
function SQLError;            external ODSGT32 name 'SQLError';
function SQLExecDirect;       external ODSGT32 name 'SQLExecDirect';
function SQLExecute;          external ODSGT32 name 'SQLExecute';
function SQLFetch;            external ODSGT32 name 'SQLFetch';
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLFetchScroll;      external ODBC32  name 'SQLFetchScroll';
{$ENDIF} {ODBC_Ver30}
function SQLFreeConnect;      external ODSGT32 name 'SQLFreeConnect';
function SQLFreeEnv;          external ODSGT32 name 'SQLFreeEnv';
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLFreeHandle;       external ODBC32  name 'SQLFreeHandle';
{$ENDIF} {ODBC_Ver30}
function SQLFreeStmt;         external ODSGT32 name 'SQLFreeStmt';
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLGetConnectAttr;   external ODBC32  name 'SQLGetConnectAttr';
{$ENDIF} {ODBC_Ver30}
function SQLGetConnectOption; external ODSGT32 name 'SQLGetConnectOption';
function SQLGetCursorName;    external ODSGT32 name 'SQLGetCursorName';
function SQLGetData;          external ODSGT32 name 'SQLGetData';
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLGetDescField;     external ODBC32  name 'SQLGetDescField';
function SQLGetDescRec;       external ODBC32  name 'SQLGetDescRec';
function SQLGetDiagField;     external ODBC32  name 'SQLGetDiagField';
function SQLGetDiagRec;       external ODBC32  name 'SQLGetDiagRec';
function SQLGetEnvAttr;       external ODBC32  name 'SQLGetEnvAttr';
{$ENDIF} {ODBC_Ver30}
function SQLGetFunctions;     external ODSGT32 name 'SQLGetFunctions';
function SQLGetInfo;          external ODSGT32 name 'SQLGetInfo';
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLGetStmtAttr;      external ODBC32  name 'SQLGetStmtAttr';
{$ENDIF} {ODBC_Ver30}
function SQLGetStmtOption;    external ODSGT32 name 'SQLGetStmtOption';
function SQLGetTypeInfo;      external ODSGT32 name 'SQLGetTypeInfo';
function SQLNumResultCols;    external ODSGT32 name 'SQLNumResultCols';
function SQLParamData;        external ODSGT32 name 'SQLParamData';
function SQLPrepare;          external ODSGT32 name 'SQLPrepare';
function SQLPutData;          external ODSGT32 name 'SQLPutData';
function SQLRowCount;         external ODSGT32 name 'SQLRowCount';
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLSetConnectAttr;   external ODBC32  name 'SQLSetConnectAttr';
{$ENDIF} {ODBC_Ver30}
function SQLSetConnectOption; external ODSGT32 name 'SQLSetConnectOption';
function SQLSetCursorName;    external ODSGT32 name 'SQLSetCursorName';
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLSetDescField;     external ODBC32  name 'SQLSetDescField';
function SQLSetDescRec;       external ODBC32  name 'SQLSetDescRec';
function SQLSetEnvAttr;       external ODBC32  name 'SQLSetEnvAttr';
{$ENDIF} {ODBC_Ver30}
function SQLSetParam;         external ODBC32  name 'SQLSetParam';
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLSetStmtAttr;      external ODBC32  name 'SQLSetStmtAttr';
{$ENDIF} {ODBC_Ver30}
function SQLSetStmtOption;    external ODSGT32 name 'SQLSetStmtOption';
function SQLSpecialColumns;   external ODSGT32 name 'SQLSpecialColumns';
function SQLStatistics;       external ODSGT32 name 'SQLStatistics';
function SQLTables;           external ODSGT32 name 'SQLTables';
function SQLTransact;         external ODSGT32 name 'SQLTransact';

////  SQL_SUCCEEDED(rc) (((rc)&(~1))==0);
function SQL_SUCCEEDED(rc: RETCODE): Boolean;
begin
  result := (rc and (not 1)) = 0;
end;

end.

