unit SqlDb;

interface

uses
{$IFDEF WIN32}
  Windows,
{$ELSE}
  WinTypes, WinProcs,
{$ENDIF}
  SqlTypes, SqlFront;

{ ------------------------------------------------------------------ }
{  SQLDB.PAS - DB-Library header file for the Microsoft SQL Server.  }
{                                                                    }
{  Copyright (c) 1989 - 1995 by Microsoft Corp. All rights reserved. }
{                                                                    }
{ Translated From: SQLDB.H                                           }
{ Last Modified: 12/19/1997                                          }
{ Version: 1.0                                                       }
{ ------------------------------------------------------------------ }


{ Macros for setting the PLOGINREC }

function DBSETLHOST(loginrec: PLOGINREC; workstation: LPCSTR): RETCODE;
function DBSETLUSER(loginrec: PLOGINREC; username: LPCSTR): RETCODE;
function DBSETLPWD(loginrec: PLOGINREC; password: LPCSTR): RETCODE;
function DBSETLAPP(loginrec: PLOGINREC; app: LPCSTR): RETCODE;
function DBSETLNATLANG(loginrec: PLOGINREC; language: LPCSTR): RETCODE;
{ This was only here to support case-sentivity and  }
{ to keep it grouped with the other like functions. }
{ function DBSETLPACKET(login: PLOGINREC; packet_size: USHORT): RETCODE; }
function DBSETLSECURE(ptrloginrec: PLOGINREC): RETCODE;
function DBSETLVERSION(ptrloginrec: PLOGINREC; version: BYTE): RETCODE;
function DBSETLTIME(ptrloginrec: PLOGINREC; seconds: DWORD): RETCODE;
function DBSETLFALLBACK(loginrec: PLOGINREC; fallback: LPCSTR): RETCODE;


{ ------------------------------------------------------------------ }
{     Windows 3.x and Non-Windows 3.x differences.                   }
{ ------------------------------------------------------------------ }

{$IFDEF WIN32}
type
  TDbErrHandleProc = function(
                        dbproc: PDBPROCESS;
                        severity,
                        dberr,
                        oserr: INT;
                        dberrstr,
                        oserrstr: LPCSTR
                     ): INT; cdecl;

  TDbMsgHandleProc = function(
                        dbproc: PDBPROCESS;
                        msgno: DBINT;
                        msgstate,
                        severity: DBINT;
                        msgtext,
                        srvname,
                        procname: LPCSTR;
                        line: DBUSMALLINT
                     ): INT; cdecl;

function dberrhandle(handler: TDbErrHandleProc): TDbErrHandleProc; cdecl;
function dbmsghandle(handler: TDbMsgHandleProc): TDbMsgHandleProc; cdecl;

function dbprocerrhandle(ptrdbhandle: PDBHANDLE; error_handler: TDbErrHandleProc): TDbErrHandleProc; cdecl;
function dbprocmsghandle(ptrdbhandle: PDBHANDLE; message_handler: TDbMsgHandleProc): TDbMsgHandleProc; cdecl;


{$ELSE}

procedure dbwinexit;   cdecl; far;  { cdecl far }

procedure dblocklib;   cdecl; far;  { cdecl far }
procedure dbunlocklib; cdecl; far;  { cdecl far }

  TDbErrHandleProc = TFarProc;
  TDbMsgHandleProc = TFarProc;

  function dberrhandle(handler: TDbErrHandleProc): TDbErrHandleProc; far;
  function dbmsghandle(handler: TDbMsgHandleProc): TDbMsgHandleProc; far;

{$ENDIF}


{ ------------------------------------------------------------------ }
{     Function Prototypes                                            }
{ ------------------------------------------------------------------ }

{ Function macros }
function dbrbuf(dbproc: PDBPROCESS): DBINT;

{ Two-phase commit functions }
function abort_xact(connect: PDBPROCESS; commid: DBINT): RETCODE; cdecl;
procedure build_xact_string(xact_name, service_name: LPCSTR; commid: DBINT; result: LPSTR); cdecl;
procedure close_commit(connect: PDBPROCESS); cdecl;
function commit_xact(connect: PDBPROCESS; commid: DBINT): RETCODE; cdecl;
function open_commit(login: PLOGINREC; servername: LPCSTR): PDBPROCESS; cdecl;
function remove_xact(connect: PDBPROCESS; commid: DBINT; n: INT): RETCODE; cdecl;
function scan_xact(connect: PDBPROCESS; commid: DBINT): RETCODE; cdecl;
function start_xact(connect: PDBPROCESS; application_name, xact_name: LPCSTR; site_count: INT): DBINT; cdecl;
function stat_xact(connect: PDBPROCESS; commid: DBINT): INT; cdecl;

{ BCP functions }
function bcp_batch(dbproc: PDBPROCESS): DBINT; cdecl;
function bcp_bind(dbproc: PDBPROCESS; varaddr: LPCBYTE; prefixlen: INT; varlen: DBINT; terminator: LPCBYTE; termlen, typ, table_column: INT): RETCODE; cdecl;
function bcp_colfmt(dbproc: PDBPROCESS; file_column: INT; file_type: BYTE; file_prefixlen: INT; file_collen: DBINT; file_term: LPCBYTE; file_termlen, table_column: INT): RETCODE; cdecl;
function bcp_collen(dbproc: PDBPROCESS; varlen: DBINT; table_column: INT): RETCODE; cdecl;
function bcp_colptr(dbproc: PDBPROCESS; colptr: LPCBYTE; table_column: INT): RETCODE; cdecl;
function bcp_columns(dbproc: PDBPROCESS; file_colcount: INT): RETCODE; cdecl;
function bcp_control(dbproc: PDBPROCESS; field: INT; value: DBINT): RETCODE; cdecl;
function bcp_done(dbproc: PDBPROCESS): DBINT; cdecl;
function bcp_exec(dbproc: PDBPROCESS; rows_copied: LPDBINT): RETCODE; cdecl;
function bcp_init(dbproc: PDBPROCESS; tblname, hfile, errfile: LPCSTR; direction: INT): RETCODE; cdecl;
function bcp_moretext(dbproc: PDBPROCESS; size: DBINT; text: LPCBYTE): RETCODE; cdecl;
function bcp_readfmt(dbproc: PDBPROCESS; filename: LPCSTR): RETCODE; cdecl;
function bcp_sendrow(dbproc: PDBPROCESS): RETCODE; cdecl;
function bcp_setl(loginrec: PLOGINREC; enable: BOOL): RETCODE; cdecl;
function bcp_writefmt(dbproc: PDBPROCESS; filename: LPCSTR): RETCODE; cdecl;

{ Standard DB-Library functions }
function dbadata(dbproc: PDBPROCESS; computeid, column: INT): LPCBYTE; cdecl;
function dbadlen(dbproc: PDBPROCESS; computeid, column: INT): DBINT; cdecl;
function dbaltbind(dbproc: PDBPROCESS; computeid, column: INT; vartype: INT; varlen: DBINT; varaddr: LPCBYTE): RETCODE; cdecl;
function dbaltcolid(dbproc: PDBPROCESS; computeid, column: INT): INT; cdecl;
function dbaltlen(dbproc: PDBPROCESS; computeid, column: INT): DBINT; cdecl;
function dbaltop(dbproc: PDBPROCESS; computeid, column: INT): INT; cdecl;
function dbalttype(dbproc: PDBPROCESS; computeid, column: INT): INT; cdecl;
function dbaltutype(dbproc: PDBPROCESS; computeid, column: INT): DBINT; cdecl;
function dbanullbind(dbproc: PDBPROCESS; computeid, column: INT; indicator: LPCDBINT): RETCODE; cdecl;
function dbbind(dbproc: PDBPROCESS; column, vartype: INT; varlen: DBINT; varaddr: LPBYTE): RETCODE; cdecl;
function dbbylist(dbproc: PDBPROCESS; computeid: INT; size: LPINT): LPCBYTE; cdecl;
function dbcancel(dbproc: PDBPROCESS): RETCODE; cdecl;
function dbcanquery(dbproc: PDBPROCESS): RETCODE; cdecl;
function dbchange(dbproc: PDBPROCESS): LPCSTR; cdecl;
function dbclose(dbproc: PDBPROCESS): RETCODE; cdecl;
procedure dbclrbuf(dbproc: PDBPROCESS; n: DBINT); cdecl;
function dbclropt(dbproc: PDBPROCESS; option: INT; param: LPCSTR): RETCODE; cdecl;
function dbcmd(dbproc: PDBPROCESS; cmdstring: LPCSTR): RETCODE; cdecl;
function dbcmdrow(dbproc: PDBPROCESS): RETCODE; cdecl;
function dbcolbrowse(dbproc: PDBPROCESS; colnum: INT): BOOL; cdecl;
function dbcolinfo(handle: PDBHANDLE; typ: INT; column, computeid: DBINT; lpdbcolumn: LPDBCOL): RETCODE; cdecl;
function dbcollen(dbproc: PDBPROCESS; column: INT): DBINT; cdecl;
function dbcolname(dbproc: PDBPROCESS; column: INT): LPCSTR; cdecl;
function dbcolsource(dbproc: PDBPROCESS; column: INT): LPCSTR; cdecl;
function dbcoltype(dbproc: PDBPROCESS; column: INT): INT; cdecl;
function dbcolutype(dbproc: PDBPROCESS; column: INT): DBINT; cdecl;
function dbconvert(dbproc: PDBPROCESS; srctype: INT; src: LPCBYTE; srclen: DBINT; desttype: INT; dest: LPBYTE; destlen: DBINT): INT; cdecl;
function dbcount(dbproc: PDBPROCESS): DBINT; cdecl;
function dbcurcmd(dbproc: PDBPROCESS): INT; cdecl;
function dbcurrow(dbproc: PDBPROCESS): DBINT; cdecl;
function dbcursor(hc: PDBCURSOR; optype, row: INT; table, values: LPCSTR): RETCODE; cdecl;
function dbcursorbind(hc: PDBCURSOR; col, vartype: INT; varlen: DBINT; poutlen: LPDBINT; pvaraddr: LPBYTE): RETCODE; cdecl;
function dbcursorclose(handle: PDBHANDLE): RETCODE; cdecl;
function dbcursorcolinfo(hcursor: PDBCURSOR; column: INT; colname: LPSTR; coltype: LPINT; collen: LPDBINT; usertype: LPINT): RETCODE; cdecl;
function dbcursorfetch(hcursor: PDBCURSOR; fetchtype, rownum: INT): RETCODE; cdecl;
function dbcursorfetchex(hcursor: PDBCURSOR; fetchtype: INT; rownum, nfetchrows, reserved: DBINT): RETCODE; cdecl;
function dbcursorinfo(hcursor: PDBCURSOR; ncols: LPINT; nrows: LPDBINT): RETCODE; cdecl;
function dbcursorinfoex(hcursor: PDBCURSOR; pdbcursorinfo: LPDBCURSORINFO): RETCODE; cdecl;
function dbcursoropen(dbproc: PDBPROCESS; stmt: LPCSTR; scrollopt, concuropt: INT; nrows: UINT; pstatus: LPDBINT): PDBCURSOR; cdecl;
function dbdata(dbproc: PDBPROCESS; column: INT): LPCBYTE; cdecl;
function dbdataready(dbproc: PDBPROCESS): BOOL; cdecl;
function dbdatecrack(dbproc: PDBPROCESS; dateinfo: LPDBDATEREC; datetime: LPCDBDATETIME): RETCODE; cdecl;
function dbdatlen(dbproc: PDBPROCESS; column: INT): DBINT; cdecl;
function dbdead(dbproc: PDBPROCESS): BOOL; cdecl;
procedure dbexit; cdecl;
//* function dbenlisttrans(dbproc: PDBPROCESS; Pointer): RETCODE; cdecl;
//* function dbenlistxatrans(dbproc: PDBPROCESS; BOOL): RETCODE; cdecl;
//* function dbfcmd(dbproc: PDBPROCESS; cmdstring: LPCSTR; ... : params): RETCODE; cdecl;
function dbfirstrow(dbproc: PDBPROCESS): DBINT; cdecl;
procedure dbfreebuf(dbproc: PDBPROCESS); cdecl;
procedure dbfreelogin(login: PLOGINREC); cdecl;
procedure dbfreequal(ptr_: LPCSTR); cdecl;
function dbgetchar(dbproc: PDBPROCESS; n: INT): LPSTR; cdecl;
function dbgetmaxprocs: SHORT; cdecl;
function dbgetoff(dbproc: PDBPROCESS; offtype: DBUSMALLINT; startfrom: INT): INT; cdecl;
function dbgetpacket(dbproc: PDBPROCESS): UINT; cdecl;
function dbgetrow(dbproc: PDBPROCESS; row: DBINT): STATUS; cdecl;
function dbgettime: INT; cdecl;
function dbgetuserdata(dbproc: PDBPROCESS): Pointer; cdecl;
function dbhasretstat(dbproc: PDBPROCESS): BOOL; cdecl;
function dbinit: LPCSTR; cdecl;
function dbisavail(dbproc: PDBPROCESS): BOOL; cdecl;
function dbiscount(dbproc: PDBPROCESS): BOOL; cdecl;
function dbisopt(dbproc: PDBPROCESS; option: INT; param: LPCSTR): BOOL; cdecl;
function dblastrow(dbproc: PDBPROCESS): DBINT; cdecl;
function dblogin: PLOGINREC; cdecl;
function dbmorecmds(dbproc: PDBPROCESS): RETCODE; cdecl;
function dbmoretext(dbproc: PDBPROCESS; size: DBINT; text: LPCBYTE): RETCODE; cdecl;
function dbname(dbproc: PDBPROCESS): LPCSTR; cdecl;
function dbnextrow(dbproc: PDBPROCESS): STATUS; cdecl;
function dbnullbind(dbproc: PDBPROCESS; column: INT; indicator: LPCDBINT): RETCODE; cdecl;
function dbnumalts(dbproc: PDBPROCESS; computeid: INT): INT; cdecl;
function dbnumcols(dbproc: PDBPROCESS): INT; cdecl;
function dbnumcompute(dbproc: PDBPROCESS): INT; cdecl;
function dbnumorders(dbproc: PDBPROCESS): INT; cdecl;
function dbnumrets(dbproc: PDBPROCESS): INT; cdecl;
function dbopen(login: PLOGINREC; servername: LPCSTR): PDBPROCESS; cdecl;
function dbordercol(dbproc: PDBPROCESS; order: INT): INT; cdecl;
function dbprocinfo(dbproc: PDBPROCESS; pdbprocinfo: LPDBPROCINFO): RETCODE; cdecl;
procedure dbprhead(dbproc: PDBPROCESS); cdecl;
function dbprrow(dbproc: PDBPROCESS): RETCODE; cdecl;
function dbprtype(token: INT): LPCSTR; cdecl;
function dbqual(dbproc: PDBPROCESS; tabnum: INT; tabname: LPCSTR): LPCSTR; cdecl;
//* function dbreadpage(dbproc: PDBPROCESS; LPCSTR; DBINT; LPBYTE); cdecl;
function dbreadtext(dbproc: PDBPROCESS; buf: Pointer; bufsize: DBINT): DBINT; cdecl;
function dbresults(dbproc: PDBPROCESS): RETCODE; cdecl;
function dbretdata(dbproc: PDBPROCESS; retnum: INT): LPCBYTE; cdecl;
function dbretlen(dbproc: PDBPROCESS; retnum: INT): DBINT; cdecl;
function dbretname(dbproc: PDBPROCESS; retnum: INT): LPCSTR; cdecl;
function dbretstatus(dbproc: PDBPROCESS): DBINT; cdecl;
function dbrettype(dbproc: PDBPROCESS; retnum: INT): INT; cdecl;
function dbrows(dbproc: PDBPROCESS): RETCODE; cdecl;
function dbrowtype(dbproc: PDBPROCESS): STATUS; cdecl;
function dbrpcinit(dbproc: PDBPROCESS; rpcname: LPCSTR; options: DBSMALLINT): RETCODE; cdecl;
function dbrpcparam(dbproc: PDBPROCESS; paramname: LPCSTR; status: BYTE; typ: INT; maxlen, datalen: DBINT; value: LPCBYTE): RETCODE; cdecl;
function dbrpcsend(dbproc: PDBPROCESS): RETCODE; cdecl;
function dbrpcexec(dbproc: PDBPROCESS): RETCODE; cdecl;
procedure dbrpwclr(loginrec: PLOGINREC); cdecl;
//* function dbrpwset(loginrec: PLOGINREC; LPCSTR; LPCSTR; INT): RETCODE; cdecl;
function dbserverenum(searchmode: USHORT; servnamebuf: LPSTR; sizeservnamebuf: USHORT; numentries: LPUSHORT): INT; cdecl;
procedure dbsetavail(dbproc: PDBPROCESS); cdecl;
function dbsetmaxprocs(maxprocs: SHORT): RETCODE; cdecl;
{*} function dbsetlname(loginrec: PLOGINREC; pstr: LPCSTR; i: INT): RETCODE; cdecl;
function dbsetlogintime(seconds: INT): RETCODE; cdecl;
function dbsetlpacket(login: PLOGINREC; packet_size: USHORT): RETCODE; cdecl;
function dbsetnull(dbproc: PDBPROCESS; bindtype, bindlen: INT; bindval: LPCBYTE): RETCODE; cdecl;
function dbsetopt(dbproc: PDBPROCESS; option: INT; param: LPCSTR): RETCODE; cdecl;
function dbsettime(seconds: INT): RETCODE; cdecl;
procedure dbsetuserdata(dbproc: PDBPROCESS; ptr: Pointer); cdecl;
function dbsqlexec(dbproc: PDBPROCESS): RETCODE; cdecl;
function dbsqlok(dbproc: PDBPROCESS): RETCODE; cdecl;
function dbsqlsend(dbproc: PDBPROCESS): RETCODE; cdecl;
function dbstrcpy(dbproc: PDBPROCESS; start, numbytes: INT; dest: LPSTR): RETCODE; cdecl;
function dbstrlen(dbproc: PDBPROCESS): INT; cdecl;
function dbtabbrowse(dbproc: PDBPROCESS; tabnum: INT): BOOL; cdecl;
function dbtabcount(dbproc: PDBPROCESS): INT; cdecl;
function dbtabname(dbproc: PDBPROCESS; tabnum: INT): LPCSTR; cdecl;
function dbtabsource(dbproc: PDBPROCESS; colnum: INT; tabnum: LPINT): LPCSTR; cdecl;
function dbtsnewlen(dbproc: PDBPROCESS): INT; cdecl;
function dbtsnewval(dbproc: PDBPROCESS): LPCDBBINARY; cdecl;
function dbtsput(dbproc: PDBPROCESS; newts: LPCDBBINARY; newtslen, tabnum: INT; tabname: LPCSTR): RETCODE; cdecl;
function dbtxptr(dbproc: PDBPROCESS; column: INT): LPCDBBINARY; cdecl;
function dbtxtimestamp(dbproc: PDBPROCESS; column: INT): LPCDBBINARY; cdecl;
function dbtxtsnewval(dbproc: PDBPROCESS): LPCDBBINARY; cdecl;
function dbtxtsput(dbproc: PDBPROCESS; newtxts: LPCDBBINARY; colnum: INT): RETCODE; cdecl;
function dbuse(dbproc: PDBPROCESS; dbname: LPCSTR): RETCODE; cdecl;
function dbvarylen(dbproc: PDBPROCESS; column: INT): BOOL; cdecl;
function dbwillconvert(srctype, desttype: INT): BOOL; cdecl;
//* function dbwritepage(dbproc: PDBPROCESS; LPCSTR; DBINT, DBINT; LPBYTE): RETCODE; cdecl;
function dbwritetext(dbproc: PDBPROCESS; objname: LPCSTR; textptr: LPCDBBINARY; textptrlen: DBTINYINT; timestamp: LPCDBBINARY; log: BOOL; size: DBINT; text: LPCBYTE): RETCODE; cdecl;
function dbupdatetext(dbproc: PDBPROCESS; dest_object: LPCSTR; dest_textptr, dest_timestamp: LPCDBBINARY; update_type: INT; insert_offset, delete_length: DBINT; src_object: LPCSTR; src_size: DBINT; src_text: LPCDBBINARY): RETCODE; cdecl;


const
{$IFDEF WIN32}
  DBLIBDLL = 'ntwdblib.dll';
{$ELSE} {WIN16}
  DBLIBDLL = 'msdblib3.dll';
{$ENDIF}

implementation

function dberrhandle; external DBLIBDLL name 'dberrhandle';
function dbmsghandle; external DBLIBDLL name 'dbmsghandle';

{$IFDEF WIN32}
function dbprocerrhandle; external DBLIBDLL name 'dbprocerrhandle';
function dbprocmsghandle; external DBLIBDLL name 'dbprocmsghandle';
{$ELSE} {Win16}
procedure dbwinexit; external DBLIBDLL name 'dbwinexit';
procedure dblocklib; external DBLIBDLL name 'dblocklib';
procedure dbunlocklib; external DBLIBDLL name 'dbunlocklib';
{$ENDIF} {WIN32}

function abort_xact; external DBLIBDLL name 'abort_xact';
procedure build_xact_string; external DBLIBDLL name 'build_xact_string';
procedure close_commit; external DBLIBDLL name 'close_commit';
function commit_xact; external DBLIBDLL name 'commit_xact';
function open_commit; external DBLIBDLL name 'open_commit';
function remove_xact; external DBLIBDLL name 'remove_xact';
function scan_xact; external DBLIBDLL name 'scan_xact';
function start_xact; external DBLIBDLL name 'start_xact';
function stat_xact; external DBLIBDLL name 'stat_xact';

function bcp_batch; external DBLIBDLL name 'bcp_batch';
function bcp_bind; external DBLIBDLL name 'bcp_bind';
function bcp_colfmt; external DBLIBDLL name 'bcp_colfmt';
function bcp_collen; external DBLIBDLL name 'bcp_collen';
function bcp_colptr; external DBLIBDLL name 'bcp_colptr';
function bcp_columns; external DBLIBDLL name 'bcp_columns';
function bcp_control; external DBLIBDLL name 'bcp_control';
function bcp_done; external DBLIBDLL name 'bcp_done';
function bcp_exec; external DBLIBDLL name 'bcp_exec';
function bcp_init; external DBLIBDLL name 'bcp_init';
function bcp_moretext; external DBLIBDLL name 'bcp_moretext';
function bcp_readfmt; external DBLIBDLL name 'bcp_readfmt';
function bcp_sendrow; external DBLIBDLL name 'bcp_sendrow';
function bcp_setl; external DBLIBDLL name 'bcp_setl';
function bcp_writefmt; external DBLIBDLL name 'bcp_writefmt';

function dbadata; external DBLIBDLL name 'dbadata';
function dbadlen; external DBLIBDLL name 'dbadlen';
function dbaltbind; external DBLIBDLL name 'dbaltbind';
function dbaltcolid; external DBLIBDLL name 'dbaltcolid';
function dbaltlen; external DBLIBDLL name 'dbaltlen';
function dbaltop; external DBLIBDLL name 'dbaltop';
function dbalttype; external DBLIBDLL name 'dbalttype';
function dbaltutype; external DBLIBDLL name 'dbaltutype';
function dbanullbind; external DBLIBDLL name 'dbanullbind';
function dbbind; external DBLIBDLL name 'dbbind';
function dbbylist; external DBLIBDLL name 'dbbylist';
function dbcancel; external DBLIBDLL name 'dbcancel';
function dbcanquery; external DBLIBDLL name 'dbcanquery';
function dbchange; external DBLIBDLL name 'dbchange';
function dbclose; external DBLIBDLL name 'dbclose';
procedure dbclrbuf; external DBLIBDLL name 'dbclrbuf';
function dbclropt; external DBLIBDLL name 'dbclropt';
function dbcmd; external DBLIBDLL name 'dbcmd';
function dbcmdrow; external DBLIBDLL name 'dbcmdrow';
function dbcolbrowse; external DBLIBDLL name 'dbcolbrowse';
function dbcolinfo; external DBLIBDLL name 'dbcolinfo';
function dbcollen; external DBLIBDLL name 'dbcollen';
function dbcolname; external DBLIBDLL name 'dbcolname';
function dbcolsource; external DBLIBDLL name 'dbcolsource';
function dbcoltype; external DBLIBDLL name 'dbcoltype';
function dbcolutype; external DBLIBDLL name 'dbcolutype';
function dbconvert; external DBLIBDLL name 'dbconvert';
function dbcount; external DBLIBDLL name 'dbcount';
function dbcurcmd; external DBLIBDLL name 'dbcurcmd';
function dbcurrow; external DBLIBDLL name 'dbcurrow';
function dbcursor; external DBLIBDLL name 'dbcursor';
function dbcursorbind; external DBLIBDLL name 'dbcursorbind';
function dbcursorclose; external DBLIBDLL name 'dbcursorclose';
function dbcursorcolinfo; external DBLIBDLL name 'dbcursorcolinfo';
function dbcursorfetch; external DBLIBDLL name 'dbcursorfetch';
function dbcursorfetchex; external DBLIBDLL name 'dbcursorfetchex';
function dbcursorinfo; external DBLIBDLL name 'dbcursorinfo';
function dbcursorinfoex; external DBLIBDLL name 'dbcursorinfoex';
function dbcursoropen; external DBLIBDLL name 'dbcursoropen';
function dbdata; external DBLIBDLL name 'dbdata';
function dbdataready; external DBLIBDLL name 'dbdataready';
function dbdatecrack; external DBLIBDLL name 'dbdatecrack';
function dbdatlen; external DBLIBDLL name 'dbdatlen';
function dbdead; external DBLIBDLL name 'dbdead';
procedure dbexit; external DBLIBDLL name 'dbexit';
//* function dbenlisttrans; external DBLIBDLL name 'dbenlisttrans';
//* function dbenlistxatrans; external DBLIBDLL name 'dbenlistxatrans';
//* function dbfcmd; external DBLIBDLL name 'dbfcmd';
function dbfirstrow; external DBLIBDLL name 'dbfirstrow';
procedure dbfreebuf; external DBLIBDLL name 'dbfreebuf';
procedure dbfreelogin; external DBLIBDLL name 'dbfreelogin';
procedure dbfreequal; external DBLIBDLL name 'dbfreequal';
function dbgetchar; external DBLIBDLL name 'dbgetchar';
function dbgetmaxprocs; external DBLIBDLL name 'dbgetmaxprocs';
function dbgetoff; external DBLIBDLL name 'dbgetoff';
function dbgetpacket; external DBLIBDLL name 'dbgetpacket';
function dbgetrow; external DBLIBDLL name 'dbgetrow';
function dbgettime; external DBLIBDLL name 'dbgettime';
function dbgetuserdata; external DBLIBDLL name 'dbgetuserdata';
function dbhasretstat; external DBLIBDLL name 'dbhasretstat';
function dbinit; external DBLIBDLL name 'dbinit';
function dbisavail; external DBLIBDLL name 'dbisavail';
function dbiscount; external DBLIBDLL name 'dbiscount';
function dbisopt; external DBLIBDLL name 'dbisopt';
function dblastrow; external DBLIBDLL name 'dblastrow';
function dblogin; external DBLIBDLL name 'dblogin';
function dbmorecmds; external DBLIBDLL name 'dbmorecmds';
function dbmoretext; external DBLIBDLL name 'dbmoretext';
function dbname; external DBLIBDLL name 'dbname';
function dbnextrow; external DBLIBDLL name 'dbnextrow';
function dbnullbind; external DBLIBDLL name 'dbnullbind';
function dbnumalts; external DBLIBDLL name 'dbnumalts';
function dbnumcols; external DBLIBDLL name 'dbnumcols';
function dbnumcompute; external DBLIBDLL name 'dbnumcompute';
function dbnumorders; external DBLIBDLL name 'dbnumorders';
function dbnumrets; external DBLIBDLL name 'dbnumrets';
function dbopen; external DBLIBDLL name 'dbopen';
function dbordercol; external DBLIBDLL name 'dbordercol';
function dbprocinfo; external DBLIBDLL name 'dbprocinfo';
procedure dbprhead; external DBLIBDLL name 'dbprhead';
function dbprrow; external DBLIBDLL name 'dbprrow';
function dbprtype; external DBLIBDLL name 'dbprtype';
function dbqual; external DBLIBDLL name 'dbqual';
//* function dbreadpage; external DBLIBDLL name 'dbreadpage';
function dbreadtext; external DBLIBDLL name 'dbreadtext';
function dbresults; external DBLIBDLL name 'dbresults';
function dbretdata; external DBLIBDLL name 'dbretdata';
function dbretlen; external DBLIBDLL name 'dbretlen';
function dbretname; external DBLIBDLL name 'dbretname';
function dbretstatus; external DBLIBDLL name 'dbretstatus';
function dbrettype; external DBLIBDLL name 'dbrettype';
function dbrows; external DBLIBDLL name 'dbrows';
function dbrowtype; external DBLIBDLL name 'dbrowtype';
function dbrpcinit; external DBLIBDLL name 'dbrpcinit';
function dbrpcparam; external DBLIBDLL name 'dbrpcparam';
function dbrpcsend; external DBLIBDLL name 'dbrpcsend';
function dbrpcexec; external DBLIBDLL name 'dbrpcexec';
procedure dbrpwclr; external DBLIBDLL name 'dbrpwclr';
//* function dbrpwset; external DBLIBDLL name 'dbrpwset';
function dbserverenum; external DBLIBDLL name 'dbserverenum';
procedure dbsetavail; external DBLIBDLL name 'dbsetavail';
function dbsetmaxprocs; external DBLIBDLL name 'dbsetmaxprocs';
{*} function dbsetlname; external DBLIBDLL name 'dbsetlname';
function dbsetlogintime; external DBLIBDLL name 'dbsetlogintime';
function dbsetlpacket; external DBLIBDLL name 'dbsetlpacket';
function dbsetnull; external DBLIBDLL name 'dbsetnull';
function dbsetopt; external DBLIBDLL name 'dbsetopt';
function dbsettime; external DBLIBDLL name 'dbsettime';
procedure dbsetuserdata; external DBLIBDLL name 'dbsetuserdata';
function dbsqlexec; external DBLIBDLL name 'dbsqlexec';
function dbsqlok; external DBLIBDLL name 'dbsqlok';
function dbsqlsend; external DBLIBDLL name 'dbsqlsend';
function dbstrcpy; external DBLIBDLL name 'dbstrcpy';
function dbstrlen; external DBLIBDLL name 'dbstrlen';
function dbtabbrowse; external DBLIBDLL name 'dbtabbrowse';
function dbtabcount; external DBLIBDLL name 'dbtabcount';
function dbtabname; external DBLIBDLL name 'dbtabname';
function dbtabsource; external DBLIBDLL name 'dbtabsource';
function dbtsnewlen; external DBLIBDLL name 'dbtsnewlen';
function dbtsnewval; external DBLIBDLL name 'dbtsnewval';
function dbtsput; external DBLIBDLL name 'dbtsput';
function dbtxptr; external DBLIBDLL name 'dbtxptr';
function dbtxtimestamp; external DBLIBDLL name 'dbtxtimestamp';
function dbtxtsnewval; external DBLIBDLL name 'dbtxtsnewval';
function dbtxtsput; external DBLIBDLL name 'dbtxtsput';
function dbuse; external DBLIBDLL name 'dbuse';
function dbvarylen; external DBLIBDLL name 'dbvarylen';
function dbwillconvert; external DBLIBDLL name 'dbwillconvert';
//* function dbwritepage; external DBLIBDLL name 'dbwritepage';
function dbwritetext; external DBLIBDLL name 'dbwritetext';
function dbupdatetext; external DBLIBDLL name 'dbupdatetext';


function DBSETLHOST(loginrec: PLOGINREC; workstation: LPCSTR): RETCODE;
begin
  result := dbsetlname(loginrec, workstation, DBSETHOST);
end;

function DBSETLUSER(loginrec: PLOGINREC; username: LPCSTR): RETCODE;
begin
  result := dbsetlname(loginrec, username, DBSETUSER);
end;

function DBSETLPWD(loginrec: PLOGINREC; password: LPCSTR): RETCODE;
begin
  result := dbsetlname(loginrec, password, DBSETPWD);
end;

function DBSETLAPP(loginrec: PLOGINREC; app: LPCSTR): RETCODE;
begin
  result := dbsetlname(loginrec, app, DBSETAPP);
end;

function DBSETLNATLANG(loginrec: PLOGINREC; language: LPCSTR): RETCODE;
begin
  result := dbsetlname(loginrec, language, DBSETLANG);
end;

{ This was only here to support case-sentivity and  }
{ to keep it grouped with the other like functions. }
{function DBSETLPACKET(login: PLOGINREC; packet_size: USHORT): RETCODE; }
{begin                                                                  }
{  result := dbsetlpacket(login, packet_size);                          }
{end;                                                                   }

function DBSETLSECURE(ptrloginrec: PLOGINREC): RETCODE;
begin
  result := dbsetlname(ptrloginrec, nil, DBSETSECURE);
end;

function DBSETLVERSION(ptrloginrec: PLOGINREC; version: BYTE): RETCODE;
begin
  result := dbsetlname(ptrloginrec, nil, version);
end;

function DBSETLTIME(ptrloginrec: PLOGINREC; seconds: DWORD): RETCODE;
begin
  result := dbsetlname(ptrloginrec, LPCSTR(ULONG(seconds)), DBSET_LOGIN_TIME);
end;

function DBSETLFALLBACK(loginrec: PLOGINREC; fallback: LPCSTR): RETCODE;
begin
  result := dbsetlname(loginrec, fallback, DBSETFALLBACK);
end;

function dbrbuf(dbproc: PDBPROCESS): DBINT;
begin
  result := DBINT( dbdataready(dbproc) );
end;

end.

