unit SqlExt;

interface

uses
{$IFDEF WIN32}
  Windows,
{$ELSE}
  WinTypes, WinProcs,
{$ENDIF}
  SqlTypes, Sql;

{ ------------------------------------------------------------ }
{ SQLEXT.PAS - This is the include for applications using      }
{              the Microsoft SQL Extensions                    }
{                                                              }
{ (C) Copyright 1990 - 1996 By Microsoft Corp.                 }
{                                                              }
{      Updated 05/12/93 for 2.00 specification                 }
{      Updated 05/23/94 for 2.01 specification                 }
{      Updated 10/27/94 for 2.10 specification                 }
{      Updated 04/10/95 for 2.50 specification                 }
{      Updated 07/25/95 for 3.00 specification                 }
{      Updated 01/12/96 for 3.00 preliminary release           }
{      Updated 09/16/96 for 3.00 SDK release                   }
{      Updated 11/21/96 for bug #4436                          }
{                                                              }
{ Translated From: SQLEXT.H                                    }
{ Last Modified: 12/05/1997                                    }
{ Version: 1.0                                                 }
{ ------------------------------------------------------------ }

{  Default to ODBC Version 3.0 if no version is specified  }
{$IFNDEF ODBC_BaseVer} {and} {$IFNDEF ODBC_Ver10} {and} {$IFNDEF ODBC_Ver20}
      {and} {$IFNDEF ODBC_Ver25} {and} {$IFNDEF ODBC_Ver30} {then}
  {$DEFINE ODBC_Ver30}
{$ENDIF} {$ENDIF} {$ENDIF} {$ENDIF} {$ENDIF}


const

{ generally useful constants }
  SQL_SPEC_MAJOR  = 3;          { Major version of specification }
  SQL_SPEC_MINOR  = 00;         { Minor version of specification }
  SQL_SPEC_STRING = '03.00';    { String constant for version }

  SQL_SQLSTATE_SIZE   = 5;      { size of SQLSTATE }
  SQL_MAX_DSN_LENGTH  = 32;     { maximum data source name size }

  SQL_MAX_OPTION_STRING_LENGTH = 256;

{ return code SQL_NO_DATA_FOUND is the same as SQL_NO_DATA }
{$IFNDEF ODBC_Ver30}  { Below ODBC Version 3.0 }
  SQL_NO_DATA_FOUND = 100;
{$ELSE}
  SQL_NO_DATA_FOUND = SQL_NO_DATA;
{$ENDIF} {Below ODBC_Ver30}

{ an end handle type }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_HANDLE_SENV = 5;
{$ENDIF} {ODBC_Ver30}

{ env attribute }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_ATTR_ODBC_VERSION        = 200;
  SQL_ATTR_CONNECTION_POOLING  = 201;
  SQL_ATTR_CP_MATCH            = 202;
{$ENDIF} {ODBC_Ver30}

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
{ values for SQL_ATTR_CONNECTION_POOLING }
  SQL_CP_OFF                   = ULONG(0);
  SQL_CP_ONE_PER_DRIVER        = ULONG(1);
  SQL_CP_ONE_PER_HENV          = ULONG(2);
  SQL_CP_DEFAULT               = SQL_CP_OFF;

{ values for SQL_ATTR_CP_MATCH }
  SQL_CP_STRICT_MATCH          = ULONG(0);
  SQL_CP_RELAXED_MATCH         = ULONG(1);
  SQL_CP_MATCH_DEFAULT         = SQL_CP_STRICT_MATCH;

{ values for SQL_ATTR_ODBC_VERSION }
  SQL_OV_ODBC2                 = ULONG(2);
  SQL_OV_ODBC3                 = ULONG(3);
{$ENDIF} {ODBC_Ver30}

{ connection attributes }
  SQL_ACCESS_MODE              = 101;
  SQL_AUTOCOMMIT               = 102;
  SQL_LOGIN_TIMEOUT            = 103;
  SQL_OPT_TRACE                = 104;
  SQL_OPT_TRACEFILE            = 105;
  SQL_TRANSLATE_DLL            = 106;
  SQL_TRANSLATE_OPTION         = 107;
  SQL_TXN_ISOLATION            = 108;
  SQL_CURRENT_QUALIFIER        = 109;
  SQL_ODBC_CURSORS             = 110;
  SQL_QUIET_MODE               = 111;
  SQL_PACKET_SIZE              = 112;

{ connection attributes with new names }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_ATTR_ACCESS_MODE         = SQL_ACCESS_MODE;
  SQL_ATTR_AUTOCOMMIT          = SQL_AUTOCOMMIT;
  SQL_ATTR_CONNECTION_TIMEOUT  = 113;
  SQL_ATTR_CURRENT_CATALOG     = SQL_CURRENT_QUALIFIER;
  SQL_ATTR_DISCONNECT_BEHAVIOR = 114;
  SQL_ATTR_ENLIST_IN_DTC       = 1207;
  SQL_ATTR_ENLIST_IN_XA        = 1208;
  SQL_ATTR_LOGIN_TIMEOUT       = SQL_LOGIN_TIMEOUT;
  SQL_ATTR_ODBC_CURSORS        = SQL_ODBC_CURSORS;
  SQL_ATTR_PACKET_SIZE         = SQL_PACKET_SIZE;
  SQL_ATTR_QUIET_MODE          = SQL_QUIET_MODE;
  SQL_ATTR_TRACE               = SQL_OPT_TRACE;
  SQL_ATTR_TRACEFILE           = SQL_OPT_TRACEFILE;
  SQL_ATTR_TRANSLATE_LIB       = SQL_TRANSLATE_DLL;
  SQL_ATTR_TRANSLATE_OPTION    = SQL_TRANSLATE_OPTION;
  SQL_ATTR_TXN_ISOLATION       = SQL_TXN_ISOLATION;
{$ENDIF} {ODBC_Ver30}

{ SQL_CONNECT_OPT_DRVR_START is not meaningful for 3.0 driver }
{$IFNDEF ODBC_Ver30}  { Below ODBC Version 3.0 }
  SQL_CONNECT_OPT_DRVR_START   = 1000;
{$ENDIF} {Below ODBC_Ver30}

{$IFNDEF ODBC_Ver30}  { Below ODBC Version 3.0 }
  SQL_CONN_OPT_MAX             = SQL_PACKET_SIZE;
  SQL_CONN_OPT_MIN             = SQL_ACCESS_MODE;
{$ENDIF} {Below ODBC_Ver30}

{ SQL_ACCESS_MODE options }
  SQL_MODE_READ_WRITE          = ULONG(0);
  SQL_MODE_READ_ONLY           = ULONG(1);
  SQL_MODE_DEFAULT             = SQL_MODE_READ_WRITE;

{ SQL_AUTOCOMMIT options }
  SQL_AUTOCOMMIT_OFF           = ULONG(0);
  SQL_AUTOCOMMIT_ON            = ULONG(1);
  SQL_AUTOCOMMIT_DEFAULT       = SQL_AUTOCOMMIT_ON;

{ SQL_LOGIN_TIMEOUT options }
  SQL_LOGIN_TIMEOUT_DEFAULT    = ULONG(15);

{ SQL_OPT_TRACE options }
  SQL_OPT_TRACE_OFF            = ULONG(0);
  SQL_OPT_TRACE_ON             = ULONG(1);
  SQL_OPT_TRACE_DEFAULT        = SQL_OPT_TRACE_OFF;
  SQL_OPT_TRACE_FILE_DEFAULT   = '\\SQL.LOG';

{ SQL_ODBC_CURSORS options }
  SQL_CUR_USE_IF_NEEDED        = ULONG(0);
  SQL_CUR_USE_ODBC             = ULONG(1);
  SQL_CUR_USE_DRIVER           = ULONG(2);
  SQL_CUR_DEFAULT              = SQL_CUR_USE_DRIVER;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
{ values for SQL_ATTR_DISCONNECT_BEHAVIOR }
  SQL_DB_RETURN_TO_POOL        = ULONG(0);
  SQL_DB_DISCONNECT            = ULONG(1);
  SQL_DB_DEFAULT               = SQL_DB_RETURN_TO_POOL;

{ values for SQL_ATTR_ENLIST_IN_DTC }
  SQL_DTC_DONE                 = LongInt(0);
{$ENDIF} {ODBC_Ver30}

{ statement attributes }
  SQL_QUERY_TIMEOUT            = 0;
  SQL_MAX_ROWS                 = 1;
  SQL_NOSCAN                   = 2;
  SQL_MAX_LENGTH               = 3;
  SQL_ASYNC_ENABLE             = 4;   { same as SQL_ATTR_ASYNC_ENABLE }
  SQL_BIND_TYPE                = 5;
  SQL_CURSOR_TYPE              = 6;
  SQL_CONCURRENCY              = 7;
  SQL_KEYSET_SIZE              = 8;
  SQL_ROWSET_SIZE              = 9;
  SQL_SIMULATE_CURSOR          = 10;
  SQL_RETRIEVE_DATA            = 11;
  SQL_USE_BOOKMARKS            = 12;
  SQL_GET_BOOKMARK             = 13;  { GetStmtOption Only }
  SQL_ROW_NUMBER               = 14;  { GetStmtOption Only }

{ statement attributes for ODBC 3.0 }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_ATTR_ASYNC_ENABLE          = 4;
  SQL_ATTR_CONCURRENCY           = SQL_CONCURRENCY;
  SQL_ATTR_CURSOR_TYPE           = SQL_CURSOR_TYPE;
  SQL_ATTR_ENABLE_AUTO_IPD       = 15;
  SQL_ATTR_FETCH_BOOKMARK_PTR    = 16;
  SQL_ATTR_KEYSET_SIZE           = SQL_KEYSET_SIZE;
  SQL_ATTR_MAX_LENGTH            = SQL_MAX_LENGTH;
  SQL_ATTR_MAX_ROWS              = SQL_MAX_ROWS;
  SQL_ATTR_NOSCAN                = SQL_NOSCAN;
  SQL_ATTR_PARAM_BIND_OFFSET_PTR = 17;
  SQL_ATTR_PARAM_BIND_TYPE       = 18;
  SQL_ATTR_PARAM_OPERATION_PTR   = 19;
  SQL_ATTR_PARAM_STATUS_PTR      = 20;
  SQL_ATTR_PARAMS_PROCESSED_PTR  = 21;
  SQL_ATTR_PARAMSET_SIZE         = 22;
  SQL_ATTR_QUERY_TIMEOUT         = SQL_QUERY_TIMEOUT;
  SQL_ATTR_RETRIEVE_DATA         = SQL_RETRIEVE_DATA;
  SQL_ATTR_ROW_BIND_OFFSET_PTR   = 23;
  SQL_ATTR_ROW_BIND_TYPE         = SQL_BIND_TYPE;
  SQL_ATTR_ROW_NUMBER            = SQL_ROW_NUMBER; { GetStmtAttr }
  SQL_ATTR_ROW_OPERATION_PTR     = 24;
  SQL_ATTR_ROW_STATUS_PTR        = 25;
  SQL_ATTR_ROWS_FETCHED_PTR      = 26;
  SQL_ATTR_ROW_ARRAY_SIZE        = 27;
  SQL_ATTR_SIMULATE_CURSOR       = SQL_SIMULATE_CURSOR;
  SQL_ATTR_USE_BOOKMARKS         = SQL_USE_BOOKMARKS;
{$ENDIF} {ODBC_Ver30}

{$IFNDEF ODBC_Ver30}  { Below ODBC Version 3.0 }
  SQL_STMT_OPT_MAX               = SQL_ROW_NUMBER;
  SQL_STMT_OPT_MIN               = SQL_QUERY_TIMEOUT;
{$ENDIF} {Below ODBC_Ver30}

{ SQLColAttributes subdefines for SQL_COLUMN_SEARCHABLE }
{ These are also used by SQLGetInfo                     }
  SQL_UNSEARCHABLE               = 0;
  SQL_LIKE_ONLY                  = 1;
  SQL_ALL_EXCEPT_LIKE            = 2;
  SQL_SEARCHABLE                 = 3;
  SQL_PRED_SEARCHABLE            = SQL_SEARCHABLE;

{ Special return values for SQLGetData }
  SQL_NO_TOTAL                   = -4;

{ New defines for SEARCHABLE column in SQLGetTypeInfo }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_COL_PRED_CHAR              = SQL_LIKE_ONLY;
  SQL_COL_PRED_BASIC             = SQL_ALL_EXCEPT_LIKE;
{$ENDIF} {ODBC_Ver30}

{ whether an attribute is a pointer or not }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_IS_POINTER                 = -4;
  SQL_IS_UINTEGER                = -5;
  SQL_IS_INTEGER                 = -6;
  SQL_IS_USMALLINT               = -7;
  SQL_IS_SMALLINT                = -8;
{$ENDIF} {ODBC_Ver30}

{ the value of SQL_ATTR_PARAM_BIND_TYPE }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_PARAM_BIND_BY_COLUMN       = ULONG(0);
  SQL_PARAM_BIND_TYPE_DEFAULT    = SQL_PARAM_BIND_BY_COLUMN;
{$ENDIF} {ODBC_Ver30}

{ SQL_QUERY_TIMEOUT options }
  SQL_QUERY_TIMEOUT_DEFAULT      = ULONG(0);

{ SQL_MAX_ROWS options }
  SQL_MAX_ROWS_DEFAULT           = ULONG(0);

{ SQL_NOSCAN options }
  SQL_NOSCAN_OFF                 = ULONG(0);     {  1.0 FALSE  }
  SQL_NOSCAN_ON                  = ULONG(1);     {  1.0 TRUE   }
  SQL_NOSCAN_DEFAULT             = SQL_NOSCAN_OFF;

{ SQL_MAX_LENGTH options }
  SQL_MAX_LENGTH_DEFAULT         = ULONG(0);

{ values for SQL_ATTR_ASYNC_ENABLE }
  SQL_ASYNC_ENABLE_OFF           = ULONG(0);
  SQL_ASYNC_ENABLE_ON            = ULONG(1);
  SQL_ASYNC_ENABLE_DEFAULT       = SQL_ASYNC_ENABLE_OFF;

{ SQL_BIND_TYPE options }
  SQL_BIND_BY_COLUMN             = ULONG(0);
  SQL_BIND_TYPE_DEFAULT          = SQL_BIND_BY_COLUMN;  { Default value }

{ SQL_CONCURRENCY options }
  SQL_CONCUR_READ_ONLY           = 1;
  SQL_CONCUR_LOCK                = 2;
  SQL_CONCUR_ROWVER              = 3;
  SQL_CONCUR_VALUES              = 4;
  SQL_CONCUR_DEFAULT             = SQL_CONCUR_READ_ONLY;  { Default value }

{ SQL_CURSOR_TYPE options }
  SQL_CURSOR_FORWARD_ONLY        = ULONG(0);
  SQL_CURSOR_KEYSET_DRIVEN       = ULONG(1);
  SQL_CURSOR_DYNAMIC             = ULONG(2);
  SQL_CURSOR_STATIC              = ULONG(3);
  SQL_CURSOR_TYPE_DEFAULT        = SQL_CURSOR_FORWARD_ONLY;  { Default value }

{ SQL_ROWSET_SIZE options }
  SQL_ROWSET_SIZE_DEFAULT        = ULONG(1);

{ SQL_KEYSET_SIZE options }
  SQL_KEYSET_SIZE_DEFAULT        = ULONG(0);

{ SQL_SIMULATE_CURSOR options }
  SQL_SC_NON_UNIQUE              = ULONG(0);
  SQL_SC_TRY_UNIQUE              = ULONG(1);
  SQL_SC_UNIQUE                  = ULONG(2);

{ SQL_RETRIEVE_DATA options }
  SQL_RD_OFF                     = ULONG(0);
  SQL_RD_ON                      = ULONG(1);
  SQL_RD_DEFAULT                 = SQL_RD_ON;

{ SQL_USE_BOOKMARKS options }
  SQL_UB_OFF                     = ULONG(0);
  SQL_UB_ON                      = ULONG(1);
  SQL_UB_DEFAULT                 = SQL_UB_OFF;

{ New values for SQL_USE_BOOKMARKS attribute }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_UB_FIXED                   = SQL_UB_ON;
  SQL_UB_VARIABLE                = ULONG(2);
{$ENDIF} {ODBC_Ver30}

{ SQLColAttributes defines }
  SQL_COLUMN_COUNT               = 0;
  SQL_COLUMN_NAME                = 1;
  SQL_COLUMN_TYPE                = 2;
  SQL_COLUMN_LENGTH              = 3;
  SQL_COLUMN_PRECISION           = 4;
  SQL_COLUMN_SCALE               = 5;
  SQL_COLUMN_DISPLAY_SIZE        = 6;
  SQL_COLUMN_NULLABLE            = 7;
  SQL_COLUMN_UNSIGNED            = 8;
  SQL_COLUMN_MONEY               = 9;
  SQL_COLUMN_UPDATABLE           = 10;
  SQL_COLUMN_AUTO_INCREMENT      = 11;
  SQL_COLUMN_CASE_SENSITIVE      = 12;
  SQL_COLUMN_SEARCHABLE          = 13;
  SQL_COLUMN_TYPE_NAME           = 14;
  SQL_COLUMN_TABLE_NAME          = 15;
  SQL_COLUMN_OWNER_NAME          = 16;
  SQL_COLUMN_QUALIFIER_NAME      = 17;
  SQL_COLUMN_LABEL               = 18;
  SQL_COLATT_OPT_MAX             = SQL_COLUMN_LABEL;
{$IFNDEF ODBC_Ver30}  { Below ODBC Version 3.0 }
  SQL_COLUMN_DRIVER_START        = 1000;
{$ENDIF} {Below ODBC_Ver30}
  SQL_COLATT_OPT_MIN             = SQL_COLUMN_COUNT;

{ SQLColAttributes subdefines for SQL_COLUMN_UPDATABLE }
  SQL_ATTR_READONLY              = 0;
  SQL_ATTR_WRITE                 = 1;
  SQL_ATTR_READWRITE_UNKNOWN     = 2;

{ extended descriptor field }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_DESC_ARRAY_SIZE            = 20;
  SQL_DESC_ARRAY_STATUS_PTR      = 21;
  SQL_DESC_AUTO_UNIQUE_VALUE     = SQL_COLUMN_AUTO_INCREMENT;
  SQL_DESC_BASE_COLUMN_NAME      = 22;
  SQL_DESC_BASE_TABLE_NAME       = 23;
  SQL_DESC_BIND_OFFSET_PTR       = 24;
  SQL_DESC_BIND_TYPE             = 25;
  SQL_DESC_CASE_SENSITIVE        = SQL_COLUMN_CASE_SENSITIVE;
  SQL_DESC_CATALOG_NAME          = SQL_COLUMN_QUALIFIER_NAME;
  SQL_DESC_CONCISE_TYPE          = SQL_COLUMN_TYPE;
  SQL_DESC_DATETIME_INTERVAL_PRECISION = 26;
  SQL_DESC_DISPLAY_SIZE          = SQL_COLUMN_DISPLAY_SIZE;
  SQL_DESC_FIXED_PREC_SCALE      = SQL_COLUMN_MONEY;
  SQL_DESC_LABEL                 = SQL_COLUMN_LABEL;
  SQL_DESC_LITERAL_PREFIX        = 27;
  SQL_DESC_LITERAL_SUFFIX        = 28;
  SQL_DESC_LOCAL_TYPE_NAME       = 29;
  SQL_DESC_MAXIMUM_SCALE         = 30;
  SQL_DESC_MINIMUM_SCALE         = 31;
  SQL_DESC_NUM_PREC_RADIX        = 32;
  SQL_DESC_PARAMETER_TYPE        = 33;
  SQL_DESC_ROWS_PROCESSED_PTR    = 34;
  SQL_DESC_SCHEMA_NAME           = SQL_COLUMN_OWNER_NAME;
  SQL_DESC_SEARCHABLE            = SQL_COLUMN_SEARCHABLE;
  SQL_DESC_TYPE_NAME             = SQL_COLUMN_TYPE_NAME;
  SQL_DESC_TABLE_NAME            = SQL_COLUMN_TABLE_NAME;
  SQL_DESC_UNSIGNED              = SQL_COLUMN_UNSIGNED;
  SQL_DESC_UPDATABLE             = SQL_COLUMN_UPDATABLE;
{$ENDIF} {ODBC_Ver30}


{ defines for diagnostics fields }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_DIAG_CURSOR_ROW_COUNT      = -1249;
  SQL_DIAG_ROW_NUMBER            = -1248;
  SQL_DIAG_COLUMN_NUMBER         = -1247;
{$ENDIF} {ODBC_Ver30}

{ dynamic function codes }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_DIAG_CALL                  = 7;
{$ENDIF} {ODBC_Ver30}

{ SQL extended datatypes }
  SQL_DATE                       = 9;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_INTERVAL                   = 10;
{$ENDIF} {ODBC_Ver30}
  SQL_TIME                       = 10;
  SQL_TIMESTAMP                  = 11;
  SQL_LONGVARCHAR                = -1;
  SQL_BINARY                     = -2;
  SQL_VARBINARY                  = -3;
  SQL_LONGVARBINARY              = -4;
  SQL_BIGINT                     = -5;
  SQL_TINYINT                    = -6;
  SQL_BIT                        = -7;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
{ interval code }
  SQL_CODE_YEAR	                 = 1;
  SQL_CODE_MONTH                 = 2;
  SQL_CODE_DAY                   = 3;
  SQL_CODE_HOUR                  = 4;
  SQL_CODE_MINUTE                = 5;
  SQL_CODE_SECOND                = 6;
  SQL_CODE_YEAR_TO_MONTH         = 7;
  SQL_CODE_DAY_TO_HOUR           = 8;
  SQL_CODE_DAY_TO_MINUTE         = 9;
  SQL_CODE_DAY_TO_SECOND         = 10;
  SQL_CODE_HOUR_TO_MINUTE        = 11;
  SQL_CODE_HOUR_TO_SECOND        = 12;
  SQL_CODE_MINUTE_TO_SECOND      = 13;

  SQL_INTERVAL_YEAR              = (100 + SQL_CODE_YEAR);
  SQL_INTERVAL_MONTH             = (100 + SQL_CODE_MONTH);
  SQL_INTERVAL_DAY               = (100 + SQL_CODE_DAY);
  SQL_INTERVAL_HOUR              = (100 + SQL_CODE_HOUR);
  SQL_INTERVAL_MINUTE            = (100 + SQL_CODE_MINUTE);
  SQL_INTERVAL_SECOND            = (100 + SQL_CODE_SECOND);
  SQL_INTERVAL_YEAR_TO_MONTH     = (100 + SQL_CODE_YEAR_TO_MONTH);
  SQL_INTERVAL_DAY_TO_HOUR       = (100 + SQL_CODE_DAY_TO_HOUR);
  SQL_INTERVAL_DAY_TO_MINUTE     = (100 + SQL_CODE_DAY_TO_MINUTE);
  SQL_INTERVAL_DAY_TO_SECOND     = (100 + SQL_CODE_DAY_TO_SECOND);
  SQL_INTERVAL_HOUR_TO_MINUTE    = (100 + SQL_CODE_HOUR_TO_MINUTE);
  SQL_INTERVAL_HOUR_TO_SECOND    = (100 + SQL_CODE_HOUR_TO_SECOND);
  SQL_INTERVAL_MINUTE_TO_SECOND  = (100 + SQL_CODE_MINUTE_TO_SECOND);

{$ELSE}
  SQL_INTERVAL_YEAR              = -80;
  SQL_INTERVAL_MONTH             = -81;
  SQL_INTERVAL_YEAR_TO_MONTH     = -82;
  SQL_INTERVAL_DAY               = -83;
  SQL_INTERVAL_HOUR              = -84;
  SQL_INTERVAL_MINUTE            = -85;
  SQL_INTERVAL_SECOND            = -86;
  SQL_INTERVAL_DAY_TO_HOUR       = -87;
  SQL_INTERVAL_DAY_TO_MINUTE     = -88;
  SQL_INTERVAL_DAY_TO_SECOND     = -89;
  SQL_INTERVAL_HOUR_TO_MINUTE    = -90;
  SQL_INTERVAL_HOUR_TO_SECOND    = -91;
  SQL_INTERVAL_MINUTE_TO_SECOND  = -92;
{$ENDIF} {ODBC_Ver30}


  SQL_UNICODE                    = -95;
  SQL_UNICODE_VARCHAR            = -96;
  SQL_UNICODE_LONGVARCHAR        = -97;
  SQL_UNICODE_CHAR               = SQL_UNICODE;

{$IFNDEF ODBC_Ver30}  { Below ODBC Version 3.0 }
  SQL_TYPE_DRIVER_START          = SQL_INTERVAL_YEAR;
  SQL_TYPE_DRIVER_END            = SQL_UNICODE_LONGVARCHAR;
{$ENDIF} {Below ODBC_Ver30}

{ C datatype to SQL datatype mapping      SQL types
                                           ------------------- }
  SQL_C_CHAR     = SQL_CHAR;      { CHAR, VARCHAR, DECIMAL, NUMERIC }
  SQL_C_LONG     = SQL_INTEGER;   { INTEGER                   }
  SQL_C_SHORT    = SQL_SMALLINT;  { SMALLINT                  }
  SQL_C_FLOAT    = SQL_REAL;      { REAL                      }
  SQL_C_DOUBLE   = SQL_DOUBLE;    { FLOAT, DOUBLE             }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_C_NUMERIC  = SQL_NUMERIC;
{$ENDIF} {ODBC_Ver30}
  SQL_C_DEFAULT                  = 99;

  SQL_SIGNED_OFFSET              = -20;
  SQL_UNSIGNED_OFFSET            = -22;

{ C datatype to SQL datatype mapping }
  SQL_C_DATE                     = SQL_DATE;
  SQL_C_TIME                     = SQL_TIME;
  SQL_C_TIMESTAMP                = SQL_TIMESTAMP;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_C_TYPE_DATE                = SQL_TYPE_DATE;
  SQL_C_TYPE_TIME                = SQL_TYPE_TIME;
  SQL_C_TYPE_TIMESTAMP           = SQL_TYPE_TIMESTAMP;
  SQL_C_INTERVAL_YEAR            = SQL_INTERVAL_YEAR;
  SQL_C_INTERVAL_MONTH           = SQL_INTERVAL_MONTH;
  SQL_C_INTERVAL_DAY             = SQL_INTERVAL_DAY;
  SQL_C_INTERVAL_HOUR            = SQL_INTERVAL_HOUR;
  SQL_C_INTERVAL_MINUTE          = SQL_INTERVAL_MINUTE;
  SQL_C_INTERVAL_SECOND          = SQL_INTERVAL_SECOND;
  SQL_C_INTERVAL_YEAR_TO_MONTH   = SQL_INTERVAL_YEAR_TO_MONTH;
  SQL_C_INTERVAL_DAY_TO_HOUR     = SQL_INTERVAL_DAY_TO_HOUR;
  SQL_C_INTERVAL_DAY_TO_MINUTE   = SQL_INTERVAL_DAY_TO_MINUTE;
  SQL_C_INTERVAL_DAY_TO_SECOND   = SQL_INTERVAL_DAY_TO_SECOND;
  SQL_C_INTERVAL_HOUR_TO_MINUTE  = SQL_INTERVAL_HOUR_TO_MINUTE;
  SQL_C_INTERVAL_HOUR_TO_SECOND  = SQL_INTERVAL_HOUR_TO_SECOND;
  SQL_C_INTERVAL_MINUTE_TO_SECOND = SQL_INTERVAL_MINUTE_TO_SECOND;
{$ENDIF} {ODBC_Ver30}
  SQL_C_BINARY                   = SQL_BINARY;
  SQL_C_BIT                      = SQL_BIT;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_C_SBIGINT	 = (SQL_BIGINT+SQL_SIGNED_OFFSET);    { SIGNED BIGINT     }
  SQL_C_UBIGINT	 = (SQL_BIGINT+SQL_UNSIGNED_OFFSET);  { UNSIGNED BIGINT   }
{$ENDIF} {ODBC_Ver30}
  SQL_C_TINYINT  = SQL_TINYINT;
  SQL_C_SLONG    = (SQL_C_LONG+SQL_SIGNED_OFFSET);    { SIGNED INTEGER    }
  SQL_C_SSHORT   = (SQL_C_SHORT+SQL_SIGNED_OFFSET);   { SIGNED SMALLINT   }
  SQL_C_STINYINT = (SQL_TINYINT+SQL_SIGNED_OFFSET);   { SIGNED TINYINT    }
  SQL_C_ULONG    = (SQL_C_LONG+SQL_UNSIGNED_OFFSET);  { UNSIGNED INTEGER  }
  SQL_C_USHORT   = (SQL_C_SHORT+SQL_UNSIGNED_OFFSET); { UNSIGNED SMALLINT }
  SQL_C_UTINYINT = (SQL_TINYINT+SQL_UNSIGNED_OFFSET); { UNSIGNED TINYINT  }
  SQL_C_BOOKMARK = SQL_C_ULONG;                       { BOOKMARK          }

  SQL_TYPE_NULL                  = 0;
{$IFNDEF ODBC_Ver30}  { Below ODBC Version 3.0 }
  SQL_TYPE_MIN                   = SQL_BIT;
  SQL_TYPE_MAX                   = SQL_VARCHAR;
{$ENDIF} {Below ODBC_Ver30}

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_C_VARBOOKMARK              = SQL_C_BINARY;
{$ENDIF} {ODBC_Ver30}

{ define for SQL_DIAG_ROW_NUMBER and SQL_DIAG_COLUMN_NUMBER }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_NO_ROW_NUMBER              = -1;
  SQL_NO_COLUMN_NUMBER           = -1;
  SQL_ROW_NUMBER_UNKNOWN         = -2;
  SQL_COLUMN_NUMBER_UNKNOWN      = -2;
{$ENDIF} {ODBC_Ver30}

{ SQLBindParameter extensions }
  SQL_DEFAULT_PARAM              = -5;
  SQL_IGNORE                     = -6;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_COLUMN_IGNORE              = SQL_IGNORE;
{$ENDIF} {ODBC_Ver30}
  SQL_LEN_DATA_AT_EXEC_OFFSET    = -100;
  function SQL_LEN_DATA_AT_EXEC(length: Integer): Integer;

const
{ binary length for driver specific attributes }
  SQL_LEN_BINARY_ATTR_OFFSET     = -100;
  function SQL_LEN_BINARY_ATTR(length: Integer): Integer;

const

{-------------------------------------------}
{ SQLGetFunctions: additional values for    }
{ fFunction to represent functions that     }
{ are not in the X/Open spec.               }
{-------------------------------------------}

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_API_SQLALLOCHANDLESTD      = 73;
  SQL_API_SQLBULKOPERATIONS      = 24;
{$ENDIF} {ODBC_Ver30}
  SQL_API_SQLBINDPARAMETER       = 72;
  SQL_API_SQLBROWSECONNECT       = 55;
  SQL_API_SQLCOLATTRIBUTES       = 6;
  SQL_API_SQLCOLUMNPRIVILEGES    = 56;
  SQL_API_SQLDESCRIBEPARAM       = 58;
  SQL_API_SQLDRIVERCONNECT       = 41;
  SQL_API_SQLDRIVERS             = 71;
  SQL_API_SQLEXTENDEDFETCH       = 59;
  SQL_API_SQLFOREIGNKEYS         = 60;
  SQL_API_SQLMORERESULTS         = 61;
  SQL_API_SQLNATIVESQL           = 62;
  SQL_API_SQLNUMPARAMS           = 63;
  SQL_API_SQLPARAMOPTIONS        = 64;
  SQL_API_SQLPRIMARYKEYS         = 65;
  SQL_API_SQLPROCEDURECOLUMNS    = 66;
  SQL_API_SQLPROCEDURES          = 67;
  SQL_API_SQLSETPOS              = 68;
  SQL_API_SQLSETSCROLLOPTIONS    = 69;
  SQL_API_SQLTABLEPRIVILEGES     = 70;

{-------------------------------------------}
{ SQL_EXT_API_LAST is not useful with ODBC  }
{ version 3.0 because some of the values    }
{ from X/Open are in the 10000 range.       }
{-------------------------------------------}

{$IFNDEF ODBC_Ver30}  { Below ODBC Version 3.0 }
  SQL_EXT_API_LAST               = SQL_API_SQLBINDPARAMETER;
  SQL_NUM_FUNCTIONS              = 23;
  SQL_EXT_API_START              = 40;
  SQL_NUM_EXTENSIONS             = (SQL_EXT_API_LAST-SQL_EXT_API_START+1);
{$ENDIF} {Below ODBC_Ver30}

{-----------------------------------------------}
{ SQL_API_ALL_FUNCTIONS returns an array        }
{ of 'booleans' representing whether a          }
{ function is implemented by the driver.        }
{                                               }
{ CAUTION: Only functions defined in ODBC       }
{ version 2.0 and earlier are returned, the     }
{ new high-range function numbers defined by    }
{ X/Open break this scheme.   See the new       }
{ method -- SQL_API_ODBC3_ALL_FUNCTIONS         }
{-----------------------------------------------}

  SQL_API_ALL_FUNCTIONS          = 0;    { See CAUTION above }

{-----------------------------------------------}
{ 2.X drivers export a dummy function with  	}
{ ordinal number SQL_API_LOADBYORDINAL to speed }
{ loading under the windows operating system.   }
{ 						}
{ CAUTION: Loading by ordinal is not supported  }
{ for 3.0 and above drivers.			}
{-----------------------------------------------}

  SQL_API_LOADBYORDINAL          = 199;  { See CAUTION above }

{-----------------------------------------------}
{ SQL_API_ODBC3_ALL_FUNCTIONS                   }
{ This returns a bitmap, which allows us to     }
{ handle the higher-valued function numbers.    }
{ Use  SQL_FUNC_EXISTS(bitmap,function_number)  }
{ to determine if the function exists.          }
{-----------------------------------------------}


{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_API_ODBC3_ALL_FUNCTIONS      = 999;
  SQL_API_ODBC3_ALL_FUNCTIONS_SIZE = 250; { array of 250 words }

  function SQL_FUNC_EXISTS(pfExists: PUWORD; uwAPI: UWORD): SQLINTEGER;
{$ENDIF} {ODBC_Ver30}


{----------------------------------------------}
{ Extended definitions for SQLGetInfo          }
{----------------------------------------------}

{---------------------------------}
{ Values in ODBC 2.0 that are not }
{ in the X/Open spec              }
{---------------------------------}

const

  SQL_INFO_FIRST                 = 0;
  SQL_ACTIVE_CONNECTIONS         = 0;   { MAX_DRIVER_CONNECTIONS    }
  SQL_ACTIVE_STATEMENTS          = 1;   { MAX_CONCURRENT_ACTIVITIES }
  SQL_DRIVER_HDBC                = 3;
  SQL_DRIVER_HENV                = 4;
  SQL_DRIVER_HSTMT               = 5;
  SQL_DRIVER_NAME                = 6;
  SQL_DRIVER_VER                 = 7;
  SQL_ODBC_API_CONFORMANCE       = 9;
  SQL_ODBC_VER                   = 10;
  SQL_ROW_UPDATES                = 11;
  SQL_ODBC_SAG_CLI_CONFORMANCE   = 12;
  SQL_ODBC_SQL_CONFORMANCE       = 15;
  SQL_PROCEDURES                 = 21;
  SQL_CONCAT_NULL_BEHAVIOR       = 22;
  SQL_CURSOR_ROLLBACK_BEHAVIOR   = 24;
  SQL_EXPRESSIONS_IN_ORDERBY     = 27;
  SQL_MAX_OWNER_NAME_LEN         = 32;  { MAX_SCHEMA_NAME_LEN  }
  SQL_MAX_PROCEDURE_NAME_LEN     = 33;
  SQL_MAX_QUALIFIER_NAME_LEN     = 34;  { MAX_CATALOG_NAME_LEN }
  SQL_MULT_RESULT_SETS           = 36;
  SQL_MULTIPLE_ACTIVE_TXN        = 37;
  SQL_OUTER_JOINS                = 38;
  SQL_OWNER_TERM                 = 39;
  SQL_PROCEDURE_TERM             = 40;
  SQL_QUALIFIER_NAME_SEPARATOR   = 41;
  SQL_QUALIFIER_TERM             = 42;
  SQL_SCROLL_OPTIONS             = 44;
  SQL_TABLE_TERM                 = 45;
  SQL_CONVERT_FUNCTIONS          = 48;
  SQL_NUMERIC_FUNCTIONS          = 49;
  SQL_STRING_FUNCTIONS           = 50;
  SQL_SYSTEM_FUNCTIONS           = 51;
  SQL_TIMEDATE_FUNCTIONS         = 52;
  SQL_CONVERT_BIGINT             = 53;
  SQL_CONVERT_BINARY             = 54;
  SQL_CONVERT_BIT                = 55;
  SQL_CONVERT_CHAR               = 56;
  SQL_CONVERT_DATE               = 57;
  SQL_CONVERT_DECIMAL            = 58;
  SQL_CONVERT_DOUBLE             = 59;
  SQL_CONVERT_FLOAT              = 60;
  SQL_CONVERT_INTEGER            = 61;
  SQL_CONVERT_LONGVARCHAR        = 62;
  SQL_CONVERT_NUMERIC            = 63;
  SQL_CONVERT_REAL               = 64;
  SQL_CONVERT_SMALLINT           = 65;
  SQL_CONVERT_TIME               = 66;
  SQL_CONVERT_TIMESTAMP          = 67;
  SQL_CONVERT_TINYINT            = 68;
  SQL_CONVERT_VARBINARY          = 69;
  SQL_CONVERT_VARCHAR            = 70;
  SQL_CONVERT_LONGVARBINARY      = 71;
  SQL_ODBC_SQL_OPT_IEF           = 73;  { SQL_INTEGRITY }
  SQL_CORRELATION_NAME           = 74;
  SQL_NON_NULLABLE_COLUMNS       = 75;
  SQL_DRIVER_HLIB                = 76;
  SQL_DRIVER_ODBC_VER            = 77;
  SQL_LOCK_TYPES                 = 78;
  SQL_POS_OPERATIONS             = 79;
  SQL_POSITIONED_STATEMENTS      = 80;
  SQL_BOOKMARK_PERSISTENCE       = 82;
  SQL_STATIC_SENSITIVITY         = 83;
  SQL_FILE_USAGE                 = 84;
  SQL_COLUMN_ALIAS               = 87;
  SQL_GROUP_BY                   = 88;
  SQL_KEYWORDS                   = 89;
  SQL_OWNER_USAGE                = 91;
  SQL_QUALIFIER_USAGE            = 92;
  SQL_QUOTED_IDENTIFIER_CASE     = 93;
  SQL_SUBQUERIES                 = 95;
  SQL_UNION                      = 96;
  SQL_MAX_ROW_SIZE_INCLUDES_LONG = 103;
  SQL_MAX_CHAR_LITERAL_LEN       = 108;
  SQL_TIMEDATE_ADD_INTERVALS     = 109;
  SQL_TIMEDATE_DIFF_INTERVALS    = 110;
  SQL_NEED_LONG_DATA_LEN         = 111;
  SQL_MAX_BINARY_LITERAL_LEN     = 112;
  SQL_LIKE_ESCAPE_CLAUSE         = 113;
  SQL_QUALIFIER_LOCATION         = 114;

{$IFNDEF ODBC_Ver30}  { Above ODBC Version 2.0 and Below Version 3.0 }
  SQL_OJ_CAPABILITIES            = 65003;  { Temp value until ODBC 3.0 }
{$ENDIF} {Above ODBC_Ver20 and Below ODBC_Ver30}

{-----------------------------------------------}
{ SQL_INFO_LAST and SQL_INFO_DRIVER_START are   }
{ not useful anymore, because  X/Open has       }
{ values in the 10000 range.                    }
{ You must contact X/Open directly to get a     }
{ range	of numbers for driver-specific values.	}
{-----------------------------------------------}

{$IFNDEF ODBC_Ver30}  { Below ODBC Version 3.0 }
  SQL_INFO_LAST                  = SQL_QUALIFIER_LOCATION;
  SQL_INFO_DRIVER_START          = 1000;
{$ENDIF} {Below ODBC_Ver30}

{-----------------------------------------------}
{ ODBC 3.0 SQLGetInfo values that are not part  }
{ of the X/Open standard at this time.   X/Open }
{ standard values are in sql.pas.               }
{-----------------------------------------------}

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_ACTIVE_ENVIRONMENTS             = 116;
  SQL_ALTER_DOMAIN                    = 117;

  SQL_SQL_CONFORMANCE                 = 118;
  SQL_DATETIME_LITERALS               = 119;

  SQL_ASYNC_MODE                      = 10021;  { new X/Open spec }
  SQL_BATCH_ROW_COUNT                 = 120;
  SQL_BATCH_SUPPORT                   = 121;
  SQL_CATALOG_LOCATION                = SQL_QUALIFIER_LOCATION;
  SQL_CATALOG_NAME_SEPARATOR          = SQL_QUALIFIER_NAME_SEPARATOR;
  SQL_CATALOG_TERM                    = SQL_QUALIFIER_TERM;
  SQL_CATALOG_USAGE                   = SQL_QUALIFIER_USAGE;
  SQL_CONVERT_WCHAR                   = 122;
  SQL_CONVERT_INTERVAL_DAY_TIME       = 123;
  SQL_CONVERT_INTERVAL_YEAR_MONTH     = 124;
  SQL_CONVERT_WLONGVARCHAR            = 125;
  SQL_CONVERT_WVARCHAR                = 126;
  SQL_CREATE_ASSERTION                = 127;
  SQL_CREATE_CHARACTER_SET            = 128;
  SQL_CREATE_COLLATION                = 129;
  SQL_CREATE_DOMAIN                   = 130;
  SQL_CREATE_SCHEMA                   = 131;
  SQL_CREATE_TABLE                    = 132;
  SQL_CREATE_TRANSLATION              = 133;
  SQL_CREATE_VIEW                     = 134;
  SQL_DRIVER_HDESC                    = 135;
  SQL_DROP_ASSERTION                  = 136;
  SQL_DROP_CHARACTER_SET              = 137;
  SQL_DROP_COLLATION                  = 138;
  SQL_DROP_DOMAIN                     = 139;
  SQL_DROP_SCHEMA                     = 140;
  SQL_DROP_TABLE                      = 141;
  SQL_DROP_TRANSLATION                = 142;
  SQL_DROP_VIEW                       = 143;
  SQL_DYNAMIC_CURSOR_ATTRIBUTES1      = 144;
  SQL_DYNAMIC_CURSOR_ATTRIBUTES2      = 145;
  SQL_FORWARD_ONLY_CURSOR_ATTRIBUTES1 = 146;
  SQL_FORWARD_ONLY_CURSOR_ATTRIBUTES2 = 147;
  SQL_INDEX_KEYWORDS                  = 148;
  SQL_INFO_SCHEMA_VIEWS               = 149;
  SQL_KEYSET_CURSOR_ATTRIBUTES1       = 150;
  SQL_KEYSET_CURSOR_ATTRIBUTES2       = 151;
  SQL_MAX_ASYNC_CONCURRENT_STATEMENTS = 10022;  { new X/Open spec }
  SQL_ODBC_INTERFACE_CONFORMANCE      = 152;
  SQL_PARAM_ARRAY_ROW_COUNTS          = 153;
  SQL_PARAM_ARRAY_SELECTS             = 154;
  SQL_SCHEMA_TERM                     = SQL_OWNER_TERM;
  SQL_SCHEMA_USAGE                    = SQL_OWNER_USAGE;
  SQL_SQL92_DATETIME_FUNCTIONS        = 155;
  SQL_SQL92_FOREIGN_KEY_DELETE_RULE   = 156;
  SQL_SQL92_FOREIGN_KEY_UPDATE_RULE   = 157;
  SQL_SQL92_GRANT                     = 158;
  SQL_SQL92_NUMERIC_VALUE_FUNCTIONS   = 159;
  SQL_SQL92_PREDICATES                = 160;
  SQL_SQL92_RELATIONAL_JOIN_OPERATORS = 161;
  SQL_SQL92_REVOKE                    = 162;
  SQL_SQL92_ROW_VALUE_CONSTRUCTOR     = 163;
  SQL_SQL92_STRING_FUNCTIONS          = 164;
  SQL_SQL92_VALUE_EXPRESSIONS         = 165;
  SQL_STANDARD_CLI_CONFORMANCE        = 166;
  SQL_STATIC_CURSOR_ATTRIBUTES1       = 167;
  SQL_STATIC_CURSOR_ATTRIBUTES2       = 168;

  SQL_AGGREGATE_FUNCTIONS             = 169;
  SQL_DDL_INDEX	                      = 170;
  SQL_DM_VER                          = 171;
  SQL_INSERT_STATEMENT                = 172;
  SQL_UNION_STATEMENT                 = SQL_UNION;
{$ENDIF} {ODBC_Ver30}

{ SQL_ALTER_TABLE bitmasks }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
{ the following 5 bitmasks are defined in sql.pas
*  SQL_AT_ADD_COLUMN                  = $00000001;
*  SQL_AT_DROP_COLUMN                 = $00000002;
*  SQL_AT_ADD_CONSTRAINT              = $00000008;
}
  SQL_AT_ADD_COLUMN_SINGLE              = $00000020;
  SQL_AT_ADD_COLUMN_DEFAULT             = $00000040;
  SQL_AT_ADD_COLUMN_COLLATION           = $00000080;
  SQL_AT_SET_COLUMN_DEFAULT             = $00000100;
  SQL_AT_DROP_COLUMN_DEFAULT            = $00000200;
  SQL_AT_DROP_COLUMN_CASCADE            = $00000400;
  SQL_AT_DROP_COLUMN_RESTRICT           = $00000800;
  SQL_AT_ADD_TABLE_CONSTRAINT           = $00001000;
  SQL_AT_DROP_TABLE_CONSTRAINT_CASCADE  = $00002000;
  SQL_AT_DROP_TABLE_CONSTRAINT_RESTRICT = $00004000;
  SQL_AT_CONSTRAINT_NAME_DEFINITION     = $00008000;
  SQL_AT_CONSTRAINT_INITIALLY_DEFERRED  = $00010000;
  SQL_AT_CONSTRAINT_INITIALLY_IMMEDIATE	= $00020000;
  SQL_AT_CONSTRAINT_DEFERRABLE          = $00040000;
  SQL_AT_CONSTRAINT_NON_DEFERRABLE      = $00080000;
{$ENDIF} {ODBC_Ver30}

{ SQL_CONVERT_*  return value bitmasks }
  SQL_CVT_CHAR                        = $00000001;
  SQL_CVT_NUMERIC                     = $00000002;
  SQL_CVT_DECIMAL                     = $00000004;
  SQL_CVT_INTEGER                     = $00000008;
  SQL_CVT_SMALLINT                    = $00000010;
  SQL_CVT_FLOAT                       = $00000020;
  SQL_CVT_REAL                        = $00000040;
  SQL_CVT_DOUBLE                      = $00000080;
  SQL_CVT_VARCHAR                     = $00000100;
  SQL_CVT_LONGVARCHAR                 = $00000200;
  SQL_CVT_BINARY                      = $00000400;
  SQL_CVT_VARBINARY                   = $00000800;
  SQL_CVT_BIT                         = $00001000;
  SQL_CVT_TINYINT                     = $00002000;
  SQL_CVT_BIGINT                      = $00004000;
  SQL_CVT_DATE                        = $00008000;
  SQL_CVT_TIME                        = $00010000;
  SQL_CVT_TIMESTAMP                   = $00020000;
  SQL_CVT_LONGVARBINARY               = $00040000;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_CVT_INTERVAL_YEAR_MONTH         = $00080000;
  SQL_CVT_INTERVAL_DAY_TIME           = $00100000;
  SQL_CVT_WCHAR                       = $00200000;
  SQL_CVT_WLONGVARCHAR                = $00400000;
  SQL_CVT_WVARCHAR                    = $00800000;
{$ENDIF} {ODBC_Ver30}


{ SQL_CONVERT_FUNCTIONS functions }
  SQL_FN_CVT_CONVERT                  = $00000001;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_FN_CVT_CAST                     = $00000002;
{$ENDIF} {ODBC_Ver30}


{ SQL_STRING_FUNCTIONS functions }
  SQL_FN_STR_CONCAT                   = $00000001;
  SQL_FN_STR_INSERT                   = $00000002;
  SQL_FN_STR_LEFT                     = $00000004;
  SQL_FN_STR_LTRIM                    = $00000008;
  SQL_FN_STR_LENGTH                   = $00000010;
  SQL_FN_STR_LOCATE                   = $00000020;
  SQL_FN_STR_LCASE                    = $00000040;
  SQL_FN_STR_REPEAT                   = $00000080;
  SQL_FN_STR_REPLACE                  = $00000100;
  SQL_FN_STR_RIGHT                    = $00000200;
  SQL_FN_STR_RTRIM                    = $00000400;
  SQL_FN_STR_SUBSTRING                = $00000800;
  SQL_FN_STR_UCASE                    = $00001000;
  SQL_FN_STR_ASCII                    = $00002000;
  SQL_FN_STR_CHAR                     = $00004000;
  SQL_FN_STR_DIFFERENCE               = $00008000;
  SQL_FN_STR_LOCATE_2                 = $00010000;
  SQL_FN_STR_SOUNDEX                  = $00020000;
  SQL_FN_STR_SPACE                    = $00040000;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_FN_STR_BIT_LENGTH               = $00080000;
  SQL_FN_STR_CHAR_LENGTH              = $00100000;
  SQL_FN_STR_CHARACTER_LENGTH         = $00200000;
  SQL_FN_STR_OCTET_LENGTH             = $00400000;
  SQL_FN_STR_POSITION                 = $00800000;
{$ENDIF} {ODBC_Ver30}

{ SQL_SQL92_STRING_FUNCTIONS }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_SSF_CONVERT                     = $00000001;
  SQL_SSF_LOWER                       = $00000002;
  SQL_SSF_UPPER                       = $00000004;
  SQL_SSF_SUBSTRING                   = $00000008;
  SQL_SSF_TRANSLATE                   = $00000010;
  SQL_SSF_TRIM_BOTH                   = $00000020;
  SQL_SSF_TRIM_LEADING                = $00000040;
  SQL_SSF_TRIM_TRAILING               = $00000080;
{$ENDIF} {ODBC_Ver30}

{ SQL_NUMERIC_FUNCTIONS functions }
  SQL_FN_NUM_ABS                      = $00000001;
  SQL_FN_NUM_ACOS                     = $00000002;
  SQL_FN_NUM_ASIN                     = $00000004;
  SQL_FN_NUM_ATAN                     = $00000008;
  SQL_FN_NUM_ATAN2                    = $00000010;
  SQL_FN_NUM_CEILING                  = $00000020;
  SQL_FN_NUM_COS                      = $00000040;
  SQL_FN_NUM_COT                      = $00000080;
  SQL_FN_NUM_EXP                      = $00000100;
  SQL_FN_NUM_FLOOR                    = $00000200;
  SQL_FN_NUM_LOG                      = $00000400;
  SQL_FN_NUM_MOD                      = $00000800;
  SQL_FN_NUM_SIGN                     = $00001000;
  SQL_FN_NUM_SIN                      = $00002000;
  SQL_FN_NUM_SQRT                     = $00004000;
  SQL_FN_NUM_TAN                      = $00008000;
  SQL_FN_NUM_PI                       = $00010000;
  SQL_FN_NUM_RAND                     = $00020000;
  SQL_FN_NUM_DEGREES                  = $00040000;
  SQL_FN_NUM_LOG10                    = $00080000;
  SQL_FN_NUM_POWER                    = $00100000;
  SQL_FN_NUM_RADIANS                  = $00200000;
  SQL_FN_NUM_ROUND                    = $00400000;
  SQL_FN_NUM_TRUNCATE                 = $00800000;

{ SQL_SQL92_NUMERIC_VALUE_FUNCTIONS }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_SNVF_BIT_LENGTH                 = $00000001;
  SQL_SNVF_CHAR_LENGTH                = $00000002;
  SQL_SNVF_CHARACTER_LENGTH           = $00000004;
  SQL_SNVF_EXTRACT                    = $00000008;
  SQL_SNVF_OCTET_LENGTH               = $00000010;
  SQL_SNVF_POSITION                   = $00000020;
{$ENDIF} {ODBC_Ver30}

{ SQL_TIMEDATE_FUNCTIONS functions }
  SQL_FN_TD_NOW                       = $00000001;
  SQL_FN_TD_CURDATE                   = $00000002;
  SQL_FN_TD_DAYOFMONTH                = $00000004;
  SQL_FN_TD_DAYOFWEEK                 = $00000008;
  SQL_FN_TD_DAYOFYEAR                 = $00000010;
  SQL_FN_TD_MONTH                     = $00000020;
  SQL_FN_TD_QUARTER                   = $00000040;
  SQL_FN_TD_WEEK                      = $00000080;
  SQL_FN_TD_YEAR                      = $00000100;
  SQL_FN_TD_CURTIME                   = $00000200;
  SQL_FN_TD_HOUR                      = $00000400;
  SQL_FN_TD_MINUTE                    = $00000800;
  SQL_FN_TD_SECOND                    = $00001000;
  SQL_FN_TD_TIMESTAMPADD              = $00002000;
  SQL_FN_TD_TIMESTAMPDIFF             = $00004000;
  SQL_FN_TD_DAYNAME                   = $00008000;
  SQL_FN_TD_MONTHNAME                 = $00010000;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_FN_TD_CURRENT_DATE              = $00020000;
  SQL_FN_TD_CURRENT_TIME              = $00040000;
  SQL_FN_TD_CURRENT_TIMESTAMP         = $00080000;
  SQL_FN_TD_EXTRACT                   = $00100000;
{$ENDIF} {ODBC_Ver30}

{ SQL_SQL92_DATETIME_FUNCTIONS }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_SDF_CURRENT_DATE                = $00000001;
  SQL_SDF_CURRENT_TIME                = $00000002;
  SQL_SDF_CURRENT_TIMESTAMP           = $00000004;
{$ENDIF} {ODBC_Ver30}

{ SQL_SYSTEM_FUNCTIONS functions }
  SQL_FN_SYS_USERNAME                 = $00000001;
  SQL_FN_SYS_DBNAME                   = $00000002;
  SQL_FN_SYS_IFNULL                   = $00000004;

{ SQL_TIMEDATE_ADD_INTERVALS and SQL_TIMEDATE_DIFF_INTERVALS functions }
  SQL_FN_TSI_FRAC_SECOND              = $00000001;
  SQL_FN_TSI_SECOND                   = $00000002;
  SQL_FN_TSI_MINUTE                   = $00000004;
  SQL_FN_TSI_HOUR                     = $00000008;
  SQL_FN_TSI_DAY                      = $00000010;
  SQL_FN_TSI_WEEK                     = $00000020;
  SQL_FN_TSI_MONTH                    = $00000040;
  SQL_FN_TSI_QUARTER                  = $00000080;
  SQL_FN_TSI_YEAR                     = $00000100;

{ bitmasks for SQL_DYNAMIC_CURSOR_ATTRIBUTES1,
 * SQL_FORWARD_ONLY_CURSOR_ATTRIBUTES1,
 * SQL_KEYSET_CURSOR_ATTRIBUTES1, and SQL_STATIC_CURSOR_ATTRIBUTES1
 }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
{ supported SQLFetchScroll FetchOrientation's }
  SQL_CA1_NEXT                        = $00000001;
  SQL_CA1_ABSOLUTE                    = $00000002;
  SQL_CA1_RELATIVE                    = $00000004;
  SQL_CA1_BOOKMARK                    = $00000008;

{ supported SQLSetPos LockType's }
  SQL_CA1_LOCK_NO_CHANGE              = $00000040;
  SQL_CA1_LOCK_EXCLUSIVE              = $00000080;
  SQL_CA1_LOCK_UNLOCK                 = $00000100;

{ supported SQLSetPos Operations }
  SQL_CA1_POS_POSITION                = $00000200;
  SQL_CA1_POS_UPDATE                  = $00000400;
  SQL_CA1_POS_DELETE                  = $00000800;
  SQL_CA1_POS_REFRESH                 = $00001000;

{ positioned updates and deletes }
  SQL_CA1_POSITIONED_UPDATE           = $00002000;
  SQL_CA1_POSITIONED_DELETE           = $00004000;
  SQL_CA1_SELECT_FOR_UPDATE           = $00008000;

{ supported SQLBulkOperations operations }
  SQL_CA1_BULK_ADD                    = $00010000;
  SQL_CA1_BULK_UPDATE_BY_BOOKMARK     = $00020000;
  SQL_CA1_BULK_DELETE_BY_BOOKMARK     = $00040000;
  SQL_CA1_BULK_FETCH_BY_BOOKMARK      = $00080000;
{$ENDIF} {ODBC_Ver30}

{ bitmasks for SQL_DYNAMIC_CURSOR_ATTRIBUTES2,
 * SQL_FORWARD_ONLY_CURSOR_ATTRIBUTES2,
 * SQL_KEYSET_CURSOR_ATTRIBUTES2, and SQL_STATIC_CURSOR_ATTRIBUTES2
 }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
{ supported values for SQL_ATTR_SCROLL_CONCURRENCY }
  SQL_CA2_READ_ONLY_CONCURRENCY       = $00000001;
  SQL_CA2_LOCK_CONCURRENCY            = $00000002;
  SQL_CA2_OPT_ROWVER_CONCURRENCY      = $00000004;
  SQL_CA2_OPT_VALUES_CONCURRENCY      = $00000008;

{ sensitivity of the cursor to its own inserts, deletes, and updates }
  SQL_CA2_SENSITIVITY_ADDITIONS       = $00000010;
  SQL_CA2_SENSITIVITY_DELETIONS       = $00000020;
  SQL_CA2_SENSITIVITY_UPDATES         = $00000040;

{ semantics of SQL_ATTR_MAX_ROWS }
  SQL_CA2_MAX_ROWS_SELECT             = $00000080;
  SQL_CA2_MAX_ROWS_INSERT             = $00000100;
  SQL_CA2_MAX_ROWS_DELETE             = $00000200;
  SQL_CA2_MAX_ROWS_UPDATE             = $00000400;
  SQL_CA2_MAX_ROWS_CATALOG            = $00000800;
  SQL_CA2_MAX_ROWS_AFFECTS_ALL        = (SQL_CA2_MAX_ROWS_SELECT or
                                         SQL_CA2_MAX_ROWS_INSERT or
                                         SQL_CA2_MAX_ROWS_DELETE or
                                         SQL_CA2_MAX_ROWS_UPDATE or
                                         SQL_CA2_MAX_ROWS_CATALOG);

{ semantics of SQL_DIAG_CURSOR_ROW_COUNT }
  SQL_CA2_CRC_EXACT                   = $00001000;
  SQL_CA2_CRC_APPROXIMATE             = $00002000;

{ the kinds of positioned statements that can be simulated }
  SQL_CA2_SIMULATE_NON_UNIQUE         = $00004000;
  SQL_CA2_SIMULATE_TRY_UNIQUE         = $00008000;
  SQL_CA2_SIMULATE_UNIQUE             = $00010000;
{$ENDIF} {ODBC_Ver30}

{ SQL_ODBC_API_CONFORMANCE values }
  SQL_OAC_NONE                        = $0000;
  SQL_OAC_LEVEL1                      = $0001;
  SQL_OAC_LEVEL2                      = $0002;

{ SQL_ODBC_SAG_CLI_CONFORMANCE values }
  SQL_OSCC_NOT_COMPLIANT              = $0000;
  SQL_OSCC_COMPLIANT                  = $0001;

{ SQL_ODBC_SQL_CONFORMANCE values }
  SQL_OSC_MINIMUM                     = $0000;
  SQL_OSC_CORE                        = $0001;
  SQL_OSC_EXTENDED                    = $0002;

{ SQL_CONCAT_NULL_BEHAVIOR values }
  SQL_CB_NULL                         = $0000;
  SQL_CB_NON_NULL                     = $0001;

{ SQL_SCROLL_OPTIONS masks }
  SQL_SO_FORWARD_ONLY                 = $00000001;
  SQL_SO_KEYSET_DRIVEN                = $00000002;
  SQL_SO_DYNAMIC                      = $00000004;
  SQL_SO_MIXED                        = $00000008;
  SQL_SO_STATIC                       = $00000010;

{ SQL_FETCH_DIRECTION masks }

{ SQL_FETCH_RESUME is no longer supported }
{$IFNDEF ODBC_Ver30}  { Below ODBC Version 3.0 }
  SQL_FD_FETCH_RESUME                 = $00000040;
{$ENDIF} {Below ODBC_Ver30}

  SQL_FD_FETCH_BOOKMARK               = $00000080;

{ SQL_TXN_ISOLATION_OPTION masks }
{ SQL_TXN_VERSIONING is no longer supported }
{$IFNDEF ODBC_Ver30}  { Below ODBC Version 3.0 }
  SQL_TXN_VERSIONING                  = $00000010;
{$ENDIF} {Below ODBC_Ver30}

{ SQL_CORRELATION_NAME values }
  SQL_CN_NONE                         = $0000;
  SQL_CN_DIFFERENT                    = $0001;
  SQL_CN_ANY                          = $0002;

{ SQL_NON_NULLABLE_COLUMNS values }
  SQL_NNC_NULL                        = $0000;
  SQL_NNC_NON_NULL                    = $0001;

{ SQL_NULL_COLLATION values }
  SQL_NC_START                        = $0002;
  SQL_NC_END                          = $0004;

{ SQL_FILE_USAGE values }
  SQL_FILE_NOT_SUPPORTED              = $0000;
  SQL_FILE_TABLE                      = $0001;
  SQL_FILE_QUALIFIER                  = $0002;
  SQL_FILE_CATALOG                    = SQL_FILE_QUALIFIER;  { ODBC 3.0 }


{ SQL_GETDATA_EXTENSIONS values }
  SQL_GD_BLOCK                        = $00000004;
  SQL_GD_BOUND                        = $00000008;

{ SQL_POSITIONED_STATEMENTS masks }
  SQL_PS_POSITIONED_DELETE            = $00000001;
  SQL_PS_POSITIONED_UPDATE            = $00000002;
  SQL_PS_SELECT_FOR_UPDATE            = $00000004;

{ SQL_GROUP_BY values }
  SQL_GB_NOT_SUPPORTED                = $0000;
  SQL_GB_GROUP_BY_EQUALS_SELECT       = $0001;
  SQL_GB_GROUP_BY_CONTAINS_SELECT     = $0002;
  SQL_GB_NO_RELATION                  = $0003;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_GB_COLLATE                      = $0004;
{$ENDIF} {ODBC_Ver30}

{ SQL_OWNER_USAGE masks }

  SQL_OU_DML_STATEMENTS               = $00000001;
  SQL_OU_PROCEDURE_INVOCATION         = $00000002;
  SQL_OU_TABLE_DEFINITION             = $00000004;
  SQL_OU_INDEX_DEFINITION             = $00000008;
  SQL_OU_PRIVILEGE_DEFINITION         = $00000010;

{ SQL_SCHEMA_USAGE masks }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_SU_DML_STATEMENTS               = SQL_OU_DML_STATEMENTS;
  SQL_SU_PROCEDURE_INVOCATION         = SQL_OU_PROCEDURE_INVOCATION;
  SQL_SU_TABLE_DEFINITION             = SQL_OU_TABLE_DEFINITION;
  SQL_SU_INDEX_DEFINITION             = SQL_OU_INDEX_DEFINITION;
  SQL_SU_PRIVILEGE_DEFINITION         = SQL_OU_PRIVILEGE_DEFINITION;
{$ENDIF} {ODBC_Ver30}

{ SQL_QUALIFIER_USAGE masks }
  SQL_QU_DML_STATEMENTS               = $00000001;
  SQL_QU_PROCEDURE_INVOCATION         = $00000002;
  SQL_QU_TABLE_DEFINITION             = $00000004;
  SQL_QU_INDEX_DEFINITION             = $00000008;
  SQL_QU_PRIVILEGE_DEFINITION         = $00000010;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
{ SQL_CATALOG_USAGE masks }
  SQL_CU_DML_STATEMENTS               = SQL_QU_DML_STATEMENTS;
  SQL_CU_PROCEDURE_INVOCATION         = SQL_QU_PROCEDURE_INVOCATION;
  SQL_CU_TABLE_DEFINITION             = SQL_QU_TABLE_DEFINITION;
  SQL_CU_INDEX_DEFINITION             = SQL_QU_INDEX_DEFINITION;
  SQL_CU_PRIVILEGE_DEFINITION         = SQL_QU_PRIVILEGE_DEFINITION;
{$ENDIF} {ODBC_Ver30}

{ SQL_SUBQUERIES masks }
  SQL_SQ_COMPARISON                   = $00000001;
  SQL_SQ_EXISTS                       = $00000002;
  SQL_SQ_IN                           = $00000004;
  SQL_SQ_QUANTIFIED                   = $00000008;
  SQL_SQ_CORRELATED_SUBQUERIES        = $00000010;


{ SQL_UNION masks }
  SQL_U_UNION                         = $00000001;
  SQL_U_UNION_ALL                     = $00000002;


{ SQL_BOOKMARK_PERSISTENCE values }
  SQL_BP_CLOSE                        = $00000001;
  SQL_BP_DELETE                       = $00000002;
  SQL_BP_DROP                         = $00000004;
  SQL_BP_TRANSACTION                  = $00000008;
  SQL_BP_UPDATE                       = $00000010;
  SQL_BP_OTHER_HSTMT                  = $00000020;
  SQL_BP_SCROLL                       = $00000040;

{ SQL_STATIC_SENSITIVITY values }
  SQL_SS_ADDITIONS                    = $00000001;
  SQL_SS_DELETIONS                    = $00000002;
  SQL_SS_UPDATES                      = $00000004;

{ SQL_VIEW values }
  SQL_CV_CREATE_VIEW                  = $00000001;
  SQL_CV_CHECK_OPTION                 = $00000002;
  SQL_CV_CASCADED                     = $00000004;
  SQL_CV_LOCAL                        = $00000008;

{ SQL_LOCK_TYPES masks }
  SQL_LCK_NO_CHANGE                   = $00000001;
  SQL_LCK_EXCLUSIVE                   = $00000002;
  SQL_LCK_UNLOCK                      = $00000004;

{ SQL_POS_OPERATIONS masks }
  SQL_POS_POSITION                    = $00000001;
  SQL_POS_REFRESH                     = $00000002;
  SQL_POS_UPDATE                      = $00000004;
  SQL_POS_DELETE                      = $00000008;
  SQL_POS_ADD                         = $00000010;

{ SQL_QUALIFIER_LOCATION values }
  SQL_QL_START                        = $0001;
  SQL_QL_END                          = $0002;


{ Here start return values for ODBC 3.0 SQLGetInfo }

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
{ SQL_AGGREGATE_FUNCTIONS bitmasks }
  SQL_AF_AVG                          = $00000001;
  SQL_AF_COUNT                        = $00000002;
  SQL_AF_MAX                          = $00000004;
  SQL_AF_MIN                          = $00000008;
  SQL_AF_SUM                          = $00000010;
  SQL_AF_DISTINCT                     = $00000020;
  SQL_AF_ALL                          = (SQL_AF_AVG or SQL_AF_COUNT or
                                         SQL_AF_MAX or SQL_AF_MIN or
                                         SQL_AF_SUM or SQL_AF_DISTINCT);

{ SQL_SQL_CONFORMANCE bit masks }
  SQL_SC_SQL92_ENTRY                  = $00000001;
  SQL_SC_FIPS127_2_TRANSITIONAL       = $00000002;
  SQL_SC_SQL92_INTERMEDIATE           = $00000004;
  SQL_SC_SQL92_FULL                   = $00000008;

{ SQL_DATETIME_LITERALS masks }
  SQL_DL_SQL92_DATE                      = $00000001;
  SQL_DL_SQL92_TIME                      = $00000002;
  SQL_DL_SQL92_TIMESTAMP                 = $00000004;
  SQL_DL_SQL92_INTERVAL_YEAR             = $00000008;
  SQL_DL_SQL92_INTERVAL_MONTH            = $00000010;
  SQL_DL_SQL92_INTERVAL_DAY              = $00000020;
  SQL_DL_SQL92_INTERVAL_HOUR             = $00000040;
  SQL_DL_SQL92_INTERVAL_MINUTE           = $00000080;
  SQL_DL_SQL92_INTERVAL_SECOND           = $00000100;
  SQL_DL_SQL92_INTERVAL_YEAR_TO_MONTH    = $00000200;
  SQL_DL_SQL92_INTERVAL_DAY_TO_HOUR      = $00000400;
  SQL_DL_SQL92_INTERVAL_DAY_TO_MINUTE    = $00000800;
  SQL_DL_SQL92_INTERVAL_DAY_TO_SECOND    = $00001000;
  SQL_DL_SQL92_INTERVAL_HOUR_TO_MINUTE   = $00002000;
  SQL_DL_SQL92_INTERVAL_HOUR_TO_SECOND   = $00004000;
  SQL_DL_SQL92_INTERVAL_MINUTE_TO_SECOND = $00008000;

{ SQL_CATALOG_LOCATION values }
  SQL_CL_START                        = SQL_QL_START;
  SQL_CL_END                          = SQL_QL_END;

{ values for SQL_BATCH_ROW_COUNT }
  SQL_BRC_PROCEDURES                  = $0000001;
  SQL_BRC_EXPLICIT                    = $0000002;
  SQL_BRC_ROLLED_UP                   = $0000004;

{ bitmasks for SQL_BATCH_SUPPORT }
  SQL_BS_SELECT_EXPLICIT              = $00000001;
  SQL_BS_ROW_COUNT_EXPLICIT           = $00000002;
  SQL_BS_SELECT_PROC                  = $00000004;
  SQL_BS_ROW_COUNT_PROC               = $00000008;

{ Values for SQL_PARAM_ARRAY_ROW_COUNTS getinfo }
  SQL_PARC_BATCH                      = 1;
  SQL_PARC_NO_BATCH                   = 2;

{ values for SQL_PARAM_ARRAY_SELECT_BATCH}
  SQL_PAS_BATCH                       = 1;
  SQL_PAS_NO_BATCH                    = 2;
  SQL_PAS_NO_SELECT                   = 3;

{ Bitmasks for SQL_INDEX_KEYWORDS }
  SQL_IK_NONE                         = $00000000;
  SQL_IK_ASC                          = $00000001;
  SQL_IK_DESC                         = $00000002;
  SQL_IK_ALL                          = (SQL_IK_ASC or SQL_IK_DESC);

{ Bitmasks for SQL_INFO_SCHEMA_VIEWS }
  SQL_ISV_ASSERTIONS                  = $00000001;
  SQL_ISV_CHARACTER_SETS              = $00000002;
  SQL_ISV_CHECK_CONSTRAINTS           = $00000004;
  SQL_ISV_COLLATIONS                  = $00000008;
  SQL_ISV_COLUMN_DOMAIN_USAGE         = $00000010;
  SQL_ISV_COLUMN_PRIVILEGES           = $00000020;
  SQL_ISV_COLUMNS                     = $00000040;
  SQL_ISV_CONSTRAINT_COLUMN_USAGE     = $00000080;
  SQL_ISV_CONSTRAINT_TABLE_USAGE      = $00000100;
  SQL_ISV_DOMAIN_CONSTRAINTS          = $00000200;
  SQL_ISV_DOMAINS                     = $00000400;
  SQL_ISV_KEY_COLUMN_USAGE            = $00000800;
  SQL_ISV_REFERENTIAL_CONSTRAINTS     = $00001000;
  SQL_ISV_SCHEMATA                    = $00002000;
  SQL_ISV_SQL_LANGUAGES               = $00004000;
  SQL_ISV_TABLE_CONSTRAINTS           = $00008000;
  SQL_ISV_TABLE_PRIVILEGES            = $00010000;
  SQL_ISV_TABLES                      = $00020000;
  SQL_ISV_TRANSLATIONS                = $00040000;
  SQL_ISV_USAGE_PRIVILEGES            = $00080000;
  SQL_ISV_VIEW_COLUMN_USAGE           = $00100000;
  SQL_ISV_VIEW_TABLE_USAGE            = $00200000;
  SQL_ISV_VIEWS                       = $00400000;

{ Bitmasks for SQL_ASYNC_MODE }
  SQL_AM_NONE                         = 0;
  SQL_AM_CONNECTION	              = 1;
  SQL_AM_STATEMENT	              = 2;

{ Bitmasks for SQL_ALTER_DOMAIN }
  SQL_AD_CONSTRAINT_NAME_DEFINITION         = $00000001;
  SQL_AD_ADD_DOMAIN_CONSTRAINT              = $00000002;
  SQL_AD_DROP_DOMAIN_CONSTRAINT             = $00000004;
  SQL_AD_ADD_DOMAIN_DEFAULT                 = $00000008;
  SQL_AD_DROP_DOMAIN_DEFAULT                = $00000010;
  SQL_AD_ADD_CONSTRAINT_INITIALLY_DEFERRED  = $00000020;
  SQL_AD_ADD_CONSTRAINT_INITIALLY_IMMEDIATE = $00000040;
  SQL_AD_ADD_CONSTRAINT_DEFERRABLE          = $00000080;
  SQL_AD_ADD_CONSTRAINT_NON_DEFERRABLE      = $00000100;


{ SQL_CREATE_SCHEMA bitmasks }
  SQL_CS_CREATE_SCHEMA                      = $00000001;
  SQL_CS_AUTHORIZATION                      = $00000002;
  SQL_CS_DEFAULT_CHARACTER_SET              = $00000004;

{ SQL_CREATE_TRANSLATION bitmasks }
  SQL_CTR_CREATE_TRANSLATION                = $00000001;

{ SQL_CREATE_ASSERTION bitmasks }
  SQL_CA_CREATE_ASSERTION                   = $00000001;
  SQL_CA_CONSTRAINT_INITIALLY_DEFERRED      = $00000010;
  SQL_CA_CONSTRAINT_INITIALLY_IMMEDIATE     = $00000020;
  SQL_CA_CONSTRAINT_DEFERRABLE              = $00000040;
  SQL_CA_CONSTRAINT_NON_DEFERRABLE          = $00000080;

{ SQL_CREATE_CHARACTER_SET bitmasks }
  SQL_CCS_CREATE_CHARACTER_SET              = $00000001;
  SQL_CCS_COLLATE_CLAUSE                    = $00000002;
  SQL_CCS_LIMITED_COLLATION                 = $00000004;

{ SQL_CREATE_COLLATION bitmasks }
  SQL_CCOL_CREATE_COLLATION                 = $00000001;

{ SQL_CREATE_DOMAIN bitmasks }
  SQL_CDO_CREATE_DOMAIN                     = $00000001;
  SQL_CDO_DEFAULT                           = $00000002;
  SQL_CDO_CONSTRAINT                        = $00000004;
  SQL_CDO_COLLATION                         = $00000008;
  SQL_CDO_CONSTRAINT_NAME_DEFINITION        = $00000010;
  SQL_CDO_CONSTRAINT_INITIALLY_DEFERRED     = $00000020;
  SQL_CDO_CONSTRAINT_INITIALLY_IMMEDIATE    = $00000040;
  SQL_CDO_CONSTRAINT_DEFERRABLE             = $00000080;
  SQL_CDO_CONSTRAINT_NON_DEFERRABLE         = $00000100;

{ SQL_CREATE_TABLE bitmasks }
  SQL_CT_CREATE_TABLE                       = $00000001;
  SQL_CT_COMMIT_PRESERVE                    = $00000002;
  SQL_CT_COMMIT_DELETE                      = $00000004;
  SQL_CT_GLOBAL_TEMPORARY                   = $00000008;
  SQL_CT_LOCAL_TEMPORARY                    = $00000010;
  SQL_CT_CONSTRAINT_INITIALLY_DEFERRED      = $00000020;
  SQL_CT_CONSTRAINT_INITIALLY_IMMEDIATE     = $00000040;
  SQL_CT_CONSTRAINT_DEFERRABLE              = $00000080;
  SQL_CT_CONSTRAINT_NON_DEFERRABLE          = $00000100;
  SQL_CT_COLUMN_CONSTRAINT                  = $00000200;
  SQL_CT_COLUMN_DEFAULT                     = $00000400;
  SQL_CT_COLUMN_COLLATION                   = $00000800;
  SQL_CT_TABLE_CONSTRAINT                   = $00001000;
  SQL_CT_CONSTRAINT_NAME_DEFINITION         = $00002000;

{ SQL_DDL_INDEX bitmasks }
  SQL_DI_CREATE_INDEX                 = $00000001;
  SQL_DI_DROP_INDEX                   = $00000002;

{ SQL_DROP_COLLATION bitmasks }
  SQL_DC_DROP_COLLATION               = $00000001;

{ SQL_DROP_DOMAIN bitmasks }
  SQL_DD_DROP_DOMAIN                  = $00000001;
  SQL_DD_RESTRICT                     = $00000002;
  SQL_DD_CASCADE                      = $00000004;

{ SQL_DROP_SCHEMA bitmasks }
  SQL_DS_DROP_SCHEMA                  = $00000001;
  SQL_DS_RESTRICT                     = $00000002;
  SQL_DS_CASCADE                      = $00000004;

{ SQL_DROP_CHARACTER_SET bitmasks }
  SQL_DCS_DROP_CHARACTER_SET          = $00000001;

{ SQL_DROP_ASSERTION bitmasks }
  SQL_DA_DROP_ASSERTION               = $00000001;

{ SQL_DROP_TABLE bitmasks }
  SQL_DT_DROP_TABLE                   = $00000001;
  SQL_DT_RESTRICT                     = $00000002;
  SQL_DT_CASCADE                      = $00000004;

{ SQL_DROP_TRANSLATION bitmasks }
  SQL_DTR_DROP_TRANSLATION            = $00000001;

{ SQL_DROP_VIEW bitmasks }
  SQL_DV_DROP_VIEW                    = $00000001;
  SQL_DV_RESTRICT                     = $00000002;
  SQL_DV_CASCADE                      = $00000004;

{ SQL_INSERT_STATEMENT bitmasks }
  SQL_IS_INSERT_LITERALS              = $00000001;
  SQL_IS_INSERT_SEARCHED              = $00000002;
  SQL_IS_SELECT_INTO                  = $00000004;

{ SQL_ODBC_INTERFACE_CONFORMANCE values }
  SQL_OIC_CORE                        = ULONG(1);
  SQL_OIC_LEVEL1                      = ULONG(2);
  SQL_OIC_LEVEL2                      = ULONG(3);

{ SQL_SQL92_FOREIGN_KEY_DELETE_RULE bitmasks }
  SQL_SFKD_CASCADE                    = $00000001;
  SQL_SFKD_NO_ACTION                  = $00000002;
  SQL_SFKD_SET_DEFAULT                = $00000004;
  SQL_SFKD_SET_NULL                   = $00000008;

{ SQL_SQL92_FOREIGN_KEY_UPDATE_RULE bitmasks }
  SQL_SFKU_CASCADE                    = $00000001;
  SQL_SFKU_NO_ACTION                  = $00000002;
  SQL_SFKU_SET_DEFAULT                = $00000004;
  SQL_SFKU_SET_NULL                   = $00000008;

{ SQL_SQL92_GRANT bitmasks }
  SQL_SG_USAGE_ON_DOMAIN              = $00000001;
  SQL_SG_USAGE_ON_CHARACTER_SET       = $00000002;
  SQL_SG_USAGE_ON_COLLATION           = $00000004;
  SQL_SG_USAGE_ON_TRANSLATION         = $00000008;
  SQL_SG_WITH_GRANT_OPTION            = $00000010;
  SQL_SG_DELETE_TABLE                 = $00000020;
  SQL_SG_INSERT_TABLE                 = $00000040;
  SQL_SG_INSERT_COLUMN                = $00000080;
  SQL_SG_REFERENCES_TABLE             = $00000100;
  SQL_SG_REFERENCES_COLUMN            = $00000200;
  SQL_SG_SELECT_TABLE                 = $00000400;
  SQL_SG_UPDATE_TABLE                 = $00000800;
  SQL_SG_UPDATE_COLUMN                = $00001000;

{ SQL_SQL92_PREDICATES bitmasks }
  SQL_SP_EXISTS                       = $00000001;
  SQL_SP_ISNOTNULL                    = $00000002;
  SQL_SP_ISNULL                       = $00000004;
  SQL_SP_MATCH_FULL                   = $00000008;
  SQL_SP_MATCH_PARTIAL                = $00000010;
  SQL_SP_MATCH_UNIQUE_FULL            = $00000020;
  SQL_SP_MATCH_UNIQUE_PARTIAL         = $00000040;
  SQL_SP_OVERLAPS                     = $00000080;
  SQL_SP_UNIQUE                       = $00000100;
  SQL_SP_LIKE                         = $00000200;
  SQL_SP_IN                           = $00000400;
  SQL_SP_BETWEEN                      = $00000800;
  SQL_SP_COMPARISON                   = $00001000;
  SQL_SP_QUANTIFIED_COMPARISON        = $00002000;

{ SQL_SQL92_RELATIONAL_JOIN_OPERATORS bitmasks }
  SQL_SRJO_CORRESPONDING_CLAUSE       = $00000001;
  SQL_SRJO_CROSS_JOIN                 = $00000002;
  SQL_SRJO_EXCEPT_JOIN                = $00000004;
  SQL_SRJO_FULL_OUTER_JOIN            = $00000008;
  SQL_SRJO_INNER_JOIN                 = $00000010;
  SQL_SRJO_INTERSECT_JOIN             = $00000020;
  SQL_SRJO_LEFT_OUTER_JOIN            = $00000040;
  SQL_SRJO_NATURAL_JOIN               = $00000080;
  SQL_SRJO_RIGHT_OUTER_JOIN           = $00000100;
  SQL_SRJO_UNION_JOIN                 = $00000200;

{ SQL_SQL92_REVOKE bitmasks }
  SQL_SR_USAGE_ON_DOMAIN              = $00000001;
  SQL_SR_USAGE_ON_CHARACTER_SET       = $00000002;
  SQL_SR_USAGE_ON_COLLATION           = $00000004;
  SQL_SR_USAGE_ON_TRANSLATION         = $00000008;
  SQL_SR_GRANT_OPTION_FOR             = $00000010;
  SQL_SR_CASCADE                      = $00000020;
  SQL_SR_RESTRICT                     = $00000040;
  SQL_SR_DELETE_TABLE                 = $00000080;
  SQL_SR_INSERT_TABLE                 = $00000100;
  SQL_SR_INSERT_COLUMN                = $00000200;
  SQL_SR_REFERENCES_TABLE             = $00000400;
  SQL_SR_REFERENCES_COLUMN            = $00000800;
  SQL_SR_SELECT_TABLE                 = $00001000;
  SQL_SR_UPDATE_TABLE                 = $00002000;
  SQL_SR_UPDATE_COLUMN                = $00004000;

{ SQL_SQL92_ROW_VALUE_CONSTRUCTOR bitmasks }
  SQL_SRVC_VALUE_EXPRESSION           = $00000001;
  SQL_SRVC_NULL                       = $00000002;
  SQL_SRVC_DEFAULT                    = $00000004;
  SQL_SRVC_ROW_SUBQUERY               = $00000008;

{ SQL_SQL92_VALUE_EXPRESSIONS bitmasks }
  SQL_SVE_CASE                        = $00000001;
  SQL_SVE_CAST                        = $00000002;
  SQL_SVE_COALESCE                    = $00000004;
  SQL_SVE_NULLIF                      = $00000008;

{ SQL_STANDARD_CLI_CONFORMANCE bitmasks }
  SQL_SCC_XOPEN_CLI_VERSION1          = $00000001;
  SQL_SCC_ISO92_CLI                   = $00000002;

{ SQL_UNION_STATEMENT bitmasks }
  SQL_US_UNION                        = SQL_U_UNION;
  SQL_US_UNION_ALL                    = SQL_U_UNION_ALL;

{$ENDIF} {ODBC_Ver30}

{ additional SQLDataSources fetch directions }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_FETCH_FIRST_USER                = 31;
  SQL_FETCH_FIRST_SYSTEM              = 32;
{$ENDIF} {ODBC_Ver30}


{ Defines for SQLSetPos }
  SQL_ENTIRE_ROWSET                   = 0;

{ Operations in SQLSetPos }
  SQL_POSITION                        = 0;  {  1.0 FALSE  }
  SQL_REFRESH                         = 1;  {  1.0 TRUE   }
  SQL_UPDATE                          = 2;
  SQL_DELETE                          = 3;

{ Operations in SQLBulkOperations }
  SQL_ADD                             = 4;
  SQL_SETPOS_MAX_OPTION_VALUE         = SQL_ADD;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_UPDATE_BY_BOOKMARK              = 5;
  SQL_DELETE_BY_BOOKMARK              = 6;
  SQL_FETCH_BY_BOOKMARK               = 7;
{$ENDIF} {ODBC_Ver30}

{ Lock options in SQLSetPos }
  SQL_LOCK_NO_CHANGE                  = 0;  {  1.0 FALSE  }
  SQL_LOCK_EXCLUSIVE                  = 1;  {  1.0 TRUE   }
  SQL_LOCK_UNLOCK                     = 2;

  SQL_SETPOS_MAX_LOCK_VALUE           = SQL_LOCK_UNLOCK;

{ Macro compatibility functions for SQLSetPos }
function SQL_POSITION_TO(hstmt: SQLHSTMT; irow: SQLUSMALLINT): SQLRETURN;
function SQL_LOCK_RECORD(hstmt: SQLHSTMT; irow, fLock: SQLUSMALLINT): SQLRETURN;
function SQL_REFRESH_RECORD(hstmt: SQLHSTMT; irow, fLock: SQLUSMALLINT): SQLRETURN;
function SQL_UPDATE_RECORD(hstmt: SQLHSTMT; irow: SQLUSMALLINT): SQLRETURN;
function SQL_DELETE_RECORD(hstmt: SQLHSTMT; irow: SQLUSMALLINT): SQLRETURN;
function SQL_ADD_RECORD(hstmt: SQLHSTMT; irow: SQLUSMALLINT): SQLRETURN;

const

{ Column types and scopes in SQLSpecialColumns. }
  SQL_BEST_ROWID                 = 1;
  SQL_ROWVER                     = 2;

{ Defines for SQLSpecialColumns (returned in the result set) }
{   SQL_PC_UNKNOWN and SQL_PC_PSEUDO are defined in sql.pas   }
  SQL_PC_NOT_PSEUDO              = 1;

{ Defines for SQLStatistics }
  SQL_QUICK                      = 0;
  SQL_ENSURE                     = 1;

{ Defines for SQLStatistics (returned in the result set)           }
{   SQL_INDEX_CLUSTERED, SQL_INDEX_HASHED, and SQL_INDEX_OTHER are }
{   defined in sql.pas                                             }
  SQL_TABLE_STAT                 = 0;


{ Defines for SQLTables }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_ALL_CATALOGS               = '%';
  SQL_ALL_SCHEMAS                = '%';
  SQL_ALL_TABLE_TYPES            = '%';
{$ENDIF} {ODBC_Ver30}

{ Options for SQLDriverConnect }
  SQL_DRIVER_NOPROMPT            = 0;
  SQL_DRIVER_COMPLETE            = 1;
  SQL_DRIVER_PROMPT              = 2;
  SQL_DRIVER_COMPLETE_REQUIRED   = 3;


function SQLDriverConnect(
               hdbc: SQLHDBC;
               hwnd: SQLHWND;
               szConnStrIn: PSQLCHAR;
               cbConnStrIn: SQLSMALLINT;
               szConnStrOut: PSQLCHAR;
               cbConnStrOutMax: SQLSMALLINT;
               pcbConnStrOut: PSQLSMALLINT;
               fDriverCompletion: SQLUSMALLINT
         ): SQLRETURN; stdcall;


{ Level 2 Functions }

const

{ SQLExtendedFetch "fFetchType" values }
  SQL_FETCH_BOOKMARK             = 8;

{ SQLExtendedFetch "rgfRowStatus" element values }
  SQL_ROW_SUCCESS                = 0;
  SQL_ROW_DELETED                = 1;
  SQL_ROW_UPDATED                = 2;
  SQL_ROW_NOROW                  = 3;
  SQL_ROW_ADDED                  = 4;
  SQL_ROW_ERROR                  = 5;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_ROW_SUCCESS_WITH_INFO      = 6;
  SQL_ROW_PROCEED                = 0;
  SQL_ROW_IGNORE                 = 1;
{$ENDIF} {ODBC_Ver30}

{ value for SQL_DESC_ARRAY_STATUS_PTR }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_PARAM_SUCCESS              = 0;
  SQL_PARAM_SUCCESS_WITH_INFO    = 6;
  SQL_PARAM_ERROR                = 5;
  SQL_PARAM_UNUSED               = 7;
  SQL_PARAM_DIAG_UNAVAILABLE     = 1;

  SQL_PARAM_PROCEED              = 0;
  SQL_PARAM_IGNORE               = 1;
{$ENDIF} {ODBC_Ver30}

{ Defines for SQLForeignKeys (returned in result set) }
  SQL_CASCADE                    = 0;
  SQL_RESTRICT                   = 1;
  SQL_SET_NULL                   = 2;
{$IFDEF ODBC_Ver25}  { ODBC Version 2.5 and above }
  SQL_NO_ACTION                  = 3;
  SQL_SET_DEFAULT                = 4;
{$ENDIF} {ODBC_Ver25}
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQL_INITIALLY_DEFERRED         = 5;
  SQL_INITIALLY_IMMEDIATE        = 6;
{$ENDIF} {ODBC_Ver30}

{ Defines for SQLBindParameter and                    }
{   SQLProcedureColumns (returned in the result set)  }
  SQL_PARAM_TYPE_UNKNOWN         = 0;
  SQL_PARAM_INPUT                = 1;
  SQL_PARAM_INPUT_OUTPUT         = 2;
  SQL_RESULT_COL                 = 3;
  SQL_PARAM_OUTPUT               = 4;
  SQL_RETURN_VALUE               = 5;

{ Defines used by Driver Manager when mapping SQLSetParam to  }
{   SQLBindParameter                                          }
  SQL_PARAM_TYPE_DEFAULT         = SQL_PARAM_INPUT_OUTPUT;
  SQL_SETPARAM_VALUE_MAX         = LongInt(-1);

{ Defines for SQLProcedures (returned in the result set) }
  SQL_PT_UNKNOWN                 = 0;
  SQL_PT_PROCEDURE               = 1;
  SQL_PT_FUNCTION                = 2;


{ This define is too large for RC }
  SQL_ODBC_KEYWORDS =
    'ABSOLUTE,ACTION,ADA,ADD,ALL,ALLOCATE,ALTER,AND,ANY,ARE,AS,' +
    'ASC,ASSERTION,AT,AUTHORIZATION,AVG,' +
    'BEGIN,BETWEEN,BIT,BIT_LENGTH,BOTH,BY,CASCADE,CASCADED,CASE,CAST,CATALOG,' +
    'CHAR,CHAR_LENGTH,CHARACTER,CHARACTER_LENGTH,CHECK,CLOSE,COALESCE,' +
    'COLLATE,COLLATION,COLUMN,COMMIT,CONNECT,CONNECTION,CONSTRAINT,' +
    'CONSTRAINTS,CONTINUE,CONVERT,CORRESPONDING,COUNT,CREATE,CROSS,CURRENT,' +
    'CURRENT_DATE,CURRENT_TIME,CURRENT_TIMESTAMP,CURRENT_USER,CURSOR,' +
    'DATE,DAY,DEALLOCATE,DEC,DECIMAL,DECLARE,DEFAULT,DEFERRABLE,' +
    'DEFERRED,DELETE,DESC,DESCRIBE,DESCRIPTOR,DIAGNOSTICS,DISCONNECT,' +
    'DISTINCT,DOMAIN,DOUBLE,DROP,' +
    'ELSE,END,END-EXEC,ESCAPE,EXCEPT,EXCEPTION,EXEC,EXECUTE,' +
    'EXISTS,EXTERNAL,EXTRACT,' +
    'FALSE,FETCH,FIRST,FLOAT,FOR,FOREIGN,FORTRAN,FOUND,FROM,FULL,' +
    'GET,GLOBAL,GO,GOTO,GRANT,GROUP,HAVING,HOUR,' +
    'IDENTITY,IMMEDIATE,IN,INCLUDE,INDEX,INDICATOR,INITIALLY,INNER,' +
    'INPUT,INSENSITIVE,INSERT,INT,INTEGER,INTERSECT,INTERVAL,INTO,IS,ISOLATION,' +
    'JOIN,KEY,LANGUAGE,LAST,LEADING,LEFT,LEVEL,LIKE,LOCAL,LOWER,' +
    'MATCH,MAX,MIN,MINUTE,MODULE,MONTH,' +
    'NAMES,NATIONAL,NATURAL,NCHAR,NEXT,NO,NONE,NOT,NULL,NULLIF,NUMERIC,' +
    'OCTET_LENGTH,OF,ON,ONLY,OPEN,OPTION,OR,ORDER,OUTER,OUTPUT,OVERLAPS,' +
    'PAD,PARTIAL,PASCAL,PLI,POSITION,PRECISION,PREPARE,PRESERVE,' +
    'PRIMARY,PRIOR,PRIVILEGES,PROCEDURE,PUBLIC,' +
    'READ,REAL,REFERENCES,RELATIVE,RESTRICT,REVOKE,RIGHT,ROLLBACK,ROWS' +
    'SCHEMA,SCROLL,SECOND,SECTION,SELECT,SESSION,SESSION_USER,SET,SIZE,' +
    'SMALLINT,SOME,SPACE,SQL,SQLCA,SQLCODE,SQLERROR,SQLSTATE,SQLWARNING,' +
    'SUBSTRING,SUM,SYSTEM_USER,' +
    'TABLE,TEMPORARY,THEN,TIME,TIMESTAMP,TIMEZONE_HOUR,TIMEZONE_MINUTE,' +
    'TO,TRAILING,TRANSACTION,TRANSLATE,TRANSLATION,TRIM,TRUE,' +
    'UNION,UNIQUE,UNKNOWN,UPDATE,UPPER,USAGE,USER,USING,' +
    'VALUE,VALUES,VARCHAR,VARYING,VIEW,WHEN,WHENEVER,WHERE,WITH,WORK,WRITE,' +
    'YEAR,ZONE';

function SQLBrowseConnect(
               hdbc: SQLHDBC;
               szConnStrIn: PSQLCHAR;
               cbConnStrIn: SQLSMALLINT;
               szConnStrOut: PSQLCHAR;
               cbConnStrOutMax: SQLSMALLINT;
               pcbConnStrOut: PSQLSMALLINT
         ): SQLRETURN; stdcall;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLBulkOperations(
              StatementHandle: SQLHSTMT;
              Operation: SQLSMALLINT
         ): SQLRETURN; stdcall;
{$ENDIF} {ODBC_Ver30}

function SQLColAttributes(
               hstmt: SQLHSTMT;
               icol: SQLUSMALLINT;
               fDescType: SQLUSMALLINT;
               rgbDesc: SQLPOINTER;
               cbDescMax: SQLSMALLINT;
               pcbDesc: PSQLSMALLINT;
               pfDesc: PSQLINTEGER
         ): SQLRETURN; stdcall;

function SQLColumnPrivileges(
               hstmt: SQLHSTMT;
               szCatalogName: PSQLCHAR;
               cbCatalogName: SQLSMALLINT;
               szSchemaName: PSQLCHAR;
               cbSchemaName: SQLSMALLINT;
               szTableName: PSQLCHAR;
               cbTableName: SQLSMALLINT;
               szColumnName: PSQLCHAR;
               cbColumnName: SQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLDescribeParam(
               hstmt: SQLHSTMT;
               ipar: SQLUSMALLINT;
               pfSqlType: PSQLSMALLINT;
               pcbParamDef: PSQLUINTEGER;
               pibScale,
               pfNullable: PSQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLExtendedFetch(
               hstmt: SQLHSTMT;
               fFetchType: SQLUSMALLINT;
               irow: SQLINTEGER;
               pcrow: PSQLUINTEGER;
               rgfRowStatus: PSQLUSMALLINT
         ): SQLRETURN; stdcall;

function SQLForeignKeys(
               hstmt: SQLHSTMT;
               szPkCatalogName: PSQLCHAR;
               cbPkCatalogName: SQLSMALLINT;
               szPkSchemaName: PSQLCHAR;
               cbPkSchemaName: SQLSMALLINT;
               szPkTableName: PSQLCHAR;
               cbPkTableName: SQLSMALLINT;
               szFkCatalogName: PSQLCHAR;
               cbFkCatalogName: SQLSMALLINT;
               szFkSchemaName: PSQLCHAR;
               cbFkSchemaName: SQLSMALLINT;
               szFkTableName: PSQLCHAR;
               cbFkTableName: SQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLMoreResults(
               hstmt: SQLHSTMT
         ): SQLRETURN; stdcall;

function SQLNativeSql(
               hdbc: SQLHDBC;
               szSqlStrIn: PSQLCHAR;
               cbSqlStrIn: SQLINTEGER;
               szSqlStr: PSQLCHAR;
               cbSqlStrMax: SQLINTEGER;
               pcbSqlStr: PSQLINTEGER
         ): SQLRETURN; stdcall;

function SQLNumParams(
               hstmt: SQLHSTMT;
               pcpar: PSQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLParamOptions(
               hstmt: SQLHSTMT;
               crow: SQLUINTEGER;
               pirow: PSQLUINTEGER
         ): SQLRETURN; stdcall;

function SQLPrimaryKeys(
               hstmt: SQLHSTMT;
               szCatalogName: PSQLCHAR;
               cbCatalogName: SQLSMALLINT;
               szSchemaName: PSQLCHAR;
               cbSchemaName: SQLSMALLINT;
               szTableName: PSQLCHAR;
               cbTableName: SQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLProcedureColumns(
               hstmt: SQLHSTMT;
               szCatalogName: PSQLCHAR;
               cbCatalogName: SQLSMALLINT;
               szSchemaName: PSQLCHAR;
               cbSchemaName: SQLSMALLINT;
               szProcName: PSQLCHAR;
               cbProcName: SQLSMALLINT;
               szColumnName: PSQLCHAR;
               cbColumnName: SQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLProcedures(
               hstmt: SQLHSTMT;
               szCatalogName: PSQLCHAR;
               cbCatalogName: SQLSMALLINT;
               szSchemaName: PSQLCHAR;
               cbSchemaName: SQLSMALLINT;
               szProcName: PSQLCHAR;
               cbProcName: SQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLSetPos(
               hstmt: SQLHSTMT;
               irow,
               fOption,
               fLock: SQLUSMALLINT
         ): SQLRETURN; stdcall;

function SQLTablePrivileges(
               hstmt: SQLHSTMT;
               szCatalogName: PSQLCHAR;
               cbCatalogName: SQLSMALLINT;
               szSchemaName: PSQLCHAR;
               cbSchemaName: SQLSMALLINT;
               szTableName: PSQLCHAR;
               cbTableName: SQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLDrivers(
               henv: SQLHENV;
               fDirection: SQLUSMALLINT;
               szDriverDesc: PSQLCHAR;
               cbDriverDescMax: SQLSMALLINT;
               pcbDriverDesc: PSQLSMALLINT;
               szDriverAttributes: PSQLCHAR;
               cbDrvrAttrMax: SQLSMALLINT;
               pcbDrvrAttr: PSQLSMALLINT
         ): SQLRETURN; stdcall;

function SQLBindParameter(
               hstmt: SQLHSTMT;
               ipar: SQLUSMALLINT;
               fParamType,
               fCType,
               fSqlType: SQLSMALLINT;
               cbColDef: SQLUINTEGER;
               ibScale: SQLSMALLINT;
               rgbValue: SQLPOINTER;
               cbValueMax: SQLINTEGER;
               pcbValue: PSQLINTEGER
         ): SQLRETURN; stdcall;


{---------------------------------------------------------}
{ SQLAllocHandleStd is implemented to make SQLAllocHandle }
{ compatible with X/Open standard. An application should  }
{ not call SQLAllocHandleStd directly.                    }
{---------------------------------------------------------}
{$IFDEF ODBC_STD}
function SQLAllocHandle(
               fHandleType: SQLSMALLINT;
               hInput: SQLHANDLE;
               phOutput: PSQLHANDLE
         ): SQLRETURN;

function SQLAllocEnv(
               fHandleType: SQLSMALLINT;
               hInput: SQLHANDLE;
               phenv: PSQLHANDLE
         ): SQLRETURN;

         
{ Internal type subcodes }
  SQL_YEAR                       = SQL_CODE_YEAR;
  SQL_MONTH                      = SQL_CODE_MONTH;
  SQL_DAY                        = SQL_CODE_DAY;
  SQL_HOUR                       = SQL_CODE_HOUR;
  SQL_MINUTE                     = SQL_CODE_MINUTE;
  SQL_SECOND                     = SQL_CODE_SECOND;
  SQL_YEAR_TO_MONTH              = SQL_CODE_YEAR_TO_MONTH;
  SQL_DAY_TO_HOUR                = SQL_CODE_DAY_TO_HOUR;
  SQL_DAY_TO_MINUTE              = SQL_CODE_DAY_TO_MINUTE;
  SQL_DAY_TO_SECOND              = SQL_CODE_DAY_TO_SECOND;
  SQL_HOUR_TO_MINUTE             = SQL_CODE_HOUR_TO_MINUTE;
  SQL_HOUR_TO_SECOND             = SQL_CODE_HOUR_TO_SECOND;
  SQL_MINUTE_TO_SECOND           = SQL_CODE_MINUTE_TO_SECOND;
{$ENDIF} {ODBC_STD}

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLAllocHandleStd(
               fHandleType: SQLSMALLINT;
               hInput: SQLHANDLE;
               phOutput: PSQLHANDLE
         ): SQLRETURN; stdcall;
{$ENDIF} {ODBC_Ver30}


const

{ Deprecated defines from prior versions of ODBC }
  SQL_DATABASE_NAME              = 16;  { Use SQLGetConnectOption/SQL_CURRENT_QUALIFIER }
  SQL_FD_FETCH_PREV              = SQL_FD_FETCH_PRIOR;
  SQL_FETCH_PREV                 = SQL_FETCH_PRIOR;
  SQL_CONCUR_TIMESTAMP           = SQL_CONCUR_ROWVER;
  SQL_SCCO_OPT_TIMESTAMP         = SQL_SCCO_OPT_ROWVER;
  SQL_CC_DELETE                  = SQL_CB_DELETE;
  SQL_CR_DELETE                  = SQL_CB_DELETE;
  SQL_CC_CLOSE                   = SQL_CB_CLOSE;
  SQL_CR_CLOSE                   = SQL_CB_CLOSE;
  SQL_CC_PRESERVE                = SQL_CB_PRESERVE;
  SQL_CR_PRESERVE                = SQL_CB_PRESERVE;
{ SQL_FETCH_RESUME is not supported by 2.0+ drivers  }
{$IFNDEF ODBC_Ver30}  { Below ODBC Version 3.0 }
  SQL_FETCH_RESUME                = 7;
{$ENDIF} {Below ODBC_Ver30}
  SQL_SCROLL_FORWARD_ONLY         =  0;  {-SQL_CURSOR_FORWARD_ONLY }
  SQL_SCROLL_KEYSET_DRIVEN        = -1;  {-SQL_CURSOR_KEYSET_DRIVEN }
  SQL_SCROLL_DYNAMIC              = -2;  {-SQL_CURSOR_DYNAMIC }
  SQL_SCROLL_STATIC               = -3;  {-SQL_CURSOR_STATIC }

{ Deprecated functions from prior versions of ODBC }

function SQLSetScrollOptions(    { Use SQLSetStmtOptions }
               hstmt: SQLHSTMT;
               fConcurrency: SQLUSMALLINT;
               crowKeyset: SQLINTEGER;
               crowRowset: SQLUSMALLINT
         ): SQLRETURN; stdcall;


const

{ Tracing section }

  TRACE_VERSION = 1000;  { Version of trace API }


function  TraceOpenLogFile(                    { open a trace log file }
             a, b: LPWSTR; c: DWORD): RETCODE; stdcall;
function  TraceCloseLogFile: RETCODE; stdcall; { Request to close a trace log }
procedure TraceReturn(                         { Processes trace after FN is called }
             rc1, rc2: RETCODE); stdcall;
function  TraceVersion: DWORD; stdcall;        { Returns trace API version }

const
  ODSGT32  = 'odsgt32.dll';
  ODBC32   = 'odbc32.dll';
  ODBCTRAC = 'odbctrac.dll';

implementation

//uses
//{$IFDEF WIN32}
  //SqlUCode;      <-- Need this once SqlUcode compiles
//{$ENDIF}

function SQLDriverConnect;    external ODSGT32 name 'SQLDriverConnect';
function SQLBrowseConnect;    external ODBC32  name 'SQLBrowseConnect';
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLBulkOperations;   external ODBC32  name 'SQLBulkOperations';
{$ENDIF} {ODBC_Ver30}
function SQLColAttributes;    external ODSGT32 name 'SQLColAttributes';
function SQLColumnPrivileges; external ODSGT32 name 'SQLColumnPrivileges';
function SQLDescribeParam;    external ODSGT32 name 'SQLDescribeParam';
function SQLExtendedFetch;    external ODSGT32 name 'SQLExtendedFetch';
function SQLForeignKeys;      external ODSGT32 name 'SQLForeignKeys';
function SQLMoreResults;      external ODSGT32 name 'SQLMoreResults';
function SQLNativeSql;        external ODSGT32 name 'SQLNativeSql';
function SQLNumParams;        external ODSGT32 name 'SQLNumParams';
function SQLParamOptions;     external ODSGT32 name 'SQLParamOptions';
function SQLPrimaryKeys;      external ODSGT32 name 'SQLPrimaryKeys';
function SQLProcedureColumns; external ODSGT32 name 'SQLProcedureColumns';
function SQLProcedures;       external ODSGT32 name 'SQLProcedures';
function SQLSetPos;           external ODSGT32 name 'SQLSetPos';
function SQLTablePrivileges;  external ODSGT32 name 'SQLTablePrivileges';
function SQLDrivers;          external ODBC32  name 'SQLDrivers';
function SQLBindParameter;    external ODSGT32 name 'SQLBindParameter';
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQLAllocHandleStd;   external ODBC32  name 'SQLAllocHandleStd';
{$ENDIF} {ODBC_Ver30}
function SQLSetScrollOptions; external ODSGT32 name 'SQLSetScrollOptions';


function TraceOpenLogFile;    external ODBCTRAC name 'TraceOpenLogFile';
function TraceCloseLogFile;   external ODBCTRAC name 'TraceCloseLogFile';
procedure TraceReturn;        external ODBCTRAC name 'TraceReturn';
function TraceVersion;        external ODBCTRAC name 'TraceVersion';


function SQL_LEN_DATA_AT_EXEC(length: Integer): Integer;
begin
  result := -(length) + SQL_LEN_DATA_AT_EXEC_OFFSET;
end;

function SQL_LEN_BINARY_ATTR(length: Integer): Integer;
begin
  result := -(length) + SQL_LEN_BINARY_ATTR_OFFSET;
end;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
function SQL_FUNC_EXISTS(pfExists: PUWORD; uwAPI: UWORD): SQLINTEGER;
begin
  Inc(pfExists, uwAPI shr 4);
  if (pfExists^ and (1 shl (uwAPI and $000F))) <> 0 then
    result := SQL_TRUE
  else
    result := SQL_FALSE;
end;
{$ENDIF} {ODBC_Ver30}

function SQL_POSITION_TO(hstmt: SQLHSTMT; irow: SQLUSMALLINT): SQLRETURN;
begin
  result := SQLSetPos(hstmt,irow,SQL_POSITION,SQL_LOCK_NO_CHANGE);
end;

function SQL_LOCK_RECORD(hstmt: SQLHSTMT; irow, fLock: SQLUSMALLINT): SQLRETURN;
begin
  result := SQLSetPos(hstmt,irow,SQL_POSITION,fLock);
end;

function SQL_REFRESH_RECORD(hstmt: SQLHSTMT; irow, fLock: SQLUSMALLINT): SQLRETURN;
begin
  result := SQLSetPos(hstmt,irow,SQL_REFRESH,fLock);
end;

function SQL_UPDATE_RECORD(hstmt: SQLHSTMT; irow: SQLUSMALLINT): SQLRETURN;
begin
  result := SQLSetPos(hstmt,irow,SQL_UPDATE,SQL_LOCK_NO_CHANGE);
end;

function SQL_DELETE_RECORD(hstmt: SQLHSTMT; irow: SQLUSMALLINT): SQLRETURN;
begin
  result := SQLSetPos(hstmt,irow,SQL_DELETE,SQL_LOCK_NO_CHANGE);
end;

function SQL_ADD_RECORD(hstmt: SQLHSTMT; irow: SQLUSMALLINT): SQLRETURN;
begin
  result := SQLSetPos(hstmt,irow,SQL_ADD,SQL_LOCK_NO_CHANGE);
end;

{$IFDEF ODBC_STD}
function SQLAllocHandle(fHandleType: SQLSMALLINT; hInput: SQLHANDLE; phOutput: PSQLHANDLE): SQLRETURN;
begin
   result := SQLAllocHandleStd(fHandleType, hInput, phOutput);
end;

function SQLAllocEnv(fHandleType: SQLSMALLINT; hInput: SQLHANDLE; phenv: PSQLHANDLE): SQLRETURN;
begin
  result := SQLAllocHandleStd(SQL_HANDLE_ENV, SQL_NULL_HANDLE, phenv);
end;
{$ENDIF} {ODBC_STD}

end.

