unit SqlFront;

interface

uses
{$IFDEF WIN32}
  Windows;
{$ELSE}
  WinTypes, WinProcs;
{$ENDIF}

{ ------------------------------------------------------------------- }
{                                                                     }
{  SQLFRONT.PAS - DB-Library unit file for the Microsoft SQL Server.  }
{                                                                     }
{  Copyright (c) 1989 - 1995 by Microsoft Corp.  All rights reserved. }
{                                                                     }
{ All constant and macro definitions for DB-Library applications      }
{ programming are contained in this file.  This file must be included }
{ before SQLDB.PAS and one of the following $defines must be made,    }
{ depending on the operating system: DBMSDOS, DBMSWIN or DBNTWIN32.   }
{                                                                     }
{ Translated From: ODBCINST.H                                         }
{ Last Modified: 12/19/1997                                           }
{ Version: 1.0                                                        }
{ ------------------------------------------------------------------- }

{ ------------------------------------------------------------------- }
{                          Datatype definitions                       }
{ ------------------------------------------------------------------- }

{ Note this has changed because Windows 3.1 defines API as 'pascal far' }

{ ------------------------------------------------------------------- }
{                     DBPROCESS, LOGINREC and DBCURSOR                }
{ ------------------------------------------------------------------- }

type

{  Windows NT Specific  }
{$IFDEF WIN32}
  PDBPROCESS = Pointer;
  PLOGINREC  = Pointer;
  PDBCURSOR  = Pointer;
  PDBHANDLE  = Pointer;
  PTR = Pointer;
  TSqlFarProc = function: Integer; cdecl;
{$ELSE}
{  WIN 3.x Specific.  The handle pointers are near for Windows 3.x  }
  PDBPROCESS = Pointer;
  PLOGINREC  = Pointer;
  PDBCURSOR  = Pointer;
  PDBHANDLE  = Pointer;
  PTR = Pointer;
  TLgFarProc = function: LongInt; pascal; far;
{$ENDIF} {WIN32}


{ ------------------------------------------------------------------- }
{ Win32 compatibility datatype definitions                            }
{ Note: The following datatypes are provided for Win32 compatibility. }
{ Since some of the datatypes are already defined in unrelated include}
{ files there may definition duplication. Every attempt has been made }
{ to check for such problems.                                         }
{ ------------------------------------------------------------------- }

{$IFNDEF WIN32}

  LPINT = ^Integer;

// typedef       CHAR PTR LPSTR;
// typedef       BYTE PTR LPBYTE;
  LPVOID = Pointer;
// typedef const CHAR PTR LPCSTR;
  BOOL = Integer;

{$ENDIF} {WIN32}


{ ------------------------------------------------------------------- }
{                     DB-Library datatype definitions                 }
{ ------------------------------------------------------------------- }

const
  DBMAXCHAR = 256;   { Max length of TDbVarBinary and TDbVarChar, etc. }

{$IFNDEF DBTYPEDEFS} { srv.h (Open Server include) not already included }

{$DEFINE DBTYPEDEFS}

type
  RETCODE = Integer;
  STATUS  = Integer;

{  DB-Library datatypes  }
  DBCHAR = Char;
  DBBINARY = UCHAR;
  DBTINYINT = UCHAR;
  DBSMALLINT = SHORT;
  USHORT = Word;
  DBUSMALLINT = USHORT;
  DBINT = LongInt;
  DBFLT8 = Double;
  DBBIT = UCHAR;
  DBBOOL = UCHAR;
  DBFLT4 = Single;
  DBMONEY4 = LongInt;

  DBREAL = DBFLT4;
  DBUBOOL = UINT;

  TDbDateTime4 = record
    numdays: USHORT;  {  No. of days since Jan-1-1900   }
    nummins: USHORT;  {  No. of minutes since midnight  }
  end;


  TDbVaryChar = record
    len: DBSMALLINT;
    str: array[0..DBMAXCHAR-1] of DBCHAR;
  end;

  TDbVaryBin = record
    len: DBSMALLINT;
    array_: array[0..DBMAXCHAR-1] of BYTE;
  end;

  TDbMoney = record
    mnyhigh: DBINT;
    mnylow: ULONG;
  end;

  PDbDateTime = ^TDbDateTime;
  TDbDateTime = record
    dtdays: DBINT;
    dttime: ULONG;
  end;

{   DBDATEREC structure used by dbdatecrack  }
  PDbDateRec = ^TDbDateRec;
  TDbDateRec = record
    year: Integer;         { 1753 - 9999             }
    quarter: Integer;      { 1 - 4                   }
    month: Integer;        { 1 - 12                  }
    dayofyear: Integer;    { 1 - 366                 }
    day: Integer;          { 1 - 31                  }
    week: Integer;         { 1 - 54 (for leap years) }
    weekday: Integer;      { 1 - 7  (Mon - Sun)      }
    hour: Integer;         { 0 - 23                  }
    minute: Integer;       { 0 - 59                  }
    second: Integer;       { 0 - 59                  }
    millisecond: Integer;  { 0 - 999                 }
  end;

const
  MAXNUMERICLEN = 16;
  MAXNUMERICDIG = 38;

  DEFAULTPRECISION = 18;
  DEFAULTSCALE     = 0;

type

  TDbNumeric = record
    precision: Byte;
    scale: Byte;
    sign: Byte;   {  1 = Positive, 0 = Negative  }
    val: array[0..MAXNUMERICLEN-1] of Byte;
  end;

  TDbDecimal = TDbNumeric;


{  Pack the following structures on a word boundary  }
{$A+}

const
  MAXCOLNAMELEN = 30;
  MAXTABLENAME  = 30;

type
  PDbCol = ^TDbCol;
  LPDbCol = PDbCol;
  TDbCol = record
    SizeOfStruct: DBINT;
    Name:       array[0..MAXCOLNAMELEN] of Char;
    ActualName: array[0..MAXCOLNAMELEN] of Char;
    TableName:  array[0..MAXTABLENAME]  of Char;
    Typ: SHORT;
    UserType: DBINT;
    MaxLength: DBINT;
    Precision: Byte;
    Scale: Byte;
    VarLength: BOOL;     { TRUE, FALSE }
    Null: Byte;          { TRUE, FALSE or DBUNKNOWN }
    CaseSensitive: Byte; { TRUE, FALSE or DBUNKNOWN }
    Updatable: Byte;     { TRUE, FALSE or DBUNKNOWN }
    Identity: BOOL;      { TRUE, FALSE }
  end;

const
  MAXSERVERNAME    = 30;
  MAXNETLIBNAME    = 255;
  MAXNETLIBCONNSTR = 255;

type
  PDbProcInfo = ^TDbProcInfo;
  LPDbProcInfo = PDbProcInfo;
  TDbProcInfo = record
    SizeOfStruct: DBINT;
    ServerType: Byte;
    ServerMajor: USHORT;
    ServerMinor: USHORT;
    ServerRevision: USHORT;
    ServerName: array[0..MAXSERVERNAME] of Char;
    NetLibName: array[0..MAXNETLIBNAME] of Char;
    NetLibConnStr: array[0..MAXNETLIBCONNSTR] of Char;
  end;

  PDbCursorInfo = ^TDbCursorInfo;
  LPDbCursorInfo = PDbCursorInfo;
  TDbCursorInfo = record
    SizeOfStruct: DBINT;   { Use sizeof(DBCURSORINFO)     }
    TotCols: ULONG;        { Total Columns in cursor      }
    TotRows: ULONG;        { Total Rows in cursor         }
    CurRow: ULONG;         { Current actual row in server }
    TotRowsFetched: ULONG; { Total rows actually fetched  }
    Typ: ULONG;            { See CU_...                   }
    Status: ULONG;         { See CU_...                   }
  end;

const
  INVALID_UROWNUM = ULONG(-1);

{  Reset default alignment  }

{$ENDIF} {DBTYPEDEFS}


{ ------------------------------------------------------------------- }
{                            Pointer Datatypes                        }
{ ------------------------------------------------------------------- }
type
  LPINT = PInteger;
//typedef const LPINT          LPCINT;
  LPCINT = LPINT;
  LPBYTE = PByte;
//typedef const LPBYTE         LPCBYTE ;
  LPCBYTE = LPBYTE;
//typedef       USHORT PTR     LPUSHORT;
  LPUSHORT = ^USHORT;
//typedef const LPUSHORT       LPCUSHORT;
  LPCUSHORT = LPUSHORT;
//typedef       DBINT PTR      LPDBINT;
  LPDBINT = ^DBINT;
//typedef const LPDBINT        LPCDBINT;
  LPCDBINT = LPDBINT;
//typedef       DBBINARY PTR   LPDBBINARY;
  LPDBBINARY = ^DBBINARY;
//typedef const LPDBBINARY     LPCDBBINARY;
  LPCDBBINARY = LPDBBINARY;
//typedef       DBDATEREC PTR  LPDBDATEREC;
  LPDbDateRec = PDbDateRec;
//typedef const LPDBDATEREC    LPCDBDATEREC;
  LPCDBDATEREC = LPDBDATEREC;
//typedef       DBDATETIME PTR LPDBDATETIME;
  LPDBDATETIME = PDbDateTime;
//typedef const LPDBDATETIME   LPCDBDATETIME;
  LPCDBDATETIME = LPDBDATETIME;


{ ------------------------------------------------------------------- }
{                            General Constants                        }
{ ------------------------------------------------------------------- }

const
  TIMEOUT_IGNORE   = ULONG(-1);
  TIMEOUT_INFINITE = ULONG(0);
  TIMEOUT_MAXIMUM  = ULONG(1200);  { 20 minutes maximum timeout value }

{  Used for ServerType in TDbGetProcInfo  }
  SERVTYPE_UNKNOWN   = 0;
  SERVTYPE_MICROSOFT = 1;

type
{  Used by TDbColInfo  }
  CI_TYPES = (CI_UKNOWN, CI_REGULAR, CI_ALTERNATE, CI_CURSOR);

const
{  Bulk Copy Definitions (bcp)  }
  DB_IN  = 1;    { Transfer from client to server }
  DB_OUT = 2;    { Transfer from server to client }

  BCPMAXERRS   = 1;    { bcp_control parameter }
  BCPFIRST     = 2;    { bcp_control parameter }
  BCPLAST      = 3;    { bcp_control parameter }
  BCPBATCH     = 4;    { bcp_control parameter }
  BCPKEEPNULLS = 5;    { bcp_control parameter }
  BCPABORT     = 6;    { bcp_control parameter }

  TINYBIND        = 1;
  SMALLBIND       = 2;
  INTBIND         = 3;
  CHARBIND        = 4;
  BINARYBIND      = 5;
  BITBIND         = 6;
  DATETIMEBIND    = 7;
  MONEYBIND       = 8;
  FLT8BIND        = 9;
  STRINGBIND      = 10;
  NTBSTRINGBIND   = 11;
  VARYCHARBIND    = 12;
  VARYBINBIND     = 13;
  FLT4BIND        = 14;
  SMALLMONEYBIND  = 15;
  SMALLDATETIBIND = 16;
  DECIMALBIND     = 17;
  NUMERICBIND     = 18;
  SRCDECIMALBIND  = 19;
  SRCNUMERICBIND  = 20;
  MAXBIND         = SRCNUMERICBIND;

  DBSAVE          = 1;
  DBNOSAVE        = 0;

  DBNOERR         = -1;
  DBFINDONE       = $04;  { Definately done }
  DBMORE          = $10;  { Maybe more commands waiting }
  DBMORE_ROWS     = $20;  { This command returned rows  }

  MAXNAME         = 31;

  DBTXTSLEN       = 8;    { Timestamp length }

  DBTXPLEN        = 16;   { Text pointer length }

{  Error code returns  }
  INT_EXIT        = 0;
  INT_CONTINUE    = 1;
  INT_CANCEL      = 2;


{  dboptions  }
  DBBUFFER        = 0;
  DBOFFSET        = 1;
  DBROWCOUNT      = 2;
  DBSTAT          = 3;
  DBTEXTLIMIT     = 4;
  DBTEXTSIZE      = 5;
  DBARITHABORT    = 6;
  DBARITHIGNORE   = 7;
  DBNOAUTOFREE    = 8;
  DBNOCOUNT       = 9;
  DBNOEXEC        = 10;
  DBPARSEONLY     = 11;
  DBSHOWPLAN      = 12;
  DBSTORPROCID    = 13;

// #if defined(DBMSWIN) || defined(DBNTWIN32)
{$IFDEF WIN32}
  DBANSItoOEM = 14;
{$ELSE} {$IFDEF WINDOWS}
  DBANSItoOEM = 14;
{$ENDIF}
{$ENDIF}

{$IFDEF DBNTWIN32}
  DBOEMtoANSI = 15;
{$ENDIF}

  DBCLIENTCURSORS = 16;
  DBSETTIME       = 17;
  DBQUOTEDIDENT   = 18;


{  Data Type Tokens  }
  SQLVOID         = $1f;
  SQLTEXT         = $23;
  SQLVARBINARY    = $25;
  SQLINTN         = $26;
  SQLVARCHAR      = $27;
  SQLBINARY       = $2d;
  SQLIMAGE        = $22;
  SQLCHAR         = $2f;
  SQLINT1         = $30;
  SQLBIT          = $32;
  SQLINT2         = $34;
  SQLINT4         = $38;
  SQLMONEY        = $3c;
  SQLDATETIME     = $3d;
  SQLFLT8         = $3e;
  SQLFLTN         = $6d;
  SQLMONEYN       = $6e;
  SQLDATETIMN     = $6f;
  SQLFLT4         = $3b;
  SQLMONEY4       = $7a;
  SQLDATETIM4     = $3a;
  SQLDECIMAL      = $6a;
  SQLNUMERIC      = $6c;

{  Data stream tokens  }
  SQLCOLFMT       = $a1;
  OLD_SQLCOLFMT   = $2a;
  SQLPROCID       = $7c;
  SQLCOLNAME      = $a0;
  SQLTABNAME      = $a4;
  SQLCOLINFO      = $a5;
  SQLALTNAME      = $a7;
  SQLALTFMT       = $a8;
  SQLERROR        = $aa;
  SQLINFO         = $ab;
  SQLRETURNVALUE  = $ac;
  SQLRETURNSTATUS = $79;
  SQLRETURN       = $db;
  SQLCONTROL      = $ae;
  SQLALTCONTROL   = $af;
  SQLROW          = $d1;
  SQLALTROW       = $d3;
  SQLDONE         = $fd;
  SQLDONEPROC     = $fe;
  SQLDONEINPROC   = $ff;
  SQLOFFSET       = $78;
  SQLORDER        = $a9;
  SQLLOGINACK     = $ad;  { NOTICE: change to real value }

{  Ag op tokens  }
  SQLAOPCNT       = $4b;
  SQLAOPSUM       = $4d;
  SQLAOPAVG       = $4f;
  SQLAOPMIN       = $51;
  SQLAOPMAX       = $52;
  SQLAOPANY       = $53;
  SQLAOPNOOP      = $56;

{  Error numbers (dberrs) DB-Library error codes  }
  SQLEMEM         = 10000;
  SQLENULL        = 10001;
  SQLENLOG        = 10002;
  SQLEPWD         = 10003;
  SQLECONN        = 10004;
  SQLEDDNE        = 10005;
  SQLENULLO       = 10006;
  SQLESMSG        = 10007;
  SQLEBTOK        = 10008;
  SQLENSPE        = 10009;
  SQLEREAD        = 10010;
  SQLECNOR        = 10011;
  SQLETSIT        = 10012;
  SQLEPARM        = 10013;
  SQLEAUTN        = 10014;
  SQLECOFL        = 10015;
  SQLERDCN        = 10016;
  SQLEICN         = 10017;
  SQLECLOS        = 10018;
  SQLENTXT        = 10019;
  SQLEDNTI        = 10020;
  SQLETMTD        = 10021;
  SQLEASEC        = 10022;
  SQLENTLL        = 10023;
  SQLETIME        = 10024;
  SQLEWRIT        = 10025;
  SQLEMODE        = 10026;
  SQLEOOB         = 10027;
  SQLEITIM        = 10028;
  SQLEDBPS        = 10029;
  SQLEIOPT        = 10030;
  SQLEASNL        = 10031;
  SQLEASUL        = 10032;
  SQLENPRM        = 10033;
  SQLEDBOP        = 10034;
  SQLENSIP        = 10035;
  SQLECNULL       = 10036;
  SQLESEOF        = 10037;
  SQLERPND        = 10038;
  SQLECSYN        = 10039;
  SQLENONET       = 10040;
  SQLEBTYP        = 10041;
  SQLEABNC        = 10042;
  SQLEABMT        = 10043;
  SQLEABNP        = 10044;
  SQLEBNCR        = 10045;
  SQLEAAMT        = 10046;
  SQLENXID        = 10047;
  SQLEIFNB        = 10048;
  SQLEKBCO        = 10049;
  SQLEBBCI        = 10050;
  SQLEKBCI        = 10051;
  SQLEBCWE        = 10052;
  SQLEBCNN        = 10053;
  SQLEBCOR        = 10054;
  SQLEBCPI        = 10055;
  SQLEBCPN        = 10056;
  SQLEBCPB        = 10057;
  SQLEVDPT        = 10058;
  SQLEBIVI        = 10059;
  SQLEBCBC        = 10060;
  SQLEBCFO        = 10061;
  SQLEBCVH        = 10062;
  SQLEBCUO        = 10063;
  SQLEBUOE        = 10064;
  SQLEBWEF        = 10065;
  SQLEBTMT        = 10066;
  SQLEBEOF        = 10067;
  SQLEBCSI        = 10068;
  SQLEPNUL        = 10069;
  SQLEBSKERR      = 10070;
  SQLEBDIO        = 10071;
  SQLEBCNT        = 10072;
  SQLEMDBP        = 10073;
  SQLINIT         = 10074;
  SQLCRSINV       = 10075;
  SQLCRSCMD       = 10076;
  SQLCRSNOIND     = 10077;
  SQLCRSDIS       = 10078;
  SQLCRSAGR       = 10079;
  SQLCRSORD       = 10080;
  SQLCRSMEM       = 10081;
  SQLCRSBSKEY     = 10082;
  SQLCRSNORES     = 10083;
  SQLCRSVIEW      = 10084;
  SQLCRSBUFR      = 10085;
  SQLCRSFROWN     = 10086;
  SQLCRSBROL      = 10087;
  SQLCRSFRAND     = 10088;
  SQLCRSFLAST     = 10089;
  SQLCRSRO        = 10090;
  SQLCRSTAB       = 10091;
  SQLCRSUPDTAB    = 10092;
  SQLCRSUPDNB     = 10093;
  SQLCRSVIIND     = 10094;
  SQLCRSNOUPD     = 10095;
  SQLCRSOS2       = 10096;
  SQLEBCSA        = 10097;
  SQLEBCRO        = 10098;
  SQLEBCNE        = 10099;
  SQLEBCSK        = 10100;
  SQLEUVBF        = 10101;
  SQLEBIHC        = 10102;
  SQLEBWFF        = 10103;
  SQLNUMVAL       = 10104;
  SQLEOLDVR       = 10105;
  SQLEBCPS        = 10106;
  SQLEDTC         = 10107;
  SQLENOTIMPL     = 10108;
  SQLENONFLOAT    = 10109;
  SQLECONNFB      = 10110;


{  The severity levels are defined here  }
  EXINFO          = 1;  { Informational, non-error }
  EXUSER          = 2;  { User error }
  EXNONFATAL      = 3;  { Non-fatal error }
  EXCONVERSION    = 4;  { Error in DB-LIBRARY data conversion }
  EXSERVER        = 5;  { The Server has returned an error flag }
  EXTIME          = 6;  { We have exceeded our timeout period while       }
                           { waiting for a response from the Server - the }
                           { DBPROCESS is still alive                     }
  EXPROGRAM       = 7;  { Coding error in user program }
  EXRESOURCE      = 8;  { Running out of resources - the DBPROCESS may be dead }
  EXCOMM          = 9;  { Failure in communication with Server - the DBPROCESS is dead }
  EXFATAL         = 10; { Fatal error - the DBPROCESS is dead }
  EXCONSISTENCY   = 11; { Internal software error  - notify MS Technical Support }

{  Offset identifiers  }
  OFF_SELECT      = $16d;
  OFF_FROM        = $14f;
  OFF_ORDER       = $165;
  OFF_COMPUTE     = $139;
  OFF_TABLE       = $173;
  OFF_PROCEDURE   = $16a;
  OFF_STATEMENT   = $1cb;
  OFF_PARAM       = $1c4;
  OFF_EXEC        = $12c;

{  Print lengths for certain fixed length data types  }
  PRINT4     = 11;
  PRINT2     = 6;
  PRINT1     = 3;
  PRFLT8     = 20;
  PRMONEY    = 26;
  PRBIT      = 3;
  PRDATETIME = 27;
  PRDECIMAL  = (MAXNUMERICDIG + 2);
  PRNUMERIC  = (MAXNUMERICDIG + 2);

  SUCCEED       = 1;
  FAIL          = 0;
  SUCCEED_ABORT = 2;

  DBUNKNOWN = 2;

  MORE_ROWS    = -1;
  NO_MORE_ROWS = -2;
  REG_ROW      = MORE_ROWS;
  BUF_FULL     = -3;

{  Status code for dbresults(). Possible return values are  }
{  SUCCEED, FAIL, and NO_MORE_RESULTS.                      }
  NO_MORE_RESULTS     = 2;
  NO_MORE_RPC_RESULTS = 3;

{  Macros for dbsetlname()  }
  DBSETHOST        = 1;
  DBSETUSER        = 2;
  DBSETPWD         = 3;
  DBSETAPP         = 4;
  DBSETID          = 5;
  DBSETLANG        = 6;
  DBSETSECURE      = 7;
  DBVER42          = 8;
  DBVER60          = 9;
  DBSET_LOGIN_TIME = 10;
  DBSETFALLBACK    = 12;

{  Standard exit and error values  }
  STDEXIT =  0;
  ERREXIT = -1;

{  dbrpcinit flags  }
  DBRPCRECOMPILE  = $0001;
  DBRPCRESET      = $0004;
  DBRPCCURSOR     = $0008;

{  dbrpcparam flags  }
  DBRPCRETURN     = $1;
  DBRPCDEFAULT    = $2;


{  Cursor related constants  }

{  Following flags are used in the concuropt parameter in the dbcursoropen function  }
  CUR_READONLY = 1;  { Read only cursor, no data modifications }
  CUR_LOCKCC   = 2;  { Intent to update, all fetched data locked when        }
                        { dbcursorfetch is called inside a transaction block }
  CUR_OPTCC    = 3;  { Optimistic concurrency control, data modifications    }
                        { succeed only if the row hasn't been updated since  }
                        { the last fetch.                                    }
  CUR_OPTCCVAL = 4;  { Optimistic concurrency control based on selected column values }

{  Following flags are used in the scrollopt parameter in dbcursoropen  }
  CUR_FORWARD      =  0;   { Forward only scrolling   }
  CUR_KEYSET       = -1;   { Keyset driven scrolling  }
  CUR_DYNAMIC      =  1;   { Fully dynamic            }
  CUR_INSENSITIVE  = -2;   { Server-side cursors only }

{  Following flags define the fetchtype in the dbcursorfetch function  }
  FETCH_FIRST      = 1;    { Fetch first n rows    }
  FETCH_NEXT       = 2;    { Fetch next n rows     }
  FETCH_PREV       = 3;    { Fetch previous n rows }
  FETCH_RANDOM     = 4;    { Fetch n rows beginning with given row # }
  FETCH_RELATIVE   = 5;    { Fetch relative to previous fetch row #  }
  FETCH_LAST       = 6;    { Fetch the last n rows }

{  Following flags define the per row status as filled by dbcursorfetch and/or dbcursorfetchex  }
  FTC_EMPTY        = $00;  { No row available                     }
  FTC_SUCCEED      = $01;  { Fetch succeeded, (failed if not set) }
  FTC_MISSING      = $02;  { The row is missing                   }
  FTC_ENDOFKEYSET  = $04;  { End of the keyset reached            }
  FTC_ENDOFRESULTS = $08;  { End of results set reached           }

{  Following flags define the operator types for the dbcursor function  }
  CRS_UPDATE       = 1;    { Update operation  }
  CRS_DELETE       = 2;    { Delete operation  }
  CRS_INSERT       = 3;    { Insert operation  }
  CRS_REFRESH      = 4;    { Refetch given row }
  CRS_LOCKCC       = 5;    { Lock given row    }

{  Following value can be passed to the dbcursorbind function for NOBIND type  }
  NOBIND = -2;    { Return length and pointer to data }

{  Following are values used by DBCURSORINFO's Type parameter  }
  CU_CLIENT       = $00000001;
  CU_SERVER       = $00000002;
  CU_KEYSET       = $00000004;
  CU_MIXED        = $00000008;
  CU_DYNAMIC      = $00000010;
  CU_FORWARD      = $00000020;
  CU_INSENSITIVE  = $00000040;
  CU_READONLY     = $00000080;
  CU_LOCKCC       = $00000100;
  CU_OPTCC        = $00000200;
  CU_OPTCCVAL     = $00000400;

{  Following are values used by DBCURSORINFO's Status parameter  }
  CU_FILLING      = $00000001;
  CU_FILLED       = $00000002;


{  Following are values used by dbupdatetext's type parameter  }
  UT_TEXTPTR      = $0001;
  UT_TEXT         = $0002;
  UT_MORETEXT     = $0004;
  UT_DELETEONLY   = $0008;
  UT_LOG          = $0010;


{  The following values are passed to dbserverenum for searching criteria.  }
  NET_SEARCH      = $0001;
  LOC_SEARCH      = $0002;

{  These constants are the possible return values from dbserverenum.  }
  ENUM_SUCCESS       = $0000;
  MORE_DATA          = $0001;
  NET_NOT_AVAIL      = $0002;
  OUT_OF_MEMORY      = $0004;
  NOT_SUPPORTED      = $0008;
  ENUM_INVALID_PARAM = $0010;


{ Netlib Error problem codes.  ConnectionError() should return one of      }
{ these as the dblib-mapped problem code, so the corresponding string      }
{ is sent to the dblib app's error handler as dberrstr.  Return NE_E_NOMAP }
{ for a generic DB-Library error string (as in prior versions of dblib).   }

  NE_E_NOMAP          = 0;   { No string; uses dblib default.    }
  NE_E_NOMEMORY       = 1;   { Insufficient memory.              }
  NE_E_NOACCESS       = 2;   { Access denied.                    }
  NE_E_CONNBUSY       = 3;   { Connection is busy.               }
  NE_E_CONNBROKEN     = 4;   { Connection broken.                }
  NE_E_TOOMANYCONN    = 5;   { Connection limit exceeded.        }
  NE_E_SERVERNOTFOUND = 6;   { Specified SQL server not found.   }
  NE_E_NETNOTSTARTED  = 7;   { The network has not been started. }
  NE_E_NORESOURCE     = 8;   { Insufficient network resources.   }
  NE_E_NETBUSY        = 9;   { Network is busy.                  }
  NE_E_NONETACCESS    = 10;  { Network access denied.            }
  NE_E_GENERAL        = 11;  { General network error.  Check your documentation. }
  NE_E_CONNMODE       = 12;  { Incorrect connection mode.             }
  NE_E_NAMENOTFOUND   = 13;  { Name not found in directory service.   }
  NE_E_INVALIDCONN    = 14;  { Invalid connection.                    }
  NE_E_NETDATAERR     = 15;  { Error reading or writing network data. }
  NE_E_TOOMANYFILES   = 16;  { Too many open file handles.            }
  NE_E_CANTCONNECT    = 17;  { SQL Server does not exist or access denied. }

  NE_MAX_NETERROR     = 17;

implementation

end.

