unit SqlTypes;

interface

uses Windows;

{ ----------------------------------------------------------------- }
{ SQLTYPES.PAS - This file defines the types used in ODBC           }
{                                                                   }
{ (C) Copyright 1995-1996 By Microsoft Corp.                        }
{                                                                   }
{               Created 04/10/95 for 2.50 specification             }
{               Updated 12/11/95 for 3.00 specification             }
{                                                                   }
{ Translated From: SQLTYPES.H                                       }
{ Last Modified: 12/05/1997                                         }
{ Version: 1.0                                                      }
{ ----------------------------------------------------------------- }

{  Default to ODBC Version 3.0 if no version is specified  }
{$IFNDEF ODBC_BaseVer} {and} {$IFNDEF ODBC_Ver10} {and} {$IFNDEF ODBC_Ver20}
      {and} {$IFNDEF ODBC_Ver25} {and} {$IFNDEF ODBC_Ver30} {then}
  {$DEFINE ODBC_Ver30}
{$ENDIF} {$ENDIF} {$ENDIF} {$ENDIF} {$ENDIF}

{ environment specific definitions }
{$IFNDEF EXPORT}
  {$DEFINE EXPORT}
{$ENDIF}


type
{ API declaration data types }
  SQLCHAR = UCHAR;
  PSQLCHAR = ^SQLCHAR;
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQLSCHAR = Char;
  SQLDATE = UCHAR;
  SQLDECIMAL = UCHAR;
  SQLDOUBLE = Double;
  SQLFLOAT = Double;
{$ENDIF} {ODBC_Ver30}

  SQLINTEGER = LongInt;
  PSQLINTEGER = ^SQLINTEGER;
  SQLUINTEGER = ULONG;
  PSQLUINTEGER = ^SQLUINTEGER;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQLNUMERIC = UCHAR;
{$ENDIF} {ODBC_Ver30}

  SQLPOINTER = Pointer;
  PSQLPOINTER = ^SQLPOINTER;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQLREAL = Single;
{$ENDIF} {ODBC_Ver30}

  SQLSMALLINT = SHORT;
  PSQLSMALLINT = ^SQLSMALLINT;
  USHORT = Word;
  SQLUSMALLINT = USHORT;
  PSQLUSMALLINT = ^SQLUSMALLINT;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  SQLTIME = UCHAR;
  SQLTIMESTAMP = UCHAR;
  SQLVARCHAR = UCHAR;
{$ENDIF} {ODBC_Ver30}

{ function return type }
  SQLRETURN = SQLSMALLINT;

{ generic data structures }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
 {$IFDEF WIN32}
  SQLHANDLE = Pointer;
 {$ELSE}
  SQLHANDLE = SQLINTEGER;
 {$ENDIF} { WIN32 }

  PSQLHANDLE = ^SQLHANDLE;

  SQLHENV   = SQLHANDLE;
  SQLHDBC   = SQLHANDLE;
  PSQLHDBC  = ^SQLHDBC;
  SQLHSTMT  = SQLHANDLE;
  PSQLHSTMT = ^SQLHSTMT;
  SQLHDESC  = SQLHANDLE;
{$ELSE}
 {$IFDEF WIN32}
  SQLHENV   = Pointer;
  SQLHDBC   = Pointer;
  PSQLHDBC  = ^SQLHDBC;
  SQLHSTMT  = Pointer;
  SQLHSTMT  = ^SQLHSTMT;
 {$ELSE}
  SQLHENV   = SQLINTEGER;
  SQLHDBC   = SQLINTEGER;
  SQLHDBC   = ^SQLHDBC;
  SQLHSTMT  = SQLINTEGER;
  SQLHSTMT  = ^SQLHSTMT;
 {$ENDIF} { WIN32 }
{$ENDIF} {ODBC_Ver30}

{ SQL portable types for C }
  UCHAR = Byte;
  SCHAR = Char;
  { SQLSCHAR = SCHAR; }
  SDWORD = LongInt;
  SWORD = SHORT;
  UDWORD = ULONG;
  UWORD = USHORT;
  PUWORD = ^UWORD;
  { SQLUINTEGER = UDWORD; }

  INT = Integer;
  LONG = LongInt;
  SLONG = LongInt;
  SSHORT = SmallInt;
  { ULONG = ULONG; }
  { USHORT = USHORT; }
  SDOUBLE = Double;
  LDOUBLE = Double;
  SFLOAT = Single;

  PTR = Pointer;

  HENV  = Pointer;
  HDBC  = Pointer;
  HSTMT = Pointer;

  RETCODE = SSHORT;

{$IFDEF WIN32}  SQLHWND = HWND;    {$ELSE}
{$IFDEF OS2}    SQLHWND = HWND;    {$ELSE}
{$IFDEF UNIX}   SQLHWND = Widget;  {$ELSE}
      { placehold for future O/S GUI window handle definition }
                SQLHWND = SQLPOINTER;
{$ENDIF} { UNIX } {$ENDIF} { OS2 } {$ENDIF} { WIN32 }

{$IFNDEF __SQLDATE}
  {$DEFINE __SQLDATE}

{ transfer types for DATE, TIME, TIMESTAMP }
  TDateStruct = record
    year:  SQLSMALLINT;
    month: SQLUSMALLINT;
    day:   SQLUSMALLINT;
  end;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  TSqlDateStruct = TDateStruct;
{$ENDIF} {ODBC_Ver30}

  TTimeStruct = record
    hour:   SQLUSMALLINT;
    minute: SQLUSMALLINT;
    second: SQLUSMALLINT;
  end;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  TSqlTimeStruct = TTimeStruct;
{$ENDIF} {ODBC_Ver30}

  TTimeStampStruct = record
    year:     SQLSMALLINT;
    month:    SQLUSMALLINT;
    day:      SQLUSMALLINT;
    hour:     SQLUSMALLINT;
    minute:   SQLUSMALLINT;
    second:   SQLUSMALLINT;
    fraction: SQLUINTEGER;
  end;

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  TSqlTimeStampStruct = TTimeStampStruct;
{$ENDIF} {ODBC_Ver30}


{ enumerations for DATETIME_INTERVAL_SUBCODE values for interval }
{ data types these values are from SQL-92                        }

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  TSqlInterval = (SQL_UNKNOWN,
                  SQL_IS_YEAR,
                  SQL_IS_MONTH,
                  SQL_IS_DAY,
                  SQL_IS_HOUR,
                  SQL_IS_MINUTE,
                  SQL_IS_SECOND,
                  SQL_IS_YEAR_TO_MONTH,
                  SQL_IS_DAY_TO_HOUR,
                  SQL_IS_DAY_TO_MINUTE,
                  SQL_IS_DAY_TO_SECOND,
                  SQL_IS_HOUR_TO_MINUTE,
                  SQL_IS_HOUR_TO_SECOND,
                  SQL_IS_MINUTE_TO_SECOND);
{$ENDIF} {ODBC_Ver30}

{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  TSqlYearMonthStruct = record
    year:  SQLUINTEGER;
    month: SQLUINTEGER;
  end;

  TSqlDaySecondStruct = record
    day:      SQLUINTEGER;
    hour:     SQLUINTEGER;
    minute:   SQLUINTEGER;
    second:   SQLUINTEGER;
    fraction: SQLUINTEGER;
  end;

  TSqlIntervalStruct = record
    interval_type: TSqlInterval;
    interval_sign: SQLSMALLINT;
    case Integer of
      0: (year_month: TSqlYearMonthStruct);
      1: (day_second: TSqlDaySecondStruct);
  end;
{$ENDIF} {ODBC_Ver30}

{$ENDIF} { __SQLDATE }

{ the ODBC C types for SQL_C_SBIGINT and SQL_C_UBIGINT }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
  ODBCINT64 = LONGLONG;    {  __int64  -  Big Int }
  SQLBIGINT = ODBCINT64;
  SQLUBIGINT = ODBCINT64;  { unsigned ODBCINT64   }
{$ENDIF} {ODBC_Ver30}

{ internal representation of numeric data type }
{$IFDEF ODBC_Ver30}  { ODBC Version 3.0 and above }
const
  SQL_MAX_NUMERIC_LEN = 16;

type
  TSqlNumericStruct = record
    precision: SQLCHAR;
    scale:     SQLSCHAR;
    sign:      SQLCHAR;	 { 1 if positive, 0 if negative }
    val: array[0..SQL_MAX_NUMERIC_LEN-1] of SQLCHAR;
  end;
{$ENDIF} {ODBC_Ver30}

  BOOKMARK = ULONG;

  SQLWCHAR = WideChar;  { WideCharacter - word-sized Unicode character }
  PSQLWCHAR = ^SQLWCHAR;

{$IFDEF UNICODE}
  SQLTCHAR = SQLWCHAR;
{$ELSE}
  SQLTCHAR = SQLCHAR;
{$ENDIF} {UNICODE}


implementation

end.

